@@ -7,6 +7,8 @@
 #Add the flag -Ddevelopment = true to use features still in development
 prefix=`dirname $(readlink $0 || echo $0)`
 exec java -Xmx4000m \
+-XX:+IgnoreUnrecognizedVMOptions \
+    --illegal-access=permit --add-modules=java.xml.bind \
 	-Dapple.laf.useScreenMenuBar=true \
 	-Djava.net.preferIPv4Stack=true \
 	-jar "$prefix"/igv.jar "$@"
