@@ -28,6 +28,8 @@ package org.broad.igv;
 import org.apache.commons.io.FileUtils;
 import org.apache.log4j.*;
 import org.broad.igv.exceptions.DataLoadException;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.ui.util.FileDialogUtils;
 import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.util.RuntimeUtils;
@@ -36,6 +38,8 @@ import javax.swing.*;
 import javax.swing.filechooser.FileSystemView;
 import java.io.File;
 import java.io.IOException;
+import java.nio.file.Files;
+import java.nio.file.Path;
 import java.util.prefs.Preferences;
 
 /**
@@ -79,13 +83,11 @@ public class DirectoryManager {
         return USER_DIRECTORY;
     }
 
-
     public static void setIgvDirectory(File dir) {
         log.info("IGV Directory: " + dir.getAbsolutePath());
         IGV_DIRECTORY = dir;
     }
 
-
     public static File getIgvDirectory() {
 
         if (IGV_DIRECTORY == null) {
@@ -211,6 +213,24 @@ public class DirectoryManager {
         return GENOME_CACHE_DIRECTORY;
     }
 
+    public static File getFastaCacheDirectory() {
+
+        File directory = null;
+        String cachePref = PreferencesManager.getPreferences().get(Constants.CRAM_CACHE_DIRECTORY);
+        if (cachePref != null) {
+            directory = new File(cachePref);
+        }
+
+        if(directory == null || !directory.exists() || !directory.isDirectory()) {
+
+            directory = new File(getGenomeCacheDirectory(), "seq");
+            if (!directory.exists()) {
+                directory.mkdir();
+            }
+        }
+        return directory;
+    }
+
     public static File getGeneListDirectory() {
         if (GENE_LIST_DIRECTORY == null) {
             GENE_LIST_DIRECTORY = new File(getIgvDirectory(), "lists");
@@ -325,7 +345,7 @@ public class DirectoryManager {
                 prefs.put(IGV_DIR_USERPREF, newIGVDirectory.getAbsolutePath());
 
                 // Update preference manager with new file location
-                PreferenceManager.getInstance().setPrefsFile(getPreferencesFile().getAbsolutePath());
+                PreferencesManager.setPrefsFile(getPreferencesFile().getAbsolutePath());
 
             } catch (IOException e) {
                 log.error("Error copying IGV directory", e);
@@ -356,6 +376,26 @@ public class DirectoryManager {
 
     }
 
+    public static void moveDirectoryContents(File oldDirectory, File newDirectory) {
+
+        if (oldDirectory != null && oldDirectory.exists() && oldDirectory.isDirectory() &&
+                newDirectory != null && newDirectory.exists() && newDirectory.isDirectory()) {
+
+            for (File f : oldDirectory.listFiles()) {
+                Path p1 = f.toPath();
+                Path p2 = (new File(newDirectory, f.getName())).toPath();
+                try {
+                    Files.move(p1, p2);
+                } catch (IOException e) {
+                    log.error("Error moving file", e);
+                }
+            }
+
+        }
+
+
+    }
+
     /**
      * Delete the directory and all contents recursively.  The apache FileUtils is hanging on Linux.
      *
@@ -459,4 +499,5 @@ public class DirectoryManager {
             log.error("Error creating log file", e);
         }
     }
+
 }
