@@ -56,8 +56,7 @@ public class BigWigDataSource extends AbstractDataSource implements FeatureSourc
 
 
     Collection<WindowFunction> availableWindowFunctions =
-            Arrays.asList(WindowFunction.min, WindowFunction.mean, WindowFunction.max);
-    WindowFunction windowFunction = WindowFunction.mean;
+            Arrays.asList(WindowFunction.min, WindowFunction.mean, WindowFunction.max, WindowFunction.none);
 
     BBFileReader reader;
     private BBZoomLevels levels;
@@ -65,7 +64,7 @@ public class BigWigDataSource extends AbstractDataSource implements FeatureSourc
     // Feature visibility window (for bigBed)
     private int featureVisiblityWindow = -1;
 
-    private List<LocusScore> wholeGenomeScores;
+    private Map<WindowFunction, List<LocusScore>> wholeGenomeScores;
 
     // Lookup table to support chromosome aliasing.
     private Map<String, String> chrNameMap = new HashMap();
@@ -81,9 +80,10 @@ public class BigWigDataSource extends AbstractDataSource implements FeatureSourc
         super(genome);
 
         this.reader = reader;
-        levels = reader.getZoomLevels();
+        this.levels = reader.getZoomLevels();
+        this.wholeGenomeScores = new HashMap<>();
 
-        if(reader.isBigWigFile()) initMinMax();
+        if (reader.isBigWigFile()) initMinMax();
 
         // Assume 1000 pixel screen, pick visibility level to be @ highest resolution zoom.
         // TODO -- something smarter, like scaling by actual density
@@ -163,12 +163,6 @@ public class BigWigDataSource extends AbstractDataSource implements FeatureSourc
         return TrackType.OTHER;
     }
 
-    public void setWindowFunction(WindowFunction statType) {
-        // Invalidate caches
-        wholeGenomeScores = null;
-
-        this.windowFunction = statType;
-    }
 
     public boolean isLogNormalized() {
         return false;
@@ -183,9 +177,6 @@ public class BigWigDataSource extends AbstractDataSource implements FeatureSourc
         return 0;
     }
 
-    public WindowFunction getWindowFunction() {
-        return windowFunction;
-    }
 
     public Collection<WindowFunction> getAvailableWindowFunctions() {
         return availableWindowFunctions;
@@ -213,15 +204,14 @@ public class BigWigDataSource extends AbstractDataSource implements FeatureSourc
         if (levels == null) return null;
 
         final ArrayList<BBZoomLevelHeader> headers = levels.getZoomLevelHeaders();
-        BBZoomLevelHeader lastLevel = null;
-        for (BBZoomLevelHeader zlHeader : headers) {
+        for (int i = headers.size() - 1; i >= 0; i--) {
+            BBZoomLevelHeader zlHeader = headers.get(i);
             int reductionLevel = zlHeader.getReductionLevel();
-            if (reductionLevel > resolution) {
-                return lastLevel == null ? zlHeader : lastLevel;
+            if (reductionLevel < resolution) {
+                return zlHeader;
             }
-            lastLevel = zlHeader;
         }
-        return headers.get(headers.size() - 1);
+        return headers.get(0);
 
     }
 
@@ -270,6 +260,10 @@ public class BigWigDataSource extends AbstractDataSource implements FeatureSourc
     }
 
     private float getValue(ZoomDataRecord rec) {
+
+        if (rec == null) {
+            System.out.println();
+        }
         float v;
         switch (windowFunction) {
             case min:
@@ -323,44 +317,53 @@ public class BigWigDataSource extends AbstractDataSource implements FeatureSourc
 
     private List<LocusScore> getWholeGenomeScores() {
 
-        if (genome.getHomeChromosome().equals(Globals.CHR_ALL)) {
-            if (wholeGenomeScores == null) {
+        if (genome.getHomeChromosome().equals(Globals.CHR_ALL) && windowFunction != WindowFunction.none) {
+
+            if (wholeGenomeScores.get(windowFunction) == null) {
+
                 double scale = genome.getNominalLength() / screenWidth;
-                wholeGenomeScores = new ArrayList<LocusScore>();
 
-                for (String chrName : genome.getLongChromosomeNames()) {
-                    Chromosome chr = genome.getChromosome(chrName);
+                int maxChromId = reader.getChromosomeNames().size() - 1;
+                String firstChr = reader.getChromsomeFromId(0);
+                String lastChr = reader.getChromsomeFromId(maxChromId);
 
-                    BBZoomLevelHeader lowestResHeader = this.getZoomLevelForScale(scale);
-                    if (lowestResHeader == null) return null;
+                ArrayList<LocusScore> scores = new ArrayList<LocusScore>();
+                wholeGenomeScores.put(windowFunction, scores);
 
-                    int lastGenomeEnd = -1;
-                    int end = chr.getLength();
+                BBZoomLevelHeader lowestResHeader = this.getZoomLevelForScale(scale);
+                if (lowestResHeader == null) return null;
 
-                    String tmp = chrNameMap.get(chrName);
-                    String querySeq = tmp == null ? chrName : tmp;
+                Set<String> wgChrNames = new HashSet<>(genome.getLongChromosomeNames());
 
-                    ZoomLevelIterator zlIter = reader.getZoomLevelIterator(
-                            lowestResHeader.getZoomLevel(), querySeq, 0, querySeq, end, false);
+                ZoomLevelIterator zlIter = reader.getZoomLevelIterator(
+                        lowestResHeader.getZoomLevel(), firstChr, 0, lastChr, Integer.MAX_VALUE, false);
 
-                    while (zlIter.hasNext()) {
-                        ZoomDataRecord rec = zlIter.next();
+                while (zlIter.hasNext()) {
+                    ZoomDataRecord rec = zlIter.next();
 
-                        float value = getValue(rec);
-                        int genomeStart = genome.getGenomeCoordinate(chrName, rec.getChromStart());
-                        if (genomeStart < lastGenomeEnd) {
-                            continue;
-                        }
+                    if (rec == null) {
+                        continue;
+                    }
 
-                        int genomeEnd = genome.getGenomeCoordinate(chrName, rec.getChromEnd());
-                        wholeGenomeScores.add(new BasicScore(genomeStart, genomeEnd, value));
-                        lastGenomeEnd = genomeEnd;
+                    float value = getValue(rec);
+                    if (Float.isNaN(value) || Float.isInfinite(value)) {
+                        continue;
+                    }
+
+                    String chr = genome.getCanonicalChrName(rec.getChromName());
+
+                    if (wgChrNames.contains(chr)) {
+
+                        int genomeStart = genome.getGenomeCoordinate(chr, rec.getChromStart());
+                        int genomeEnd = genome.getGenomeCoordinate(chr, rec.getChromEnd());
+                        scores.add(new BasicScore(genomeStart, genomeEnd, value));
                     }
                 }
 
+                scores.sort((o1, o2) -> o1.getStart() - o2.getStart());
 
             }
-            return wholeGenomeScores;
+            return wholeGenomeScores.get(windowFunction);
         } else {
             return null;
         }
@@ -370,7 +373,7 @@ public class BigWigDataSource extends AbstractDataSource implements FeatureSourc
     @Override
     public void dispose() {
         super.dispose();
-        if(reader != null) {
+        if (reader != null) {
             reader.close();
         }
     }
@@ -403,7 +406,7 @@ public class BigWigDataSource extends AbstractDataSource implements FeatureSourc
         return null;  //To change body of implemented methods use File | Settings | File Templates.
     }
 
-    public  class WrappedIterator implements Iterator<Feature> {
+    public class WrappedIterator implements Iterator<Feature> {
 
         BigBedIterator bedIterator;
 
@@ -418,7 +421,7 @@ public class BigWigDataSource extends AbstractDataSource implements FeatureSourc
         public Feature next() {
             BedFeature feat = bedIterator.next();
             String[] restOfFields = feat.getRestOfFields();
-            String [] tokens = new String[restOfFields.length + 3];
+            String[] tokens = new String[restOfFields.length + 3];
             tokens[0] = feat.getChromosome();
             tokens[1] = String.valueOf(feat.getStartBase());
             tokens[2] = String.valueOf(feat.getEndBase());
@@ -456,5 +459,4 @@ public class BigWigDataSource extends AbstractDataSource implements FeatureSourc
     }
 
 
-
 }
