@@ -39,12 +39,9 @@ import java.util.*;
  */
 public class FreqData {
 
-    public static float DEFAULT_AMP_THRESHOLD = 0.1f;
-    public static float DEFAULT_DEL_THRESHOLD = -0.1f;
+
     public static int DEFAULT_BIN_SIZE = 200000;
 
-    private float ampThreshold = DEFAULT_AMP_THRESHOLD;
-    private float delThreshold = DEFAULT_DEL_THRESHOLD;
     private int binSize = DEFAULT_BIN_SIZE;    // 200 kb bin size;
 
     private SegmentedDataSet dataset;
@@ -54,6 +51,8 @@ public class FreqData {
     private Map<String, List<LocusScore>> del;
     private List<String> sampleNames;
     Genome genome;
+    private float ampThreshold;
+    private float delThreshold;
 
     public FreqData(SegmentedDataSet ds, Genome genome) {
 
@@ -63,19 +62,16 @@ public class FreqData {
         amp = new HashMap();
         del = new HashMap();
         this.genome = genome;
-        compute();
 
     }
 
 
-    public void setParameters(int binSize, float delThreshold, float ampThreshold) {
-        this.binSize = binSize;
-        this.delThreshold = delThreshold;
+    public void compute(float ampThreshold, float delThreshold) {
+
+        if(this.ampThreshold == ampThreshold && this.delThreshold == delThreshold) return;
+
         this.ampThreshold = ampThreshold;
-        compute();
-    }
-
-    void compute() {
+        this.delThreshold = delThreshold;
 
         amp.clear();
         del.clear();
@@ -154,6 +150,7 @@ public class FreqData {
                 }
             }
         }
+
     }
 
     private void binCounts(String chr, int segStart, int segEnd, float segScore, int b, int binSize) {
@@ -217,15 +214,6 @@ public class FreqData {
         return del.get(chr);
     }
 
-    public float getAmpThreshold() {
-        return ampThreshold;
-    }
-
-    public float getDelThreshold() {
-        return delThreshold;
-    }
-
-
     public class Bin implements LocusScore {
         String chr;
         int start;
@@ -288,7 +276,7 @@ public class FreqData {
             return this;  //To change body of implemented methods use File | Settings | File Templates.
         }
 
-        public String getValueString(double position, WindowFunction windowFunction) {
+        public String getValueString(double position, int mouseX, WindowFunction windowFunction) {
             int cnt = Math.abs(Math.round(count));
             int percent = ((cnt * 100) / numberOfSamples);
             return cnt + " (" + percent + "%)";
