@@ -28,7 +28,6 @@ package org.broad.igv.feature;
 
 import org.broad.igv.feature.basepair.BasePairFeature;
 import org.broad.igv.Globals;
-import org.broad.igv.util.Utilities;
 
 
 import java.awt.Color;
@@ -40,8 +39,7 @@ import java.util.*;
 // multiple return from loadDotBracket() and loadConnectTable()
 class SeqLenAndPairs {
     public int seqLen;
-    public ArrayList<Point> pairs;
-
+    public  ArrayList<Point> pairs;
     public SeqLenAndPairs(int seqLen, ArrayList<Point> pairs) {
         this.seqLen = seqLen;
         this.pairs = pairs;
@@ -51,8 +49,7 @@ class SeqLenAndPairs {
 // multiple return from loadPairingProb()
 class SeqLenAndBinnedPairs {
     public int seqLen;
-    public ArrayList<ArrayList<Point>> binnedPairs;
-
+    public  ArrayList<ArrayList<Point>> binnedPairs;
     public SeqLenAndBinnedPairs(int seqLen, ArrayList<ArrayList<Point>> binnedPairs) {
         this.seqLen = seqLen;
         this.binnedPairs = binnedPairs;
@@ -60,6 +57,7 @@ class SeqLenAndBinnedPairs {
 }
 
 
+
 /**
  * @author sbusan
  */
@@ -74,28 +72,28 @@ public class BasePairFileUtils {
      *
      * @param arcs
      * @param seqLen
-     * @param newLeft 1-based genomic coordinate for left-most
-     *                position for input pairs sequence after transformation.
-     *                If strand is "-", this will end up being the 3-prime end
-     *                of the transcript (but the left end in genomic coords).
-     * @param strand  "+" or "-"
+     * @param newLeft   1-based genomic coordinate for left-most
+     *                  position for input pairs sequence after transformation.
+     *                  If strand is "-", this will end up being the 3-prime end
+     *                  of the transcript (but the left end in genomic coords).
+     * @param strand    "+" or "-"
      * @return
      */
     static LinkedList<BasePairFeature> transformArcs(LinkedList<BasePairFeature> arcs,
-                                                     int seqLen,
-                                                     int newLeft,
-                                                     String strand) {
-        LinkedList<BasePairFeature> transArcs = new LinkedList<BasePairFeature>();
-        for (BasePairFeature arc : arcs) {
+                                                    int seqLen,
+                                                    int newLeft,
+                                                    String strand){
+        LinkedList<BasePairFeature> transArcs = new LinkedList<>();
+        for (BasePairFeature arc : arcs){
             String chr = arc.getChr();
             Color color = arc.getColor();
             int startLeft, startRight, endLeft, endRight;
-            if (strand == "+") {
+            if (strand == "+"){
                 startLeft = arc.getStartLeft() + newLeft - 1;
                 startRight = arc.getStartRight() + newLeft - 1;
                 endLeft = arc.getEndLeft() + newLeft - 1;
                 endRight = arc.getEndRight() + newLeft - 1;
-            } else if (strand == "-") {
+            } else if (strand == "-"){
                 startLeft = seqLen - arc.getEndRight() + newLeft;
                 startRight = seqLen - arc.getEndLeft() + newLeft;
                 endLeft = seqLen - arc.getStartRight() + newLeft;
@@ -104,11 +102,11 @@ public class BasePairFileUtils {
                 throw new RuntimeException("Unrecognized strand (options: \"+\",\"-\")");
             }
             BasePairFeature transArc = new BasePairFeature(chr,
-                    startLeft,
-                    startRight,
-                    endLeft,
-                    endRight,
-                    color);
+                                                           startLeft,
+                                                           startRight,
+                                                           endLeft,
+                                                           endRight,
+                                                           color);
             transArcs.add(transArc);
         }
         return transArcs;
@@ -117,7 +115,7 @@ public class BasePairFileUtils {
     static SeqLenAndPairs loadDotBracket(String inFile) throws
             FileNotFoundException, IOException {
         // TODO: add error messages for misformatted file
-        ArrayList<Point> pairs = new ArrayList<Point>();
+        ArrayList<Point> pairs = new ArrayList<>();
         int seqLen = 0;
 
         BufferedReader br = null;
@@ -135,7 +133,7 @@ public class BasePairFileUtils {
                 }
 
                 String s = nextLine.trim();
-                if (Utilities.isAllLetters(s)) {
+                if (s.chars().allMatch(Character::isLetter)) {
                     // sequence line
                     continue;
                 } else {
@@ -147,9 +145,9 @@ public class BasePairFileUtils {
             String leftBrackets = "([{<";
             String rightBrackets = ")]}>";
 
-            ArrayList<LinkedList<Integer>> openIndices = new ArrayList<LinkedList<Integer>>();
+            ArrayList<LinkedList<Integer>> openIndices = new ArrayList<>();
             for (int i = 0; i < leftBrackets.length(); ++i) {
-                openIndices.add(new LinkedList<Integer>());
+                openIndices.add(new LinkedList<>());
             }
 
             for (int i = 0; i < struct.length(); ++i) {
@@ -158,8 +156,8 @@ public class BasePairFileUtils {
                 if (n >= 0) {
                     openIndices.get(n).add(i);
                 } else if (k >= 0) {
-                    int left = i + 1;
-                    int right = openIndices.get(k).pollLast() + 1;
+                    int left = i+1;
+                    int right = openIndices.get(k).pollLast()+1;
                     pairs.add(new Point(left, right));
                 }
             }
@@ -175,7 +173,7 @@ public class BasePairFileUtils {
     static SeqLenAndPairs loadConnectTable(String inFile) throws
             FileNotFoundException, IOException {
         // TODO: add error messages for misformatted file
-        ArrayList<Point> pairs = new ArrayList<Point>();
+        ArrayList<Point> pairs = new ArrayList<>();
         int seqLen = 0;
 
         BufferedReader br = null;
@@ -206,16 +204,16 @@ public class BasePairFileUtils {
         // TODO: add probability threshold color legend to track dropdown menu
         // TODO: support alternate thresholds, interactive threshold update from track UI?
 
-        ArrayList<ArrayList<Point>> binnedPairs = new ArrayList<ArrayList<Point>>();
+        ArrayList<ArrayList<Point>> binnedPairs = new ArrayList<>();
         int seqLen = 0;
 
         double[] probThresh = {0.1, 0.3, 0.8};
-        double[] negLogTenProbThresh = {0, 0, 0};
-        for (int i = 0; i < probThresh.length; i++) {
+        double[] negLogTenProbThresh = {0,0,0};
+        for (int i=0; i<probThresh.length; i++) {
             negLogTenProbThresh[i] = -Math.log10(probThresh[i]);
         }
 
-        for (int i = 0; i < probThresh.length; i++) binnedPairs.add(new ArrayList<java.awt.Point>());
+        for (int i=0; i<probThresh.length; i++) binnedPairs.add(new ArrayList<>());
 
         BufferedReader br = null;
 
@@ -231,7 +229,7 @@ public class BasePairFileUtils {
                 int right = Integer.parseInt(s[1]);
                 double negLogTenProb = Double.parseDouble(s[2]);
                 int binIndex = -1;
-                for (int i = probThresh.length - 1; i >= 0; i--) {
+                for (int i=probThresh.length-1; i>=0; i--){
                     if (negLogTenProb <= negLogTenProbThresh[i]) {
                         binIndex = i;
                         break;
@@ -275,16 +273,17 @@ public class BasePairFileUtils {
 
     /**
      * Merge adjacent basepairs into helices. This makes assumptions about input pair list order.
+
      */
     static LinkedList<BasePairFeature> pairsToHelices(ArrayList<Point> pairs,
                                                       String chromosome) {
-        ArrayList<Point> bps = new ArrayList<Point>(pairs);
-        LinkedList<LinkedList<Point>> helixPairGroups = new LinkedList<LinkedList<Point>>();
+        ArrayList<Point> bps = new ArrayList<>(pairs);
+        LinkedList<LinkedList<Point>> helixPairGroups = new LinkedList<>();
 
         // FIXME: there should be a much faster and more elegant way to do this
         while (bps.size() > 0) {
             Point bp = bps.get(0);
-            LinkedList<Point> helixPairs = new LinkedList<Point>();
+            LinkedList<Point> helixPairs = new LinkedList<>();
             boolean[] removePairs = new boolean[bps.size()];
             helixPairs.add(bp);
             removePairs[0] = true;
@@ -313,7 +312,7 @@ public class BasePairFileUtils {
                     // reached the end of the helix
                     helixPairGroups.add(helixPairs);
                     // remove helix pairs
-                    ArrayList<Point> tmpBps = new ArrayList<Point>();
+                    ArrayList<Point> tmpBps = new ArrayList<>();
                     for (int k = 0; k < bps.size(); k++) {
                         if (!removePairs[k]) tmpBps.add(bps.get(k));
                     }
@@ -333,7 +332,7 @@ public class BasePairFileUtils {
             if (endOfList) {
                 helixPairGroups.add(helixPairs);
                 // remove helix pairs
-                ArrayList<Point> tmpBps = new ArrayList<Point>();
+                ArrayList<Point> tmpBps = new ArrayList<>();
                 for (int k = 0; k < bps.size(); k++) {
                     if (!removePairs[k]) tmpBps.add(bps.get(k));
                 }
@@ -342,7 +341,7 @@ public class BasePairFileUtils {
         }
 
         // convert lists of adjacent pairs to BasePairFeatures
-        LinkedList<BasePairFeature> helices = new LinkedList<BasePairFeature>();
+        LinkedList<BasePairFeature> helices = new LinkedList<>();
         for (LinkedList<Point> helixPairs : helixPairGroups) {
             int startLeft = Integer.MAX_VALUE;
             int startRight = 0;
@@ -369,6 +368,7 @@ public class BasePairFileUtils {
      * Convert a base pairing structure file in dot-bracket notation
      * (also known as Vienna format) to an easily parseable .bp arcs file. Does not
      * currently handle mapping coords to spliced transcripts.
+     *
      */
     public static void dotBracketToBasePairFile(String inFile,
                                                 String bpFile,
@@ -382,9 +382,9 @@ public class BasePairFileUtils {
         int seqLen = s.seqLen;
         LinkedList<BasePairFeature> arcs = pairsToHelices(pairs, chromosome);
         arcs = transformArcs(arcs, seqLen, left, strand);
-        ArrayList<Color> colors = new ArrayList<Color>();
+        ArrayList<Color> colors = new ArrayList<>();
         colors.add(Color.black);
-        ArrayList<LinkedList<BasePairFeature>> groupedArcs = new ArrayList<LinkedList<BasePairFeature>>();
+        ArrayList<LinkedList<BasePairFeature>> groupedArcs = new ArrayList<>();
         groupedArcs.add(arcs); // list of length 1 for this case (arcs only have 1 color)
         writeBasePairFile(bpFile, colors, groupedArcs);
     }
@@ -393,6 +393,7 @@ public class BasePairFileUtils {
      * Convert a connectivity table file as output by RNAStructure
      * to an easily parseable .bp arcs file. Does not
      * currently handle mapping coords to spliced transcripts.
+
      */
     public static void connectTableToBasePairFile(String inFile,
                                                   String bpFile,
@@ -406,9 +407,9 @@ public class BasePairFileUtils {
         int seqLen = s.seqLen;
         LinkedList<BasePairFeature> arcs = pairsToHelices(pairs, chromosome);
         arcs = transformArcs(arcs, seqLen, left, strand);
-        ArrayList<Color> colors = new ArrayList<Color>();
+        ArrayList<Color> colors = new ArrayList<>();
         colors.add(Color.black);
-        ArrayList<LinkedList<BasePairFeature>> groupedArcs = new ArrayList<LinkedList<BasePairFeature>>();
+        ArrayList<LinkedList<BasePairFeature>> groupedArcs = new ArrayList<>();
         groupedArcs.add(arcs); // list of length 1 for this case (arcs only have 1 color)
         writeBasePairFile(bpFile, colors, groupedArcs);
     }
@@ -417,6 +418,7 @@ public class BasePairFileUtils {
      * Convert a pairing probability file as output by RNAStructure
      * and/or SuperFold to an easily parseable .bp arcs file. Does not
      * currently handle mapping coords to spliced transcripts.
+
      */
     public static void pairingProbToBasePairFile(String inFile,
                                                  String bpFile,
@@ -428,12 +430,12 @@ public class BasePairFileUtils {
         SeqLenAndBinnedPairs s = loadPairingProb(inFile);
         ArrayList<ArrayList<Point>> binnedPairs = s.binnedPairs;
         int seqLen = s.seqLen;
-        ArrayList<LinkedList<BasePairFeature>> groupedArcs = new ArrayList<LinkedList<BasePairFeature>>();
-        for (ArrayList<Point> pairGroup : binnedPairs) {
+        ArrayList<LinkedList<BasePairFeature>> groupedArcs = new ArrayList<>();
+        for (ArrayList<Point> pairGroup : binnedPairs){
             groupedArcs.add(transformArcs(pairsToHelices(pairGroup, chromosome),
-                    seqLen, left, strand));
+                                           seqLen, left, strand));
         }
-        ArrayList<Color> colors = new ArrayList<Color>();
+        ArrayList<Color> colors = new ArrayList<>();
         colors.add(new Color(255, 204, 0));
         colors.add(new Color(72, 143, 205));
         colors.add(new Color(81, 184, 72));
@@ -441,4 +443,8 @@ public class BasePairFileUtils {
     }
 
 
+
+
+
+
 }
