@@ -1,13 +1,28 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
+
 package org.broad.igv.feature;
 
 //~--- non-JDK imports --------------------------------------------------------
@@ -55,13 +70,17 @@ public class EmblFeatureTableParser implements FeatureParser {
         int cds = 0;
         int exonNumber = 1;
         for (int i = startIndex; i != endIndex; i += increment) {
-            org.broad.igv.feature.Exon exon = exons.get(i);
-            exon.setNumber(exonNumber);
-            int modCds = cds % 3;
-            int phase = (modCds == 0) ? 0 : 3 - modCds;
-            exon.setPhase(phase);
-            cds += exon.getCodingLength();
-            exonNumber++;
+
+            Exon exon = exons.get(i);
+            exon.setNumber(exonNumber++);
+
+            if (exon.getCodingLength() > 0 || cds > 0) {  // Skip until we find the coding start
+                int modCds = cds % 3;
+                int phase = (modCds == 0) ? 0 : 3 - modCds;
+                exon.setPhase(phase);
+                cds += exon.getCodingLength();
+            }
+
         }
     }
 
@@ -81,7 +100,7 @@ public class EmblFeatureTableParser implements FeatureParser {
         try {
             reader = ParsingUtils.openBufferedReader(locator);
 
-            List<org.broad.tribble.Feature> features = loadFeatures(reader, genome);
+            List<htsjdk.tribble.Feature> features = loadFeatures(reader, genome);
 
             if (features.isEmpty()) {
                 return null;
@@ -119,7 +138,7 @@ public class EmblFeatureTableParser implements FeatureParser {
      * @param reader
      * @return
      */
-    public List<org.broad.tribble.Feature> loadFeatures(BufferedReader reader, Genome genome) {
+    public List<htsjdk.tribble.Feature> loadFeatures(BufferedReader reader, Genome genome) {
 
         List<BasicFeature> features = new ArrayList();
 
@@ -198,9 +217,9 @@ public class EmblFeatureTableParser implements FeatureParser {
 
     // Combine the constituitve gene parts into a single feature (3', 5', and cds).  This is
     // necccessary with the current IGV gene model, which is heavily influence by ucsc conventions
-    static List<org.broad.tribble.Feature> combineGeneParts(List<BasicFeature> features) {
+    static List<htsjdk.tribble.Feature> combineGeneParts(List<BasicFeature> features) {
 
-        List<org.broad.tribble.Feature> newFeatureList = new ArrayList(features.size());
+        List<htsjdk.tribble.Feature> newFeatureList = new ArrayList(features.size());
         Map<String, BasicFeature> genes = new HashMap();
 
         // Step 1 -- find the coding regions
@@ -235,11 +254,10 @@ public class EmblFeatureTableParser implements FeatureParser {
                     exon.setNonCoding(true);
                     boolean plus = (type.equals("5'UTR") && feature.getStrand() == Strand.POSITIVE) ||
                             (type.equals("3'UTR") && feature.getStrand() == Strand.NEGATIVE);
-                    if(plus) {
+                    if (plus) {
                         exon.setCodingStart(feature.getEnd());
                         exon.setCodingEnd(feature.getEnd());
-                    }
-                    else {
+                    } else {
                         exon.setCodingStart(feature.getStart());
                         exon.setCodingEnd(feature.getStart());
                     }
