@@ -245,7 +245,7 @@ public class Exon extends AbstractFeature implements IExon {
                         seqBytes = tmp;
                     }
 
-                    aminoAcidSequence = AminoAcidManager.getInstance().getAminoAcidSequence(getStrand(), readStart, seqBytes);
+                    aminoAcidSequence = AminoAcidManager.getInstance().getAminoAcidSequence(getStrand(), readStart, new String(seqBytes));
                 }
             }
         }
@@ -263,7 +263,7 @@ public class Exon extends AbstractFeature implements IExon {
         return copy;
     }
 
-    public String getValueString(double position, WindowFunction windowFunction) {
+    public String getValueString(double position, int mouseX, WindowFunction windowFunction) {
 
         StringBuffer buffer = new StringBuffer();
 
