@@ -32,6 +32,7 @@ import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.genome.GenomeManager;
+import org.broad.igv.track.SequenceTrack;
 import org.broad.igv.util.collections.MultiMap;
 import htsjdk.tribble.Feature;
 
@@ -77,6 +78,30 @@ public class FeatureDB {
         }
     }
 
+    public static void removeFeature(NamedFeature feature, Genome genome) {
+
+        final String name = feature.getName();
+        if (name != null && name.length() > 0 && !name.equals(".")) {
+            featureMap.remove(name.toUpperCase());
+        }
+        if (feature instanceof IGVFeature) {
+            final IGVFeature igvFeature = (IGVFeature) feature;
+            final String id = igvFeature.getIdentifier();
+            if (id != null && id.length() > 0) {
+                featureMap.remove(id.toUpperCase());
+            }
+
+            removeByAttributes(igvFeature, genome);
+
+            List<Exon> exons = igvFeature.getExons();
+            if (exons != null) {
+                for (Exon exon : exons) {
+                    removeByAttributes(exon, genome);
+                }
+            }
+        }
+    }
+
     private static void addByAttributes(IGVFeature igvFeature, Genome genome) {
         MultiMap<String, String> attributes = igvFeature.getAttributes();
         if (attributes != null) {
@@ -88,6 +113,17 @@ public class FeatureDB {
         }
     }
 
+    private static void removeByAttributes(IGVFeature igvFeature, Genome genome) {
+        MultiMap<String, String> attributes = igvFeature.getAttributes();
+        if (attributes != null) {
+            for (String value : attributes.values()) {
+                if (value.length() < 20) {
+                    featureMap.remove(value.toUpperCase());
+                }
+            }
+        }
+    }
+
     /**
      * Add feature to the list of features associated with this name.
      * Performs no data integrity checks
@@ -110,7 +146,7 @@ public class FeatureDB {
             List<NamedFeature> currentList = featureMap.get(key);
             if (currentList == null) {
                 List<NamedFeature> newList = new SortedList<NamedFeature>(
-                        new ArrayList<NamedFeature>(), FeatureComparator.get(true));
+                        new ArrayList<>(), FeatureComparator.get(true));
                 boolean added = newList.add(feature);
                 if (added) {
                     featureMap.put(key, newList);
@@ -363,7 +399,7 @@ public class FeatureDB {
                     }
                     tempNT = new String(nuclSequence);
                     if (bf.getStrand() == Strand.NEGATIVE) {
-                        tempNT = AminoAcidManager.getNucleotideComplement(tempNT);
+                        tempNT = SequenceTrack.getReverseComplement(tempNT);
                     }
 
                     if (tempNT.toUpperCase().equals(brefNT)) {
