@@ -39,6 +39,8 @@ import org.broad.igv.Globals;
 import org.broad.igv.feature.Chromosome;
 import org.broad.igv.feature.Cytoband;
 import org.broad.igv.track.FeatureTrack;
+import org.broad.igv.ui.panel.ReferenceFrame;
+import org.broad.igv.util.ResourceLocator;
 
 import java.io.*;
 import java.util.*;
@@ -64,7 +66,16 @@ public class Genome {
     private Sequence sequence;
     private FeatureTrack geneTrack;
     private String species;
+    private String ucscID;
+    private GenomeDescriptor descriptor;   // Can be null
+    private ArrayList<ResourceLocator> annotationResources;
 
+
+    public Genome(String id, String displayName, Sequence sequence, boolean chromosOrdered, GenomeDescriptor descriptor) {
+        this(id, displayName, sequence, chromosOrdered);
+        this.descriptor = descriptor;
+
+    }
     /**
      * @param id
      * @param displayName
@@ -77,6 +88,7 @@ public class Genome {
         this.chrAliasTable = new HashMap<String, String>();
         this.sequence = sequence;
         chromosomeNames = sequence.getChromosomeNames();
+        this.ucscID = ucsdIDMap.containsKey(id) ? ucsdIDMap.get(id) : id;
 
         List<Chromosome> tmpChromos = new ArrayList<Chromosome>(chromosomeNames.size());
         int maxLength = -1;
@@ -99,6 +111,7 @@ public class Genome {
             chromosomeNames = new ArrayList<String>(chromosomeMap.keySet());
         }
 
+
         initializeChromosomeAliases();
     }
 
@@ -139,6 +152,10 @@ public class Genome {
         }
     }
 
+    public GenomeDescriptor getDescriptor() {
+        return descriptor;
+    }
+
     public Map<String, String> getChrAliasTable() {
         return chrAliasTable;
     }
@@ -152,7 +169,7 @@ public class Genome {
      */
     public void addChrAliases(Collection<Collection<String>> synonymsList) {
 
-        if(chrAliasTable == null) chrAliasTable = new HashMap<String, String>();
+        if (chrAliasTable == null) chrAliasTable = new HashMap<String, String>();
 
         // Convert names to a set for fast "contains" testing.
         Set<String> chrNameSet = new HashSet<String>(chromosomeNames);
@@ -201,64 +218,59 @@ public class Genome {
 
                 // Also strip version number out, if present
                 int dotIndex = alias.lastIndexOf('.');
-                if(dotIndex > 0) {
+                if (dotIndex > 0) {
                     alias = alias.substring(0, dotIndex);
                     autoAliases.put(alias, name);
                 }
             }
         }
 
-        if (chromosomeNames.size() < 10000) {
-            for (String name : chromosomeNames) {
 
-                // UCSC Conventions
-                if (name.toLowerCase().startsWith("chr")) {
-                    autoAliases.put(name.substring(3), name);
-                } else {
-                    autoAliases.put("chr" + name, name);
-                }
+        // Auto insert UCSC conventions for first 50
+        int count = 0;
+        for (String name : chromosomeNames) {
+            // UCSC Conventions
+            if (name.toLowerCase().startsWith("chr")) {
+                autoAliases.put(name.substring(3), name);
+            } else {
+                autoAliases.put("chr" + name, name);
             }
+            if(count++ == 50) break;
+        }
 
+        // Special case for human and mouse -- for other genomes define these in the alias file.
+        if (id.startsWith("hg") || id.equalsIgnoreCase("1kg_ref")) {
+            autoAliases.put("23", "chrX");
+            autoAliases.put("24", "chrY");
+            autoAliases.put("MT", "chrM");
+        } else if (id.startsWith("mm") || id.startsWith("rheMac")) {
+            autoAliases.put("21", "chrX");
+            autoAliases.put("22", "chrY");
+            autoAliases.put("MT", "chrM");
+        } else if (id.equals("b37")) {
+            autoAliases.put("chrM", "MT");
+            autoAliases.put("chrX", "23");
+            autoAliases.put("chrY", "24");
+        }
 
-            // These are legacy mappings,  these are now defined in the genomes alias file
-            if (id.startsWith("hg") || id.equalsIgnoreCase("1kg_ref"))
-
-            {
-                autoAliases.put("23", "chrX");
-                autoAliases.put("24", "chrY");
-                autoAliases.put("MT", "chrM");
-            } else if (id.startsWith("mm"))
-
-            {
-                autoAliases.put("21", "chrX");
-                autoAliases.put("22", "chrY");
-                autoAliases.put("MT", "chrM");
-            } else if (id.equals("b37"))
-
-            {
-                autoAliases.put("chrM", "MT");
-                autoAliases.put("chrX", "23");
-                autoAliases.put("chrY", "24");
-
+        Collection<Map.Entry<String, String>> aliasEntries = new ArrayList(autoAliases.entrySet());
+        for (Map.Entry<String, String> aliasEntry : aliasEntries) {
+            // Illumina conventions
+            String alias = aliasEntry.getKey();
+            String chr = aliasEntry.getValue();
+            if (!alias.endsWith(".fa")) {
+                String illuminaName = alias + ".fa";
+                autoAliases.put(illuminaName, chr);
             }
-
-            Collection<Map.Entry<String, String>> aliasEntries = new ArrayList(autoAliases.entrySet());
-            for (Map.Entry<String, String> aliasEntry : aliasEntries) {
-                // Illumina conventions
-                String alias = aliasEntry.getKey();
-                String chr = aliasEntry.getValue();
-                if (!alias.endsWith(".fa")) {
-                    String illuminaName = alias + ".fa";
-                    autoAliases.put(illuminaName, chr);
-                }
-                if (!chr.endsWith(".fa")) {
-                    String illuminaName = chr + ".fa";
-                    autoAliases.put(illuminaName, chr);
-                }
+            if (!chr.endsWith(".fa")) {
+                String illuminaName = chr + ".fa";
+                autoAliases.put(illuminaName, chr);
             }
         }
+
         return autoAliases;
     }
+
     /**
      * Extract the user friendly name from an NCBI accession
      * example: gi|125745044|ref|NC_002229.3|  =>  NC_002229.3
@@ -364,18 +376,18 @@ public class Genome {
         return new ChromosomeCoordinate(c, bp);
     }
 
-    /**
-     * Method description
-     *
-     * @return
-     */
+
     public String getId() {
         return id;
     }
 
+    public String getUCSCId() {
+        return ucscID == null ? id : ucscID;
+    }
+
     public String getSpecies() {
         if (species == null) {
-            species = Genome.getSpeciesForID(id);
+            species = Genome.getSpeciesForID(getUCSCId());
         }
         return species;
     }
@@ -410,7 +422,13 @@ public class Genome {
      * @return sequence, or null if not available
      * @api
      */
+
     public byte[] getSequence(String chr, int start, int end) {
+        return getSequence(chr, start, end, true);
+    }
+
+    public byte[] getSequence(String chr, int start, int end, boolean useCache) {
+
 
         if (sequence == null) {
             return null;
@@ -424,7 +442,15 @@ public class Genome {
         if (end <= start) {
             return null;
         }
-        return sequence.getSequence(chr, start, end);
+        return sequence.getSequence(chr, start, end, useCache);
+    }
+
+    public boolean sequenceIsRemote() {
+        return sequence.isRemote();
+    }
+
+    public boolean sequenceIsFasta() {
+        return sequence.isFasta();
     }
 
     public String getDisplayName() {
@@ -520,8 +546,7 @@ public class Genome {
     }
 
 
-    // TODO A hack (
-    // obviously),  we need to record a species in the genome definitions
+    // TODO A hack (obviously),  we need to record a species in the genome definitions
     private static Map<String, String> ucscSpeciesMap;
 
     private static synchronized String getSpeciesForID(String id) {
@@ -537,7 +562,7 @@ public class Genome {
                 String nextLine;
                 while ((nextLine = br.readLine()) != null) {
                     if (nextLine.startsWith("#")) continue;
-                    String[] tokens = Globals.whitespacePattern.split(nextLine);
+                    String[] tokens = Globals.tabPattern.split(nextLine);
                     if (tokens.length == 2) {
                         ucscSpeciesMap.put(tokens[0], tokens[1]);
                     } else {
@@ -564,5 +589,26 @@ public class Genome {
         return null;
     }
 
+    // Map some common IGV genome IDs to UCSC equivalents.  Primarily for BLAT usage
+    private static Map<String, String> ucsdIDMap;
 
+    static {
+        ucsdIDMap = new HashMap<>();
+        ucsdIDMap.put("1kg_ref", "hg18");
+        ucsdIDMap.put("1kg_v37", "hg19");
+        ucsdIDMap.put("b37", "hg19");
+    }
+
+
+    public boolean sequenceIsLoaded(ReferenceFrame frame) {
+        return sequence.isLoaded(frame);
+    }
+
+    public void setAnnotationResources(ArrayList<ResourceLocator> annotationResources) {
+        this.annotationResources = annotationResources;
+    }
+
+    public ArrayList<ResourceLocator> getAnnotationResources() {
+        return annotationResources;
+    }
 }
