@@ -43,7 +43,6 @@ public class GenomeZipDescriptor extends GenomeDescriptor {
     private ZipFile genomeZipFile;
 
     public GenomeZipDescriptor(String name,
-                               boolean chrNamesAltered,
                                String id,
                                String cytoBandFileName,
                                String geneFileName,
@@ -51,14 +50,17 @@ public class GenomeZipDescriptor extends GenomeDescriptor {
                                String geneTrackName,
                                String sequenceLocation,
                                boolean hasCustomSequenceLocation,
+                               String compressedSequencePath,
                                ZipFile genomeZipFile,
                                Map<String, ZipEntry> zipEntries,
                                boolean chromosomesAreOrdered,
                                boolean fasta,
-                               boolean fastaDirectory,
                                String fastaFileNameString) {
-        super(name, chrNamesAltered, id, cytoBandFileName, geneFileName, chrAliasFileName, geneTrackName,
-                sequenceLocation, hasCustomSequenceLocation, chromosomesAreOrdered, fasta, fastaDirectory, fastaFileNameString);
+
+        super(name, id, cytoBandFileName, geneFileName, chrAliasFileName, geneTrackName,
+                sequenceLocation, hasCustomSequenceLocation, compressedSequencePath,
+                chromosomesAreOrdered, fasta, fastaFileNameString);
+
         this.zipEntries = zipEntries;
         this.genomeZipFile = genomeZipFile;
 
