@@ -28,6 +28,8 @@ package org.broad.igv.feature.genome;
 import htsjdk.samtools.seekablestream.SeekableStream;
 import org.apache.log4j.Logger;
 import org.broad.igv.feature.Cytoband;
+import org.broad.igv.feature.genome.fasta.FastaIndexedSequence;
+import org.broad.igv.util.FileUtils;
 import org.broad.igv.util.stream.IGVSeekableStreamFactory;
 
 import java.io.IOException;
@@ -57,7 +59,7 @@ public class IGVSequence implements Sequence {
         this.dirPath = dirPath;
     }
 
-    public byte[] getSequence(String chr, int start, int end) {
+    public byte[] getSequence(String chr, int start, int end, boolean useCache) {
 
         String fn = getChrFileName(chr);
         String seqFile = dirPath + fn;
@@ -103,6 +105,11 @@ public class IGVSequence implements Sequence {
         return chromosomeLengths.get(chrname);
     }
 
+    @Override
+    public boolean isRemote() {
+        return FileUtils.isRemote(dirPath);
+    }
+
     /**
      * Get a "legal" chromosome file name from the chr name.  This method supports "old" style .genome
      * files.
