@@ -71,14 +71,6 @@ public class GFFCodec extends AsciiFeatureCodec<Feature> {
 
     static HashSet<String> ignoredTypes = new HashSet();
 
-    static {
-        ignoredTypes.add("start_codon");
-        ignoredTypes.add("stop_codon");
-        ignoredTypes.add("Contig");
-        ignoredTypes.add("RealContig");
-        ignoredTypes.add("CDS_parts");
-    }
-
 
     private TrackProperties trackProperties = null;
     private CI.CIHashSet featuresToHide = new CI.CIHashSet();
@@ -92,17 +84,6 @@ public class GFFCodec extends AsciiFeatureCodec<Feature> {
     }
 
 
-    /**
-     * List of known "Name" fields.  Some important fields from the GFF3 spec are listed below.  Note GFF3
-     * is case sensitive, however GFF2, GTF, and other variants might not be.
-     * <p/>
-     * ID	  Indicates the ID of the feature.
-     * Name   Display name for the feature.
-     * Alias  A secondary name for the feature.
-     */
-    static String[] nameFields = {"Name", "name", "Alias", "gene", "primary_name", "locus", "alias", "systematic_id", "ID", "transcript_id"};
-
-
     public GFFCodec(Genome genome) {
         super(Feature.class);
         // Assume GFF2 until shown otherwise
@@ -197,10 +178,6 @@ public class GFFCodec extends AsciiFeatureCodec<Feature> {
                 pathLowerCase.endsWith(".gvf") || pathLowerCase.endsWith(".gtf");
     }
 
-    public BasicFeature decodeLoc(String line) {
-        return decode(line);
-    }
-
     public BasicFeature decode(String line) {
 
         if (fastaSection) {
@@ -328,7 +305,7 @@ public class GFFCodec extends AsciiFeatureCodec<Feature> {
     }
 
 
-    protected interface Helper {
+    public interface Helper {
 
         String[] getParentIds(MultiMap<String, String> attributes, String attributeString);
 
@@ -421,6 +398,13 @@ public class GFFCodec extends AsciiFeatureCodec<Feature> {
                 return id;
             }
 
+            // Try <type>_id convention
+            id = attributes.get(type + "_id");
+            if (id != null && id.length() > 0) {
+                return id;
+            }
+
+
             for (String nf : idFields) {
                 if (attributes.containsKey(nf)) {
                     String tmp = attributes.get(nf).trim();
