@@ -144,17 +144,14 @@ public class IGVBEDCodec extends UCSCCodec<BasicFeature> implements LineFeatureE
 
         if (tokenCount > 4) {
             try {
-                float score = Float.parseFloat(tokens[4]);
+                float score = tokens[4].equals(".") ? 1000 : Float.parseFloat(tokens[4]);
                 feature.setScore(score);
                 if (featureType == FeatureType.SPLICE_JUNCTION ) {
                     ((SpliceJunctionFeature) feature).setJunctionDepth((int) score);
                 }
             } catch (NumberFormatException numberFormatException) {
-
-                // Unexpected, but does not invalidate the previous values.
-                // Stop parsing the line here but keep the feature
-                // Don't log, would just slow parsing down.
-                return feature;
+                // Interpret as missing score value, set to 1000 => max value for score according to BED spec.
+                feature.setScore(1000);
             }
         }
 
@@ -256,7 +253,9 @@ public class IGVBEDCodec extends UCSCCodec<BasicFeature> implements LineFeatureE
         }
 
         tokens = Globals.whitespacePattern.split(trimLine);
-        return decode(tokens);
+        BasicFeature feature = decode(tokens);
+        feature.setRepresentation(nextLine);
+        return feature;
     }
 
 
@@ -319,6 +318,11 @@ public class IGVBEDCodec extends UCSCCodec<BasicFeature> implements LineFeatureE
      */
     public String encode(Feature feature) {
 
+        if(feature instanceof BasicFeature) {
+            String rep = ((BasicFeature) feature).getRepresentation();
+            if(rep != null) return rep;
+        }
+
         StringBuffer buffer = new StringBuffer();
 
         buffer.append(feature.getChr());
@@ -402,11 +406,38 @@ public class IGVBEDCodec extends UCSCCodec<BasicFeature> implements LineFeatureE
                     // Must continue if basicFeature has color or exons
                     java.util.List<Exon> exons = basicFeature.getExons();
 
+
+                    int thickStart, thickEnd;
                     if (basicFeature.getColor() != null || exons != null) {
+
+                        // Correct "thickStart" and "thickEnd"
+                        if(exons != null && exons.size() > 0) {
+                             thickStart = basicFeature.getEnd();   // This is not a typo
+                            for (Exon ex : exons) {
+                                if (!ex.isNonCoding()) {
+                                    thickStart = ex.getCdStart();
+                                    break;
+                                }
+                            }
+                             thickEnd = basicFeature.getStart();    // Not a typo
+                            for (int i = exons.size() - 1; i >= 0; i--) {
+                                Exon ex = exons.get(i);
+                                if (!ex.isNonCoding()) {
+                                    thickEnd = ex.getCdEnd();
+                                    break;
+                                }
+                            }
+                        }
+                        else {
+                            thickStart = ((BasicFeature) feature).getThickStart();
+                            thickEnd = ((BasicFeature) feature).getThickEnd();
+                        }
+
+
                         buffer.append("\t");
-                        buffer.append(String.valueOf(basicFeature.getThickStart()));
+                        buffer.append(String.valueOf(thickStart));
                         buffer.append("\t");
-                        buffer.append(String.valueOf(basicFeature.getThickEnd()));
+                        buffer.append(String.valueOf(thickEnd));
                         buffer.append("\t");
 
                         java.awt.Color c = basicFeature.getColor();
