@@ -27,7 +27,9 @@ package org.broad.igv.gwas;
 
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
-import org.broad.igv.PreferenceManager;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.IGVPreferences;
+import org.broad.igv.prefs.PreferencesManager;
 
 import java.util.ArrayList;
 
@@ -56,8 +58,8 @@ public class DescriptionCache {
 
     public DescriptionCache() {
 
-        PreferenceManager prefs = PreferenceManager.getInstance();
-        this.maxSize = prefs.getAsInt(PreferenceManager.GWAS_DESCRIPTION_CACHE_SIZE);
+        IGVPreferences prefs = PreferencesManager.getPreferences();
+        this.maxSize = prefs.getAsInt(Constants.GWAS_DESCRIPTION_CACHE_SIZE);
 
     }
 
