@@ -1,21 +1,37 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 package org.broad.igv.gwas;
 
 import org.apache.log4j.Logger;
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.genome.ChromosomeCoordinate;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.genome.GenomeManager;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.IGVPreferences;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.renderer.DataRange;
 import org.broad.igv.renderer.GraphicUtils;
 import org.broad.igv.session.IGVSessionReader;
@@ -46,40 +62,49 @@ import java.util.ArrayList;
 import java.util.Collection;
 
 /**
- * Created by IntelliJ IDEA.
- * User: jussi
- * Date: Nov 23, 2009
- * Time: 4:56:40 PM
- * To change this template use File | Settings | File Templates.
+ * @author jussi
+ * @since Nov 23, 2009
  */
 @XmlType(factoryMethod = "getNextTrack")
 public class GWASTrack extends AbstractTrack {
 
     // Color properties
-    @XmlAttribute private int minPointSize;
-    @XmlAttribute private int maxPointSize;
+    @XmlAttribute
+    private int minPointSize;
+    @XmlAttribute
+    private int maxPointSize;
 
-    @XmlAttribute private boolean useChrColors;
-    @XmlAttribute private boolean singleColor;
-    @XmlAttribute private boolean alternatingColors;
+    @XmlAttribute
+    private boolean useChrColors;
+    @XmlAttribute
+    private boolean singleColor;
+    @XmlAttribute
+    private boolean alternatingColors;
 
     @XmlJavaTypeAdapter(SessionXmlAdapters.Color.class)
-    @XmlAttribute private Color primaryColor;
+    @XmlAttribute
+    private Color primaryColor;
     @XmlJavaTypeAdapter(SessionXmlAdapters.Color.class)
-    @XmlAttribute private Color secondaryColor;
+    @XmlAttribute
+    private Color secondaryColor;
 
     private GWASData gData;
     private static final Logger log = Logger.getLogger(GWASTrack.class);
 
     private static final int AXIS_AREA_WIDTH = 60;
-    @XmlAttribute private double trackMinY;
-    @XmlAttribute private double maxY;
-    @XmlAttribute private double scale;
+    @XmlAttribute
+    private double trackMinY;
+    @XmlAttribute
+    private double maxY;
+    @XmlAttribute
+    private double scale;
     private GWASParser parser;
     private static final DecimalFormat formatter = new DecimalFormat();
     //private String displayName = "GWAS Track";
-    @XmlAttribute private String displayName = null;
-    @XmlAttribute private boolean drawYAxis = true;
+    @XmlAttribute
+    private String displayName = null;
+    @XmlAttribute
+    private boolean drawYAxis = true;
     private boolean showAxis = true;
 
     String getDisplayName() {
@@ -105,25 +130,25 @@ public class GWASTrack extends AbstractTrack {
 
         super(locator, id, name);
 
-        PreferenceManager prefs = PreferenceManager.getInstance();
+        IGVPreferences prefs = PreferencesManager.getPreferences();
 
         // Set range from 0 to highest value rounded to greater integer
         int maxValue = (int) Math.ceil(gData.getMaxValue());
         super.setDataRange(new DataRange(0, (maxValue / 2), maxValue));
 
 
-        // Get defaulta values
-        super.setHeight(prefs.getAsInt(PreferenceManager.GWAS_TRACK_HEIGHT));
+        // Get default values
+        super.setHeight(prefs.getAsInt(Constants.GWAS_TRACK_HEIGHT));
 
-        this.minPointSize = prefs.getAsInt(PreferenceManager.GWAS_MIN_POINT_SIZE);
-        this.maxPointSize = prefs.getAsInt(PreferenceManager.GWAS_MAX_POINT_SIZE);
+        this.minPointSize = prefs.getAsInt(Constants.GWAS_MIN_POINT_SIZE);
+        this.maxPointSize = prefs.getAsInt(Constants.GWAS_MAX_POINT_SIZE);
 
-        this.primaryColor = ColorUtilities.stringToColor(prefs.get(PreferenceManager.GWAS_PRIMARY_COLOR));
-        this.secondaryColor = ColorUtilities.stringToColor(prefs.get(PreferenceManager.GWAS_SECONDARY_COLOR));
-        this.singleColor = prefs.getAsBoolean(PreferenceManager.GWAS_SINGLE_COLOR);
-        this.alternatingColors = prefs.getAsBoolean(PreferenceManager.GWAS_ALTERNATING_COLORS);
-        this.useChrColors = prefs.getAsBoolean(PreferenceManager.GWAS_USE_CHR_COLORS);
-        this.showAxis = prefs.getAsBoolean(PreferenceManager.GWAS_SHOW_AXIS);
+        this.primaryColor = ColorUtilities.stringToColor(prefs.get(Constants.GWAS_PRIMARY_COLOR));
+        this.secondaryColor = ColorUtilities.stringToColor(prefs.get(Constants.GWAS_SECONDARY_COLOR));
+        this.singleColor = prefs.getAsBoolean(Constants.GWAS_SINGLE_COLOR);
+        this.alternatingColors = prefs.getAsBoolean(Constants.GWAS_ALTERNATING_COLORS);
+        this.useChrColors = prefs.getAsBoolean(Constants.GWAS_USE_CHR_COLORS);
+        this.showAxis = prefs.getAsBoolean(Constants.GWAS_SHOW_AXIS);
 
         this.gData = gData;
         this.parser = parser;
@@ -131,6 +156,15 @@ public class GWASTrack extends AbstractTrack {
 
     }
 
+    @Override
+    public boolean isReadyToPaint(ReferenceFrame frame) {
+        return true;  // Track is initialized with all data
+    }
+
+    @Override
+    public void load(ReferenceFrame frame) {
+        // Nothing to do, track is initialized with all data
+    }
 
     public void render(RenderContext context, Rectangle arect) {
 
@@ -301,14 +335,14 @@ public class GWASTrack extends AbstractTrack {
 
         Rectangle drawingRect = calculateDrawingRect(arect);
 
-        Color labelColor = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.CHART_COLOR_TRACK_NAME) ? getColor() : Color.black;
+        Color labelColor = PreferencesManager.getPreferences().getAsBoolean(Constants.CHART_COLOR_TRACK_NAME) ? getColor() : Color.black;
         Graphics2D labelGraphics = context.getGraphic2DForColor(labelColor);
         //Graphics2D labelGraphics = context.getGraphic2DForColor(Color.black);
 
         labelGraphics.setFont(FontManager.getFont(8));
 
         String tmpDisplayName = this.getDisplayName();
-        if (tmpDisplayName != null && tmpDisplayName.length() > 0 && PreferenceManager.getInstance().getAsBoolean(PreferenceManager.CHART_DRAW_TRACK_NAME)) {
+        if (tmpDisplayName != null && tmpDisplayName.length() > 0 && PreferencesManager.getPreferences().getAsBoolean(Constants.CHART_DRAW_TRACK_NAME)) {
             // Only attempt if track height is > 25 pixels
             if (arect.getHeight() > 25) {
                 Rectangle labelRect = new Rectangle(arect.x, arect.y + 10, arect.width, 10);
@@ -317,7 +351,7 @@ public class GWASTrack extends AbstractTrack {
             }
         }
 
-        //if (PreferenceManager.getInstance().getAsBoolean(PreferenceManager.CHART_DRAW_Y_AXIS)) {
+        //if (IGVPreferences.getInstance().getAsBoolean(IGVPreferences.CHART_DRAW_Y_AXIS)) {
         if (this.drawYAxis) {
             labelGraphics = context.getGraphic2DForColor(Color.black);
             labelGraphics.setFont(FontManager.getFont(11));
@@ -471,14 +505,14 @@ public class GWASTrack extends AbstractTrack {
 
 
         } catch (IOException e) {
-            e.printStackTrace();  //To change body of catch statement use File | Settings | File Templates.
+            log.error(e.getMessage(), e);
         }
         return textValue;
 
     }
 
 
-    public String getValueStringAt(String chr, double position, int y, ReferenceFrame frame) {
+    public String getValueStringAt(String chr, double position, int mouseX, int mouseY, ReferenceFrame frame) {
 
         int location = (int) position;
 
@@ -494,7 +528,7 @@ public class GWASTrack extends AbstractTrack {
             maxDistance = maxDistance * 1000;
         }
 
-        int index = findIndex(chr, y, location, maxDistance);
+        int index = findIndex(chr, mouseY, location, maxDistance);
 
         // If there is a data point at the given location, fetch description
         return index >= 0 ? getDescription(chr, index) : null;
@@ -525,7 +559,6 @@ public class GWASTrack extends AbstractTrack {
 
 
         popupMenu.add(TrackMenuUtils.getTrackRenameItem(tmpTracks));
-        popupMenu.add(TrackMenuUtils.getRemoveMenuItem(tmpTracks));
         popupMenu.addSeparator();
 
         popupMenu.add(TrackMenuUtils.getDataRangeItem(tmpTracks));
@@ -563,8 +596,8 @@ public class GWASTrack extends AbstractTrack {
         axisItem.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent e) {
                 showAxis = axisItem.isSelected();
-                PreferenceManager.getInstance().put(PreferenceManager.GWAS_SHOW_AXIS, String.valueOf(showAxis));
-                IGV.getInstance().repaintDataPanels();
+                PreferencesManager.getPreferences().put(Constants.GWAS_SHOW_AXIS, String.valueOf(showAxis));
+                IGV.getInstance().revalidateTrackPanels();
 
             }
         });
@@ -580,7 +613,7 @@ public class GWASTrack extends AbstractTrack {
                 useChrColors = true;
                 alternatingColors = false;
                 updateColorPreferences();
-                IGV.getInstance().repaintDataPanels();
+                IGV.getInstance().revalidateTrackPanels();
 
             }
         });
@@ -597,7 +630,7 @@ public class GWASTrack extends AbstractTrack {
                 useChrColors = false;
                 alternatingColors = true;
                 updateColorPreferences();
-                IGV.getInstance().repaintDataPanels();
+                IGV.getInstance().revalidateTrackPanels();
             }
         });
         menu.add(colorItem);
@@ -615,7 +648,7 @@ public class GWASTrack extends AbstractTrack {
                 useChrColors = false;
                 alternatingColors = false;
                 updateColorPreferences();
-                IGV.getInstance().repaintDataPanels();
+                IGV.getInstance().revalidateTrackPanels();
 
             }
         });
@@ -626,9 +659,9 @@ public class GWASTrack extends AbstractTrack {
 
 
     private void updateColorPreferences() {
-        PreferenceManager.getInstance().put(PreferenceManager.GWAS_SINGLE_COLOR, String.valueOf(singleColor));
-        PreferenceManager.getInstance().put(PreferenceManager.GWAS_USE_CHR_COLORS, String.valueOf(useChrColors));
-        PreferenceManager.getInstance().put(PreferenceManager.GWAS_ALTERNATING_COLORS, String.valueOf(alternatingColors));
+        PreferencesManager.getPreferences().put(Constants.GWAS_SINGLE_COLOR, String.valueOf(singleColor));
+        PreferencesManager.getPreferences().put(Constants.GWAS_USE_CHR_COLORS, String.valueOf(useChrColors));
+        PreferencesManager.getPreferences().put(Constants.GWAS_ALTERNATING_COLORS, String.valueOf(alternatingColors));
     }
 
 
@@ -640,8 +673,8 @@ public class GWASTrack extends AbstractTrack {
                 if (color != null) {
                     primaryColor = color;
                     String colorString = ColorUtilities.colorToString(primaryColor);
-                    PreferenceManager.getInstance().put(PreferenceManager.GWAS_PRIMARY_COLOR, colorString);
-                    IGV.getInstance().repaintDataPanels();
+                    PreferencesManager.getPreferences().put(Constants.GWAS_PRIMARY_COLOR, colorString);
+                    IGV.getInstance().revalidateTrackPanels();
                 }
             }
         });
@@ -658,8 +691,8 @@ public class GWASTrack extends AbstractTrack {
                 if (color != null) {
                     secondaryColor = color;
                     String colorString = ColorUtilities.colorToString(secondaryColor);
-                    PreferenceManager.getInstance().put(PreferenceManager.GWAS_SECONDARY_COLOR, colorString);
-                    IGV.getInstance().repaintDataPanels();
+                    PreferencesManager.getPreferences().put(Constants.GWAS_SECONDARY_COLOR, colorString);
+                    IGV.getInstance().revalidateTrackPanels();
                 }
 
             }
@@ -710,7 +743,7 @@ public class GWASTrack extends AbstractTrack {
                     }
                     this.minPointSize = value;
                     updatePointSizePreferences();
-                    IGV.getInstance().repaintDataPanels();
+                    IGV.getInstance().revalidateTrackPanels();
                 }
 
             } catch (NumberFormatException numberFormatException) {
@@ -740,7 +773,7 @@ public class GWASTrack extends AbstractTrack {
                     }
                     this.maxPointSize = value;
                     updatePointSizePreferences();
-                    IGV.getInstance().repaintDataPanels();
+                    IGV.getInstance().revalidateTrackPanels();
                 }
 
             } catch (NumberFormatException numberFormatException) {
@@ -751,8 +784,8 @@ public class GWASTrack extends AbstractTrack {
     }
 
     private void updatePointSizePreferences() {
-        PreferenceManager.getInstance().put(PreferenceManager.GWAS_MIN_POINT_SIZE, String.valueOf(minPointSize));
-        PreferenceManager.getInstance().put(PreferenceManager.GWAS_MAX_POINT_SIZE, String.valueOf(maxPointSize));
+        PreferencesManager.getPreferences().put(Constants.GWAS_MIN_POINT_SIZE, String.valueOf(minPointSize));
+        PreferencesManager.getPreferences().put(Constants.GWAS_MAX_POINT_SIZE, String.valueOf(maxPointSize));
 
 
     }
@@ -761,13 +794,8 @@ public class GWASTrack extends AbstractTrack {
         return false;  //To change body of implemented methods use File | Settings | File Templates.
     }
 
-
-    public float getRegionScore(String chr, int start, int end, int zoom, RegionScoreType type) {
-        return 0;  //To change body of implemented methods use File | Settings | File Templates.
-    }
-
     @SubtlyImportant
-    private static GWASTrack getNextTrack(){
+    private static GWASTrack getNextTrack() {
         return (GWASTrack) IGVSessionReader.getNextTrack();
     }
 }
