@@ -25,10 +25,8 @@
 
 package org.broad.igv.maf;
 
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.renderer.GraphicUtils;
 import org.broad.igv.renderer.SequenceRenderer;
-import org.broad.igv.sam.AlignmentRenderer;
 import org.broad.igv.track.RenderContext;
 import org.broad.igv.track.Track;
 import org.broad.igv.ui.FontManager;
@@ -130,11 +128,8 @@ public class MAFRenderer {
             int dY = (int) rect.getHeight();
             int dX = (int) (1.0 / locScale);
 
-            // Create a graphics to use
-            Graphics2D g = (Graphics2D) context.getGraphics().create();
-            if (PreferenceManager.getInstance().getAsBoolean(PreferenceManager.ENABLE_ANTIALISING)) {
-                g.setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
-            }
+            // Get a graphics to use
+            Graphics2D g = context.getGraphics2D("SEQUENCE");
 
             if (dX >= 8) {
                 Font f = FontManager.getFont(Font.BOLD, Math.min(dX, 12));
