@@ -27,19 +27,19 @@ package org.broad.igv.renderer;
 
 //~--- non-JDK imports --------------------------------------------------------
 
+import htsjdk.tribble.Feature;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.IExon;
 import org.broad.igv.feature.IGVFeature;
 import org.broad.igv.feature.SpliceJunctionFeature;
+import org.broad.igv.prefs.PreferencesManager;
+import org.broad.igv.sam.AlignmentDataManager;
 import org.broad.igv.sam.AlignmentInterval;
 import org.broad.igv.sam.CoverageTrack;
-import org.broad.igv.sam.IAlignmentDataManager;
 import org.broad.igv.track.RenderContext;
 import org.broad.igv.track.Track;
 import org.broad.igv.ui.FontManager;
-import htsjdk.tribble.Feature;
 
 import java.awt.*;
 import java.awt.geom.Ellipse2D;
@@ -48,6 +48,8 @@ import java.awt.geom.Rectangle2D;
 import java.util.*;
 import java.util.List;
 
+import static org.broad.igv.prefs.Constants.SASHIMI_SHOW_COVERAGE;
+
 /**
  * Renderer for splice junctions. Draws a filled-in arc for each junction, with the width of the
  * arc representing the depth of coverage. If coverage information is present for the flanking
@@ -84,7 +86,7 @@ public class SashimiJunctionRenderer extends IGVFeatureRenderer {
     private Set<IExon> selectedExons;
 
     private CoverageTrack coverageTrack = null;
-    private IAlignmentDataManager dataManager = null;
+    private AlignmentDataManager dataManager = null;
 
     private Color background;
 
@@ -110,11 +112,11 @@ public class SashimiJunctionRenderer extends IGVFeatureRenderer {
      * Set the data manager
      * @param dataManager
      */
-    public void setDataManager(IAlignmentDataManager dataManager) {
+    public void setDataManager(AlignmentDataManager dataManager) {
         this.dataManager = dataManager;
     }
 
-    public IAlignmentDataManager getDataManager(){
+    public AlignmentDataManager getDataManager(){
         return this.dataManager;
     }
 
@@ -181,7 +183,7 @@ public class SashimiJunctionRenderer extends IGVFeatureRenderer {
 
         Rectangle coverageRectangle = new Rectangle(trackRectangle);
 
-        final boolean showCoverage = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SASHIMI_SHOW_COVERAGE);
+        final boolean showCoverage = PreferencesManager.getPreferences().getAsBoolean(SASHIMI_SHOW_COVERAGE);
 
         if(coverageTrack != null && showCoverage){
             //Only want the coverage track to go so high so that the arcs still have room
@@ -202,9 +204,7 @@ public class SashimiJunctionRenderer extends IGVFeatureRenderer {
             // affecting other tracks.
             Font font = FontManager.getFont(track.getFontSize());
             Graphics2D fontGraphics = (Graphics2D) context.getGraphic2DForColor(Color.BLACK).create();
-            if (PreferenceManager.getInstance().getAsBoolean(PreferenceManager.ENABLE_ANTIALISING)) {
-                fontGraphics.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
-            }
+            fontGraphics.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
             fontGraphics.setFont(font);
 
             // Track coordinates
