@@ -105,7 +105,7 @@ public interface Alignment extends LocusScore {
      * Return an explicitly set color for this alignment, if any  (typically null).
      * @return
      */
-    Color getColor();
+    Color getYcColor();
 
     String getSample();
 
@@ -113,8 +113,12 @@ public interface Alignment extends LocusScore {
 
     String getLibrary();
 
-    String getClipboardString(double location);
+    String getClipboardString(double location, int mouseX);
 
 
     void finish();
+
+    default AlignmentBlock getInsertionAt(int position) {
+        return null;
+    }
 }
