@@ -57,7 +57,11 @@ public interface AlignmentCounts extends Feature {
 
     String getValueStringAt(int pos);
 
-    boolean isMismatch(int pos, byte ref, String chr, float snpThreshold);
+    boolean isConsensusMismatch(int pos, byte ref, String chr, float snpThreshold);
+
+    boolean isConsensusDeletion(int start, int end, float snpThreshold);
+
+    boolean isConsensusInsertion(int pos, float snpThreshold);
 
     BisulfiteCounts getBisulfiteCounts();
 
@@ -67,5 +71,4 @@ public interface AlignmentCounts extends Feature {
 
     void finish();
 
-
 }
