@@ -25,56 +25,50 @@
 
 package org.broad.igv.sam;
 
-import com.google.common.eventbus.EventBus;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
-import org.broad.igv.PreferenceManager;
+import org.broad.igv.event.RefreshEvent;
 import org.broad.igv.feature.Range;
 import org.broad.igv.feature.genome.Genome;
+import org.broad.igv.prefs.IGVPreferences;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.sam.AlignmentTrack.SortOption;
 import org.broad.igv.sam.reader.AlignmentReaderFactory;
 import org.broad.igv.track.RenderContext;
-import org.broad.igv.ui.IGV;
-import org.broad.igv.ui.event.DataLoadedEvent;
+import org.broad.igv.event.IGVEventBus;
+import org.broad.igv.event.IGVEventObserver;
+import org.broad.igv.track.Track;
 import org.broad.igv.ui.panel.FrameManager;
 import org.broad.igv.ui.panel.ReferenceFrame;
-import org.broad.igv.ui.util.ProgressMonitor;
-import org.broad.igv.util.LongRunningTask;
-import org.broad.igv.util.NamedRunnable;
 import org.broad.igv.util.ResourceLocator;
+import org.broad.igv.util.collections.IntArrayList;
 
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
 import java.io.IOException;
 import java.util.*;
 
-public class AlignmentDataManager implements IAlignmentDataManager {
+import static org.broad.igv.prefs.Constants.*;
+
+/**
+ * Manages data loading for a single alignment file.  Shared between alignment, coverage, and junction
+ * tracks.
+ */
+
+public class AlignmentDataManager implements IGVEventObserver {
 
     private static Logger log = Logger.getLogger(AlignmentDataManager.class);
 
-    /**
-     * Caches for loaded alignments and the relevant packing
-     */
-    private PositionCache<AlignmentInterval> loadedIntervalCache = new PositionCache<AlignmentInterval>();
-    private PositionCache<PackedAlignments> packedAlignmentsCache = new PositionCache<PackedAlignments>();
 
+    private List<AlignmentInterval> intervalCache;
     private ResourceLocator locator;
     private HashMap<String, String> chrMappings = new HashMap();
-    private volatile boolean isLoading = false;
+    private Set<Range> isLoading = new HashSet<>();
     private AlignmentTileLoader reader;
     private CoverageTrack coverageTrack;
     private Map<String, PEStats> peStats;
-    private AlignmentTrack.ExperimentType experimentType;
     private SpliceJunctionHelper.LoadOptions loadOptions;
     private Object loadLock = new Object();
-    private boolean showAlignments = true;
-
-    /**
-     * This {@code EventBus} is typically used to notify listeners when new data
-     * is loaded
-     */
-    private EventBus eventBus = new EventBus();
-
+    private AlignmentTrack.ExperimentType inferredExperimentType;
+    private Set<Track> subscribedTracks;
 
     public AlignmentDataManager(ResourceLocator locator, Genome genome) throws IOException {
         this.locator = locator;
@@ -82,6 +76,34 @@ public class AlignmentDataManager implements IAlignmentDataManager {
         peStats = new HashMap();
         initLoadOptions();
         initChrMap(genome);
+        intervalCache = Collections.synchronizedList(new ArrayList<>());
+        subscribedTracks = Collections.synchronizedSet(new HashSet<>());
+
+        IGVEventBus.getInstance().subscribe(FrameManager.ChangeEvent.class, this);
+        IGVEventBus.getInstance().subscribe(RefreshEvent.class, this);
+    }
+
+    public void receiveEvent(Object event) {
+
+        if (event instanceof FrameManager.ChangeEvent) {
+            trimCache();
+        } else if (event instanceof RefreshEvent) {
+            clear();
+        } else {
+            log.info("Unknown event type: " + event.getClass());
+        }
+    }
+
+    public void subscribe(Track track) {
+        subscribedTracks.add(track);
+    }
+
+    public void unsubscribe(Track track) {
+        subscribedTracks.remove(track);
+        if (subscribedTracks.isEmpty()) {
+            dumpAlignments();
+            IGVEventBus.getInstance().unsubscribe(this);
+        }
     }
 
     void initLoadOptions() {
@@ -104,14 +126,6 @@ public class AlignmentDataManager implements IAlignmentDataManager {
         }
     }
 
-    public void setExperimentType(AlignmentTrack.ExperimentType experimentType) {
-        this.experimentType = experimentType;
-    }
-
-    public AlignmentTrack.ExperimentType getExperimentType() {
-        return experimentType;
-    }
-
     public AlignmentTileLoader getReader() {
         return reader;
     }
@@ -128,10 +142,22 @@ public class AlignmentDataManager implements IAlignmentDataManager {
         return reader.isPairedEnd();
     }
 
+    public boolean hasYCTags() {
+        return reader.hasYCTags();
+    }
+
     public boolean hasIndex() {
         return reader.hasIndex();
     }
 
+    public void setInferredExperimentType(AlignmentTrack.ExperimentType inferredExperimentType) {
+        if (inferredExperimentType != this.inferredExperimentType) {
+            ExperimentTypeChangeEvent event = new ExperimentTypeChangeEvent(this, inferredExperimentType);
+            this.inferredExperimentType = inferredExperimentType;
+            IGVEventBus.getInstance().post(event);
+        }
+    }
+
     public void setCoverageTrack(CoverageTrack coverageTrack) {
         this.coverageTrack = coverageTrack;
     }
@@ -141,8 +167,8 @@ public class AlignmentDataManager implements IAlignmentDataManager {
     }
 
     public double getMinVisibleScale() {
-        PreferenceManager prefs = PreferenceManager.getInstance();
-        float maxRange = prefs.getAsFloat(PreferenceManager.SAM_MAX_VISIBLE_RANGE);
+        IGVPreferences prefs = PreferencesManager.getPreferences();
+        float maxRange = prefs.getAsFloat(SAM_MAX_VISIBLE_RANGE);
         return (maxRange * 1000) / 700;
     }
 
@@ -158,20 +184,15 @@ public class AlignmentDataManager implements IAlignmentDataManager {
     }
 
 
-    public boolean isIonTorrent() {
-        Set<String> platforms = reader.getPlatforms();
-        if (platforms != null) {
-            return platforms.contains("IONTORRENT");
+    public AlignmentInterval getLoadedInterval(ReferenceFrame frame) {
+
+        for (AlignmentInterval interval : intervalCache) {
+            if (interval.contains(frame.getCurrentRange())) {
+                return interval;
+            }
         }
-        return false;
-    }
 
-    public Collection<AlignmentInterval> getLoadedIntervals() {
-        return this.loadedIntervalCache.values();
-    }
-
-    public AlignmentInterval getLoadedInterval(Range range) {
-        return loadedIntervalCache.getForRange(range);
+        return null;
     }
 
     /**
@@ -181,19 +202,24 @@ public class AlignmentDataManager implements IAlignmentDataManager {
      * @param location
      */
     public boolean sortRows(SortOption option, ReferenceFrame frame, double location, String tag) {
-        PackedAlignments packedAlignments = packedAlignmentsCache.getForRange(frame.getCurrentRange());
-        AlignmentInterval interval = loadedIntervalCache.getForRange(frame.getCurrentRange());
-        if (packedAlignments == null || interval == null) {
-            return false;
-        }
 
-        for (List<Row> alignmentRows : packedAlignments.values()) {
-            for (Row row : alignmentRows) {
-                row.updateScore(option, location, interval, tag);
+        AlignmentInterval interval = getLoadedInterval(frame);
+        if (interval == null) {
+            return false;
+        } else {
+            PackedAlignments packedAlignments = interval.getPackedAlignments();
+            if (packedAlignments == null) {
+                return false;
             }
-            Collections.sort(alignmentRows);
+
+            for (List<Row> alignmentRows : packedAlignments.values()) {
+                for (Row row : alignmentRows) {
+                    row.updateScore(option, location, interval, tag);
+                }
+                Collections.sort(alignmentRows);
+            }
+            return true;
         }
-        return true;
     }
 
     public void setViewAsPairs(boolean option, AlignmentTrack.RenderOptions renderOptions) {
@@ -201,7 +227,6 @@ public class AlignmentDataManager implements IAlignmentDataManager {
             return;
         }
         renderOptions.setViewPairs(option);
-
         packAlignments(renderOptions);
     }
 
@@ -212,121 +237,95 @@ public class AlignmentDataManager implements IAlignmentDataManager {
      * @param renderOptions
      * @return Whether repacking was performed
      */
-    boolean packAlignments(AlignmentTrack.RenderOptions renderOptions) {
-
-        List<ReferenceFrame> frameList = FrameManager.getFrames();
-        List<AlignmentInterval> intervalList = new ArrayList<AlignmentInterval>(frameList.size());
-
-        this.packedAlignmentsCache.clear();
-        this.packedAlignmentsCache.setMaxEntries(2 * intervalList.size());
-
-        for (ReferenceFrame frame : frameList) {
-            AlignmentInterval interval = loadedIntervalCache.getForRange(frame.getCurrentRange());
-
-            if (interval == null) {
-                return false;
-            }
-
-            final AlignmentPacker alignmentPacker = new AlignmentPacker();
-            PackedAlignments packedAlignments = alignmentPacker.packAlignments(interval, renderOptions);
-
-            //We cache by the interval range because this will generally be buffered/expanded, whereas the frame
-            //will be to-the-pixel (meaning a slight scroll triggers a repack
-
-            this.packedAlignmentsCache.put(interval.getRange(), packedAlignments);
+    void packAlignments(AlignmentTrack.RenderOptions renderOptions) {
+        for (AlignmentInterval interval : intervalCache) {
+            interval.packAlignments(renderOptions);
         }
-
-        return true;
     }
 
+
+    public boolean isLoaded(ReferenceFrame frame) {
+        return getLoadedInterval(frame) != null;
+    }
+
+    public boolean isLoading(ReferenceFrame frame) {
+
+        Range range = frame.getCurrentRange();
+        for (Range r : isLoading) {
+            if (r.contains(range)) return true;
+        }
+        return false;
+    }
+
+
     public void load(ReferenceFrame referenceFrame,
                      AlignmentTrack.RenderOptions renderOptions,
                      boolean expandEnds) {
 
-        synchronized (loadLock) {
-            final String chr = referenceFrame.getChrName();
-            final int start = (int) referenceFrame.getOrigin();
-            final int end = (int) referenceFrame.getEnd();
-            AlignmentInterval loadedInterval = loadedIntervalCache.getForRange(referenceFrame.getCurrentRange());
+        if (isLoaded(referenceFrame)) return;  // Already loaded
 
+        if (isLoading(referenceFrame)) return;   // Already oading
+
+        synchronized (loadLock) {
+            Range range = referenceFrame.getCurrentRange();
+
+            isLoading.add(range);
+
+            final String chr = referenceFrame.getChrName();
+
+            final int start = (int) range.getStart();
+            final int end = (int) range.getEnd();
             int adjustedStart = start;
             int adjustedEnd = end;
+
             // Expand the interval by the lesser of  +/- a 2 screens, or max visible range
-            int windowSize = Math.min(4 * (end - start), PreferenceManager.getInstance().getAsInt(PreferenceManager.SAM_MAX_VISIBLE_RANGE) * 1000);
+            int windowSize = Math.min(4 * (end - start), PreferencesManager.getPreferences().getAsInt(SAM_MAX_VISIBLE_RANGE) * 1000);
             int center = (end + start) / 2;
             int expand = Math.max(end - start, windowSize / 2);
 
-            if (loadedInterval != null) {
-                // First see if we have a loaded interval that fully contain the requested interval.
-                // If so, we don't need to load it
-                if (loadedInterval.contains(chr, start, end)) {
-                    return;
-                }
-            }
-
             if (expandEnds) {
                 adjustedStart = Math.max(0, Math.min(start, center - expand));
                 adjustedEnd = Math.max(end, center + expand);
             }
-            loadAlignments(chr, adjustedStart, adjustedEnd, renderOptions, referenceFrame);
-        }
 
-    }
 
-    public synchronized PackedAlignments getGroups(RenderContext context, AlignmentTrack.RenderOptions renderOptions) {
-        load(context.getReferenceFrame(), renderOptions, false);
-        Range range = context.getReferenceFrame().getCurrentRange();
-        if (!packedAlignmentsCache.containsRange(range)) {
+            log.debug("Loading alignments: " + chr + ":" + adjustedStart + "-" + adjustedEnd + " for " + AlignmentDataManager.this);
+
+
+            AlignmentInterval loadedInterval = loadInterval(chr, adjustedStart, adjustedEnd, renderOptions);
+
+            trimCache();
+
+            intervalCache.add(loadedInterval);
+
             packAlignments(renderOptions);
-        }
-        return packedAlignmentsCache.getForRange(context.getReferenceFrame().getCurrentRange());
-    }
+            isLoading.remove(range);
 
-    public void clear() {
-        // reader.clearCache();
-        loadedIntervalCache.clear();
-        packedAlignmentsCache.clear();
-    }
+            //  IGVEventBus.getInstance().post(new DataLoadedEvent(referenceFrame));
 
-    public void dumpAlignments() {
-        packedAlignmentsCache.clear();
-        for (AlignmentInterval interval : loadedIntervalCache.values()) {
-            interval.dumpAlignments();
         }
     }
 
-    public synchronized void loadAlignments(final String chr, final int start, final int end,
-                                            final AlignmentTrack.RenderOptions renderOptions,
-                                            final ReferenceFrame frame) {
 
-        if (isLoading || chr.equals(Globals.CHR_ALL)) {
-            return;
-        }
-        loadedIntervalCache.setMaxEntries(2 * FrameManager.getFrames().size());
-        isLoading = true;
+    /**
+     * Remove out-of-view intervals from the cache.  This is O(N) where N = #frames X #intervals.   It is assumed
+     * that N is small
+     */
+    private synchronized void trimCache() {
 
-        NamedRunnable runnable = new NamedRunnable() {
-
-            public String getName() {
-                return "loadAlignments";
+       Iterator<AlignmentInterval> iter =  intervalCache.iterator();
+        while(iter.hasNext()) {
+            AlignmentInterval interval = iter.next();
+            for (ReferenceFrame frame : FrameManager.getFrames()) {
+                if (!interval.contains(frame.getCurrentRange())) {
+                    iter.remove();
+                }
             }
 
-            public void run() {
-
-                log.debug("Loading alignments: " + chr + ":" + start + "-" + end + " for " + AlignmentDataManager.this);
-
-                AlignmentInterval loadedInterval = loadInterval(chr, start, end, renderOptions);
-                loadedIntervalCache.put(loadedInterval.getRange(), loadedInterval);
-
-                packAlignments(renderOptions);
-                getEventBus().post(new DataLoadedEvent(frame));
-
-                isLoading = false;
-            }
-        };
-        LongRunningTask.submit(runnable);
+        }
     }
 
+
     AlignmentInterval loadInterval(String chr, int start, int end, AlignmentTrack.RenderOptions renderOptions) {
 
         String sequence = chrMappings.containsKey(chr) ? chrMappings.get(chr) : chr;
@@ -336,27 +335,62 @@ public class AlignmentDataManager implements IAlignmentDataManager {
         final AlignmentTrack.BisulfiteContext bisulfiteContext =
                 renderOptions != null ? renderOptions.bisulfiteContext : null;
 
-        ProgressMonitor monitor = null;
-        //Show cancel button
-        if (IGV.hasInstance() && !Globals.isBatch() && !Globals.isHeadless()) {
-            ActionListener cancelListener = new ActionListener() {
-                @Override
-                public void actionPerformed(ActionEvent e) {
-                    AlignmentTileLoader.cancelReaders();
-                }
-            };
-            IGV.getInstance().getContentPane().getStatusBar().activateCancelButton(cancelListener);
-        }
-
         SpliceJunctionHelper spliceJunctionHelper = new SpliceJunctionHelper(this.loadOptions);
+
+        ReadStats readStats = new ReadStats();
+
         AlignmentTileLoader.AlignmentTile t = reader.loadTile(sequence, start, end, spliceJunctionHelper,
-                downsampleOptions, peStats, bisulfiteContext, showAlignments, monitor);
+                downsampleOptions, readStats, peStats, bisulfiteContext);
+//
+        if (inferredExperimentType == null && !Globals.VERSION.contains("2.4")) {
+            readStats.compute();
+            inferType(readStats);
+        }
 
         List<Alignment> alignments = t.getAlignments();
         List<DownsampledInterval> downsampledIntervals = t.getDownsampledIntervals();
         return new AlignmentInterval(chr, start, end, alignments, t.getCounts(), spliceJunctionHelper, downsampledIntervals);
     }
 
+    /**
+     * Some empirical metrics for determining experiment type
+     *
+     * @param readStats
+     */
+    private void inferType(ReadStats readStats) {
+
+        if (readStats.readLengthStdDev > 100 || readStats.medianReadLength > 1000) {
+            setInferredExperimentType(AlignmentTrack.ExperimentType.THIRD_GEN);  // Could also use fracReadsWithIndels
+        } else if (readStats.medianRefToReadRatio > 10) {
+            setInferredExperimentType(AlignmentTrack.ExperimentType.RNA);
+        } else {
+            setInferredExperimentType(AlignmentTrack.ExperimentType.OTHER);
+        }
+    }
+
+
+    public synchronized PackedAlignments getGroups(RenderContext context, AlignmentTrack.RenderOptions renderOptions) {
+        //   load(context.getReferenceFrame(), renderOptions, false);
+        //   Range range = context.getReferenceFrame().getCurrentRange();
+
+        AlignmentInterval interval = getLoadedInterval(context.getReferenceFrame());
+        if (interval != null) {
+            return interval.getPackedAlignments();
+        } else {
+            return null;
+        }
+    }
+
+    public void clear() {
+        intervalCache.clear();
+    }
+
+    public void dumpAlignments() {
+        for (AlignmentInterval interval : intervalCache) {
+            interval.dumpAlignments();
+        }
+    }
+
     /**
      * Find the first loaded interval for the specified chromosome and genomic {@code positon},
      * return the grouped alignments
@@ -370,18 +404,28 @@ public class AlignmentDataManager implements IAlignmentDataManager {
         int start = (int) position;
         int end = start + 1;
 
-        PackedAlignments packedAlignments = packedAlignmentsCache.getForRange(referenceFrame.getCurrentRange());
-        if (packedAlignments != null && packedAlignments.contains(chr, start, end)) {
-            return packedAlignments;
+        AlignmentInterval interval = getLoadedInterval(referenceFrame);
+        if (interval == null) {
+            return null;
+        } else {
+            PackedAlignments packedAlignments = interval.getPackedAlignments();
+            if (packedAlignments != null && packedAlignments.contains(chr, start, end)) {
+                return packedAlignments;
+            } else {
+                return null;
+            }
         }
-        return null;
     }
 
     public int getNLevels() {
         int nLevels = 0;
-        for (PackedAlignments packedAlignments : packedAlignmentsCache.values()) {
-            int intervalNLevels = packedAlignments.getNLevels();
-            nLevels = Math.max(nLevels, intervalNLevels);
+
+        for (AlignmentInterval interval : intervalCache) {
+            PackedAlignments packedAlignments = interval.getPackedAlignments();
+            if (packedAlignments != null) {
+                int intervalNLevels = packedAlignments.getNLevels();
+                nLevels = Math.max(nLevels, intervalNLevels);
+            }
         }
         return nLevels;
     }
@@ -392,10 +436,15 @@ public class AlignmentDataManager implements IAlignmentDataManager {
      */
     public int getMaxGroupCount() {
         int groupCount = 0;
-        for (PackedAlignments packedAlignments : packedAlignmentsCache.values()) {
-            groupCount = Math.max(groupCount, packedAlignments.size());
-        }
 
+        for (AlignmentInterval interval : intervalCache) {
+            if (interval != null) {  // Not sure how this happens but it does
+                PackedAlignments packedAlignments = interval.getPackedAlignments();
+                if (packedAlignments != null) {
+                    groupCount = Math.max(groupCount, packedAlignments.size());
+                }
+            }
+        }
         return groupCount;
     }
 
@@ -420,44 +469,48 @@ public class AlignmentDataManager implements IAlignmentDataManager {
         }
     }
 
-    public EventBus getEventBus() {
-        return eventBus;
-    }
-
     public SpliceJunctionHelper.LoadOptions getSpliceJunctionLoadOptions() {
         return loadOptions;
     }
 
     public void setMinJunctionCoverage(int minJunctionCoverage) {
         this.loadOptions = new SpliceJunctionHelper.LoadOptions(minJunctionCoverage, this.loadOptions.minReadFlankingWidth);
-        for (AlignmentInterval interval : getLoadedIntervals()) {
+        for (AlignmentInterval interval : intervalCache) {
             interval.getSpliceJunctionHelper().setLoadOptions(this.loadOptions);
         }
     }
 
-    PositionCache getCache() {
-        return this.loadedIntervalCache;
-    }
-
     public void alleleThresholdChanged() {
-        coverageTrack.setSnpThreshold(PreferenceManager.getInstance().getAsFloat(PreferenceManager.SAM_ALLELE_THRESHOLD));
+        coverageTrack.setSnpThreshold(PreferencesManager.getPreferences().getAsFloat(SAM_ALLELE_THRESHOLD));
     }
 
-    public void setShowAlignments(boolean showAlignments) {
-        this.showAlignments = showAlignments;
-        clear();
+    public boolean isTenX() {
+        return reader.isTenX();
     }
 
+    public boolean isPhased() {
+        return reader.isPhased();
+    }
+
+    public boolean isMoleculo() {
+        return reader.isMoleculo();
+    }
+
+    public Collection<AlignmentInterval> getLoadedIntervals() {
+        return intervalCache;
+    }
+
+
     public static class DownsampleOptions {
         private boolean downsample;
         private int sampleWindowSize;
         private int maxReadCount;
 
         public DownsampleOptions() {
-            PreferenceManager prefs = PreferenceManager.getInstance();
-            init(prefs.getAsBoolean(PreferenceManager.SAM_DOWNSAMPLE_READS),
-                    prefs.getAsInt(PreferenceManager.SAM_SAMPLING_WINDOW),
-                    prefs.getAsInt(PreferenceManager.SAM_SAMPLING_COUNT));
+            IGVPreferences prefs = PreferencesManager.getPreferences();
+            init(prefs.getAsBoolean(SAM_DOWNSAMPLE_READS),
+                    prefs.getAsInt(SAM_SAMPLING_WINDOW),
+                    prefs.getAsInt(SAM_SAMPLING_COUNT));
         }
 
         DownsampleOptions(boolean downsample, int sampleWindowSize, int maxReadCount) {
@@ -483,5 +536,72 @@ public class AlignmentDataManager implements IAlignmentDataManager {
         }
 
     }
+
+    static class IntervalCache {
+
+        private int maxSize;
+        ArrayList<AlignmentInterval> intervals;
+
+        public IntervalCache() {
+            this(1);
+        }
+
+        public IntervalCache(int ms) {
+            this.maxSize = Math.max(1, ms);
+            intervals = new ArrayList<>(maxSize);
+        }
+
+        void setMaxSize(int ms, List<ReferenceFrame> frames) {
+            this.maxSize = Math.max(1, ms);
+            if (intervals.size() > maxSize) {
+                // Reduce size.  Try to keep intervals that cover frame ranges.  This involves a linear search
+                // of potentially (intervals.size X frames.size) elements.  Don't attempt if this number is too large
+                if (frames.size() * intervals.size() < 25) {
+                    ArrayList<AlignmentInterval> tmp = new ArrayList<>(maxSize);
+                    for (AlignmentInterval interval : intervals) {
+                        if (tmp.size() == maxSize) break;
+                        for (ReferenceFrame frame : frames) {
+                            Range range = frame.getCurrentRange();
+                            if (interval.contains(range.getChr(), range.getStart(), range.getEnd())) {
+                                tmp.add(interval);
+                                break;
+                            }
+                        }
+                    }
+                    intervals = tmp;
+                } else {
+                    intervals = new ArrayList(intervals.subList(0, maxSize));
+                    intervals.trimToSize();
+                }
+            }
+        }
+
+        public void add(AlignmentInterval interval) {
+            if (intervals.size() >= maxSize) {
+                intervals.remove(0);
+            }
+            intervals.add(interval);
+        }
+
+        public AlignmentInterval getIntervalForRange(Range range) {
+
+            for (AlignmentInterval interval : intervals) {
+                if (interval.contains(range.getChr(), range.getStart(), range.getEnd())) {
+                    return interval;
+                }
+            }
+
+            return null;
+
+        }
+
+        public Collection<AlignmentInterval> values() {
+            return intervals;
+        }
+
+        public void clear() {
+            intervals.clear();
+        }
+    }
 }
 
