@@ -29,8 +29,6 @@
  */
 package org.broad.igv.sam;
 
-import com.google.common.collect.HashBasedTable;
-import com.google.common.collect.Table;
 import org.apache.log4j.Logger;
 import org.broad.igv.feature.Range;
 import org.broad.igv.feature.Strand;
@@ -49,7 +47,7 @@ public class AlignmentPacker {
     /**
      * Minimum gap between the end of one alignment and start of another.
      */
-    public static final int MIN_ALIGNMENT_SPACING = 5;
+    public static final int MIN_ALIGNMENT_SPACING = 2;
     private static final Comparator<Alignment> lengthComparator = new Comparator<Alignment>() {
         public int compare(Alignment row1, Alignment row2) {
             return (row2.getEnd() - row2.getStart()) -
@@ -58,9 +56,7 @@ public class AlignmentPacker {
         }
     };
 
-    private static final String NULL_GROUP_VALUE = "Because google-guava tables don't support a null key, we use a special value" +
-            " for null keys. It doesn't matter much what it is, but we want to avoid collisions. I find it unlikely that " +
-            " this sentence will ever be used as a group value";
+    private static final String NULL_GROUP_VALUE = "";
     public static final int tenMB = 10000000;
 
     /**
@@ -70,22 +66,23 @@ public class AlignmentPacker {
             AlignmentInterval interval,
             AlignmentTrack.RenderOptions renderOptions) {
 
-        if (renderOptions == null) renderOptions = new AlignmentTrack.RenderOptions();
-
         LinkedHashMap<String, List<Row>> packedAlignments = new LinkedHashMap<String, List<Row>>();
 
-        boolean isPairedAlignments = renderOptions.isViewPairs() || renderOptions.isPairedArcView();
+        List<Alignment> alList = interval.getAlignments();
+        // TODO -- means to undo this
+        if (renderOptions.isLinkedReads()) {
+            alList = linkByTag(alList, renderOptions.getLinkByTag());
+        }
 
-
-        if (renderOptions.groupByOption == null) {
-            List<Row> alignmentRows = new ArrayList<Row>(10000);
-            pack(interval.getAlignments(), isPairedAlignments, alignmentRows);
+        if (renderOptions.getGroupByOption() == null) {
+            List<Row> alignmentRows = new ArrayList<>(10000);
+            pack(alList, renderOptions, alignmentRows);
             packedAlignments.put("", alignmentRows);
         } else {
 
             // Separate alignments into groups.
             Map<String, List<Alignment>> groupedAlignments = new HashMap<String, List<Alignment>>();
-            Iterator<Alignment> iter = interval.getAlignmentIterator();
+            Iterator<Alignment> iter = alList.iterator();
             while (iter.hasNext()) {
                 Alignment alignment = iter.next();
                 String groupKey = getGroupValue(alignment, renderOptions);
@@ -94,31 +91,24 @@ public class AlignmentPacker {
                 }
                 List<Alignment> groupList = groupedAlignments.get(groupKey);
                 if (groupList == null) {
-                    groupList = new ArrayList<Alignment>(1000);
+                    groupList = new ArrayList<>(1000);
                     groupedAlignments.put(groupKey, groupList);
                 }
                 groupList.add(alignment);
             }
 
 
-            // Now alphabetize (sort) and packGroup the groups
+            // Now alphabetize (sort) and pack the groups
             List<String> keys = new ArrayList<String>(groupedAlignments.keySet());
-            Comparator<String> groupComparator = getGroupComparator(renderOptions.groupByOption);
+            Comparator<String> groupComparator = getGroupComparator(renderOptions.getGroupByOption());
             Collections.sort(keys, groupComparator);
 
             for (String key : keys) {
-                if (key.equals(NULL_GROUP_VALUE)) continue;
-                List<Row> alignmentRows = new ArrayList<Row>(10000);
+                List<Row> alignmentRows = new ArrayList<>(10000);
                 List<Alignment> group = groupedAlignments.get(key);
-                pack(group, isPairedAlignments, alignmentRows);
+                pack(group, renderOptions, alignmentRows);
                 packedAlignments.put(key, alignmentRows);
             }
-
-            //Put null valued group at end
-            List<Row> alignmentRows = new ArrayList<Row>(10000);
-            List<Alignment> group = groupedAlignments.get(NULL_GROUP_VALUE);
-            pack(group, isPairedAlignments, alignmentRows);
-            packedAlignments.put("", alignmentRows);
         }
 
         List<AlignmentInterval> tmp = new ArrayList<AlignmentInterval>();
@@ -127,13 +117,18 @@ public class AlignmentPacker {
     }
 
 
-    private void pack(List<Alignment> alList, boolean pairAlignments, List<Row> alignmentRows) {
+    private void pack(List<Alignment> alList, AlignmentTrack.RenderOptions renderOptions, List<Row> alignmentRows) {
 
         Map<String, PairedAlignment> pairs = null;
-        if (pairAlignments) {
-            pairs = new HashMap<String, PairedAlignment>(1000);
+
+        boolean isPairedAlignments = renderOptions.isViewPairs();
+        String linkByTag = renderOptions.getLinkByTag();
+
+        if (isPairedAlignments) {
+            pairs = new HashMap<>(1000);
         }
 
+
         // Allocate alignemnts to buckets for each range.
         // We use priority queues to keep the buckets sorted by alignment length.  However this  is probably a needless
         // complication,  any collection type would do.
@@ -156,17 +151,14 @@ public class AlignmentPacker {
             bucketCollection = new SparseBucketCollection(curRange);
         }
 
-
         int curRangeStart = curRange.getStart();
         for (Alignment al : alList) {
 
             if (al.isMapped()) {
                 Alignment alignment = al;
-                if (pairAlignments &&
-                        al.isPaired() &&
-                        al.isPrimary() &&
-                        al.getMate().isMapped() &&
-                        al.getMate().getChr().equals(al.getChr())) {
+
+                // Pair alignments -- do not pair secondaryalignments
+                if (isPairedAlignments && isPairable(al)) {
                     String readName = al.getReadName();
                     PairedAlignment pair = pairs.get(readName);
                     if (pair == null) {
@@ -182,6 +174,7 @@ public class AlignmentPacker {
                     }
                 }
 
+                // Allocate to bucket.
                 // Negative "bucketNumbers" can arise with soft clips at the left edge of the chromosome. Allocate
                 // these alignments to the first bucket.
                 int bucketNumber = Math.max(0, al.getStart() - curRangeStart);
@@ -208,7 +201,6 @@ public class AlignmentPacker {
 
         while (allocatedCount < totalCount) {
 
-
             curRange = bucketCollection.getRange();
 
             curRangeStart = curRange.getStart();
@@ -259,6 +251,71 @@ public class AlignmentPacker {
 
     }
 
+    private boolean isPairable(Alignment al) {
+        return al.isPrimary() &&
+                al.isPaired() &&
+                al.getMate().isMapped() &&
+                al.getMate().getChr().equals(al.getChr());
+    }
+
+    private List<Alignment> linkByTag(List<Alignment> alList, String tag) {
+
+        List<Alignment> bcList = new ArrayList<>(alList.size() / 10);
+        Map<Object, LinkedAlignment> map = new HashMap<>(bcList.size() * 2);
+
+        for (Alignment a : alList) {
+
+            if(a.isPrimary()) {
+                Object bc;
+                if("READNAME".equals(tag)) {
+                    bc = a.getReadName();
+                    if(a.isPaired()) {
+                        bc += a.isFirstOfPair() ? "/1" : "/2";
+                    }
+                }
+                else {
+                    bc = a.getAttribute(tag);
+                }
+
+                if (bc == null) {
+                    bcList.add(a);
+                } else {
+                    LinkedAlignment linkedAlignment = map.get(bc);
+                    if (linkedAlignment == null) {
+                        linkedAlignment = new LinkedAlignment(tag, bc.toString());
+                        map.put(bc, linkedAlignment);
+                        bcList.add(linkedAlignment);
+                    }
+                    linkedAlignment.addAlignment(a);
+                }
+            }
+            else {
+                // Don't link secondary reads
+                bcList.add(a);
+            }
+        }
+
+        // Now copy list, de-linking orhpaned alignments (alignments with no linked mates)
+        List<Alignment> delinkedList = new ArrayList<>(alList.size());
+        for(Alignment a : bcList) {
+            if(a instanceof LinkedAlignment) {
+                final List<Alignment> alignments = ((LinkedAlignment) a).alignments;
+                if(alignments.size() == 1) {
+                    delinkedList.add(alignments.get(0));
+                }
+                else {
+                    a.finish();
+                    delinkedList.add(a);
+                }
+            }
+            else {
+                delinkedList.add(a);
+            }
+        }
+
+        return delinkedList;
+    }
+
 
     /**
      * Gets the range over which alignmentsList spans. Asssumes all on same chr, and sorted
@@ -288,15 +345,25 @@ public class AlignmentPacker {
                 return new Comparator<String>() {
                     @Override
                     public int compare(String o1, String o2) {
-                        if (o1 != null) {
-                            return o1.compareToIgnoreCase(o2);
-                        } else if (o2 != null) {
-                            return o2.compareToIgnoreCase(o1);
-                        } else {
-                            //Both null;
+                        if (o1 == null && o2 == null) {
                             return 0;
+                        } else if (o1 == null) {
+                            return 1;
+                        } else if (o2 == null) {
+                            return -1;
+                        } else {
+                            // no nulls
+                            if (o1.equals(o2)) {
+                                return 0;
+                            } else if (NULL_GROUP_VALUE.equals(o1)) {
+                                return 1;
+                            }
+                            if (NULL_GROUP_VALUE.equals(o2)) {
+                                return -1;
+                            } else {
+                                return o1.compareToIgnoreCase(o2);
+                            }
                         }
-
                     }
                 };
         }
@@ -304,12 +371,13 @@ public class AlignmentPacker {
 
     private String getGroupValue(Alignment al, AlignmentTrack.RenderOptions renderOptions) {
 
-        AlignmentTrack.GroupOption groupBy = renderOptions.groupByOption;
+        AlignmentTrack.GroupOption groupBy = renderOptions.getGroupByOption();
         String tag = renderOptions.getGroupByTag();
+        Range pos = renderOptions.getGroupByPos();
 
         switch (groupBy) {
             case STRAND:
-                return String.valueOf(al.isNegativeStrand());
+                return al.isNegativeStrand() ? "-" : "+";
             case SAMPLE:
                 return al.getSample();
             case LIBRARY:
@@ -322,7 +390,6 @@ public class AlignmentPacker {
             case FIRST_OF_PAIR_STRAND:
                 Strand strand = al.getFirstOfPairStrand();
                 String strandString = strand == Strand.NONE ? null : strand.toString();
-                System.out.println(strandString);
                 return strandString;
             case PAIR_ORIENTATION:
                 PEStats peStats = AlignmentRenderer.getPEStats(al, renderOptions);
@@ -335,18 +402,40 @@ public class AlignmentPacker {
                 ReadMate mate = al.getMate();
                 if (mate == null) {
                     return null;
-                } else if (mate.isMapped() == false) {
+                }
+                if (mate.isMapped() == false) {
                     return "UNMAPPED";
                 } else {
                     return mate.getChr();
                 }
             case SUPPLEMENTARY:
-                return String.valueOf(!al.isSupplementary());
+                return al.isSupplementary() ? "SUPPLEMENTARY" : "";
+            case BASE_AT_POS:
+                // Use a string prefix to enforce grouping rules:
+                //    1: alignments with a base at the position
+                //    2: alignments with a gap at the position
+                //    3: alignment that do not overlap the position (or are on a different chromosome)
+
+                if (al.getChr().equals(pos.getChr()) &&
+                    al.getAlignmentStart() <= pos.getStart() &&
+                    al.getAlignmentEnd() > pos.getStart()) {
+
+                    byte[] baseAtPos = new byte[] {al.getBase(pos.getStart())};
+                    if (baseAtPos[0] == 0) { // gap at position
+                        return "2:";
+                    }
+                    else { // base at position
+                        return "1:" + new String(baseAtPos);
+                    }
+                }
+                else { // does not overlap position
+                    return "3:";
+                }
         }
         return null;
     }
 
-    static interface BucketCollection {
+    interface BucketCollection {
 
         Range getRange();
 
@@ -411,14 +500,13 @@ public class AlignmentPacker {
             while (bucketNumber < bucketArray.length) {
 
                 if (bucketNumber < 0) {
-                    System.out.println();
+                    log.info("Negative bucket number: " + bucketNumber);
                 }
 
                 bucket = bucketArray[bucketNumber];
                 if (bucket != null) {
                     if (bucket.isEmpty()) {
                         bucketArray[bucketNumber] = null;
-                        bucket = null;
                     } else {
                         return bucket;
                     }
