@@ -29,15 +29,16 @@
  */
 package org.broad.igv.sam;
 
-import com.google.common.eventbus.Subscribe;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.data.CoverageDataSource;
+import org.broad.igv.event.IGVEventBus;
 import org.broad.igv.feature.FeatureUtils;
 import org.broad.igv.feature.LocusScore;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.goby.GobyCountArchiveDataSource;
+import org.broad.igv.prefs.IGVPreferences;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.renderer.BarChartRenderer;
 import org.broad.igv.renderer.DataRange;
 import org.broad.igv.renderer.DataRenderer;
@@ -50,9 +51,7 @@ import org.broad.igv.track.*;
 import org.broad.igv.ui.DataRangeDialog;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.color.ColorUtilities;
-import org.broad.igv.ui.event.AlignmentTrackEvent;
-import org.broad.igv.ui.event.DataLoadedEvent;
-import org.broad.igv.ui.event.ViewChange;
+import org.broad.igv.event.AlignmentTrackEvent;
 import org.broad.igv.ui.panel.FrameManager;
 import org.broad.igv.ui.panel.IGVPopupMenu;
 import org.broad.igv.ui.panel.ReferenceFrame;
@@ -71,10 +70,11 @@ import java.awt.event.ActionListener;
 import java.io.File;
 import java.text.DecimalFormat;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collection;
 import java.util.List;
 
+import static org.broad.igv.prefs.Constants.*;
+
 /**
  * @author jrobinso
  */
@@ -107,7 +107,7 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
     private CoverageDataSource dataSource;
     private DataRenderer dataSourceRenderer;
     private IntervalRenderer intervalRenderer;
-    private PreferenceManager prefs;
+    private IGVPreferences prefs;
     private JMenuItem dataRangeItem;
     private Genome genome;
     private boolean removed = false;
@@ -118,7 +118,6 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
      */
     private boolean globalAutoScale = true;
 
-    private AlignmentTrack.RenderOptions renderOptions = null;
 
     @SubtlyImportant
     public CoverageTrack() {
@@ -135,6 +134,8 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
         this(track.getResourceLocator(), track.getName(), track.alignmentTrack, track.genome);
         if (track.dataManager != null) this.setDataManager(track.dataManager);
         if (track.dataSource != null) this.setDataSource(track.dataSource);
+        this.snpThreshold = track.snpThreshold;
+        this.prefs = track.prefs;
     }
 
     public CoverageTrack(ResourceLocator locator, String name, AlignmentTrack alignmentTrack, Genome genome) {
@@ -147,8 +148,8 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
 
         setColor(coverageGrey);
 
-        prefs = PreferenceManager.getInstance();
-        snpThreshold = prefs.getAsFloat(PreferenceManager.SAM_ALLELE_THRESHOLD);
+        prefs = PreferencesManager.getPreferences();
+        snpThreshold = prefs.getAsFloat(SAM_ALLELE_THRESHOLD);
         autoScale = DEFAULT_AUTOSCALE;
         showReference = DEFAULT_SHOW_REFERENCE;
         //TODO  logScale = prefs.
@@ -158,7 +159,7 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
 
     public void setDataManager(AlignmentDataManager dataManager) {
         this.dataManager = dataManager;
-        this.dataManager.getEventBus().register(this);
+        this.dataManager.subscribe(this);
     }
 
     public void setDataSource(CoverageDataSource dataSource) {
@@ -168,6 +169,22 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
 
     }
 
+    @Override
+    public boolean isReadyToPaint(ReferenceFrame frame) {
+
+        if (frame.getChrName().equals(Globals.CHR_ALL) || frame.getScale() > dataManager.getMinVisibleScale()) {
+            return true;   // Nothing to paint
+        } else {
+            return dataManager.isLoaded(frame);
+        }
+    }
+
+    @Override
+    public void load(ReferenceFrame referenceFrame) {
+        dataManager.load(referenceFrame, alignmentTrack.renderOptions, true);
+    }
+
+
     public void setSnpThreshold(float snpThreshold) {
         this.snpThreshold = snpThreshold;
     }
@@ -180,15 +197,6 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
         return showReference;
     }
 
-
-    public void setRenderOptions(AlignmentTrack.RenderOptions renderOptions) {
-        this.renderOptions = renderOptions;
-    }
-
-    AlignmentTrack.RenderOptions getRenderOptions() {
-        return this.renderOptions;
-    }
-
     public boolean isRemoved() {
         return removed;
     }
@@ -197,53 +205,15 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
     public void dispose() {
         super.dispose();
         removed = true;
+        if (dataManager != null) {
+            dataManager.unsubscribe(this);
+        }
         dataManager = null;
         dataSource = null;
         alignmentTrack = null;
         setVisible(false);
     }
 
-    /**
-     * Rescale as necessary, and tell components to repaint
-     *
-     * @param e
-     */
-    @Subscribe
-    public void receiveDataLoaded(DataLoadedEvent e) {
-        ReferenceFrame frame = e.getReferenceFrame();
-        //rescale(frame);
-        frame.getEventBus().post(new ViewChange.Result());
-    }
-
-    public void rescale(ReferenceFrame iframe) {
-        List<ReferenceFrame> frameList = new ArrayList<ReferenceFrame>();
-        if (iframe != null) frameList.add(iframe);
-        if (globalAutoScale) {
-            frameList.addAll(FrameManager.getFrames());
-        }
-
-        if (autoScale && dataManager != null) {
-
-            int max = 10;
-            for (ReferenceFrame frame : frameList) {
-                AlignmentInterval interval = dataManager.getLoadedInterval(frame.getCurrentRange());
-                if (interval == null) continue;
-
-                int origin = (int) frame.getOrigin();
-                int end = (int) frame.getEnd() + 1;
-
-                int intervalMax = interval.getMaxCount(origin, end);
-                max = intervalMax > max ? intervalMax : max;
-            }
-
-            DataRange newRange = new DataRange(0, max);
-            newRange.setType(getDataRange().getType());
-            super.setDataRange(newRange);
-
-        }
-    }
-
-
     public void render(RenderContext context, Rectangle rect) {
 
         if (context.getScale() > dataManager.getMinVisibleScale() && dataSource == null) {
@@ -269,15 +239,15 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
 
     public void drawData(RenderContext context, Rectangle rect) {
 
-        float maxRange = PreferenceManager.getInstance().getAsFloat(PreferenceManager.SAM_MAX_VISIBLE_RANGE);
+        float maxRange = PreferencesManager.getPreferences().getAsFloat(SAM_MAX_VISIBLE_RANGE);
         float minVisibleScale = (maxRange * 1000) / 700;
 
         if (context.getScale() < minVisibleScale && !context.getChr().equals(Globals.CHR_ALL)) {
             //Show coverage calculated from intervals if zoomed in enough
             AlignmentInterval interval = null;
             if (dataManager != null) {
-                dataManager.load(context.getReferenceFrame(), renderOptions, true);
-                interval = dataManager.getLoadedInterval(context.getReferenceFrame().getCurrentRange());
+                dataManager.load(context.getReferenceFrame(), alignmentTrack.renderOptions, true);
+                interval = dataManager.getLoadedInterval(context.getReferenceFrame());
             }
             if (interval != null) {
                 if (interval.contains(context.getChr(), (int) context.getOrigin(), (int) context.getEndLocation())) {
@@ -312,7 +282,7 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
             // Trim scores
             int startIdx = FeatureUtils.getIndexBefore(start, inViewScores);
             int endIdx = inViewScores.size() - 1;   // Starting guess
-            int tmp = FeatureUtils.getIndexBefore(end, inViewScores);
+            int tmp = Math.max(0, FeatureUtils.getIndexBefore(end, inViewScores));
             for (int i = tmp; i < inViewScores.size(); i++) {
                 if (inViewScores.get(i).getStart() > end) {
                     endIdx = i - 1;
@@ -321,9 +291,13 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
             }
             endIdx = Math.max(startIdx + 1, endIdx);
 
-            return startIdx == 0 && endIdx == inViewScores.size() - 1 ?
-                    inViewScores :
-                    inViewScores.subList(startIdx, endIdx);
+            if (inViewScores.size() > 1) {
+                return startIdx == 0 && endIdx == inViewScores.size() - 1 ?
+                        inViewScores :
+                        inViewScores.subList(startIdx, endIdx);
+            } else {
+                return inViewScores;
+            }
         }
         return inViewScores;
     }
@@ -351,7 +325,7 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
 
         } else {
 
-            AlignmentInterval interval = dataManager.getLoadedInterval(frame.getCurrentRange());
+            AlignmentInterval interval = dataManager.getLoadedInterval(frame);
             if (interval == null) return null;
 
             int origin = (int) frame.getOrigin();
@@ -385,9 +359,9 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
         return false;
     }
 
-    public String getValueStringAt(String chr, double position, int y, ReferenceFrame frame) {
+    public String getValueStringAt(String chr, double position, int mouseX, int mouseY, ReferenceFrame frame) {
 
-        float maxRange = PreferenceManager.getInstance().getAsFloat(PreferenceManager.SAM_MAX_VISIBLE_RANGE);
+        float maxRange = PreferencesManager.getPreferences().getAsFloat(SAM_MAX_VISIBLE_RANGE);
         float minVisibleScale = (maxRange * 1000) / 700;
 
         StringBuffer buf = new StringBuffer();
@@ -399,7 +373,7 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
         }
 
         if (frame.getScale() < minVisibleScale) {
-            AlignmentInterval interval = dataManager.getLoadedInterval(frame.getCurrentRange());
+            AlignmentInterval interval = dataManager.getLoadedInterval(frame);
             if (interval != null && interval.contains(chr, (int) position, (int) position)) {
                 AlignmentCounts counts = interval.getCounts();
                 if (counts != null) {
@@ -412,6 +386,15 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
         return buf.toString();
     }
 
+    public AlignmentCounts getCounts(String chr, double position, ReferenceFrame frame) {
+        AlignmentInterval interval = dataManager.getLoadedInterval(frame);
+        if (interval != null && interval.contains(chr, (int) position, (int) position)) {
+            return interval.getCounts();
+        } else {
+            return null;
+        }
+    }
+
     private String getPrecomputedValueString(String chr, double position, ReferenceFrame frame) {
 
         if (dataSource == null) {
@@ -436,6 +419,34 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
         return 0;
     }
 
+    public void rescale(ReferenceFrame iframe) {
+        List<ReferenceFrame> frameList = new ArrayList<ReferenceFrame>();
+        if (iframe != null) frameList.add(iframe);
+        if (globalAutoScale) {
+            frameList.addAll(FrameManager.getFrames());
+        }
+
+        if (autoScale && dataManager != null) {
+
+            int max = 10;
+            for (ReferenceFrame frame : frameList) {
+                AlignmentInterval interval = dataManager.getLoadedInterval(frame);
+                if (interval == null) continue;
+
+                int origin = (int) frame.getOrigin();
+                int end = (int) frame.getEnd() + 1;
+
+                int intervalMax = interval.getMaxCount(origin, end);
+                max = intervalMax > max ? intervalMax : max;
+            }
+
+            DataRange newRange = new DataRange(0, max);
+            newRange.setType(getDataRange().getType());
+            super.setDataRange(newRange);
+
+        }
+    }
+
     /**
      * Class to render coverage track, including mismatches.
      * <p/>
@@ -461,7 +472,7 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
             final double colorScaleMax = getColorScale().getMaximum();
             final double scale = context.getScale();
 
-            boolean bisulfiteMode = dataManager.getExperimentType() == AlignmentTrack.ExperimentType.BISULFITE;
+            boolean bisulfiteMode = alignmentTrack.renderOptions.getColorOption() == AlignmentTrack.ColorOption.BISULFITE;
 
 
             // First pass, coverage
@@ -543,7 +554,6 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
 
                         // Test to see if any single nucleotide mismatch  (nucleotide other than the reference)
                         // has a quality weight > 20% of the total
-                        // Skip this test if the position is in the list of known snps or if the reference is unknown
                         boolean mismatch = false;
 
                         if (refBases != null) {
@@ -553,7 +563,7 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
                                     mismatch = (bc != null && (bc.methylatedCount + bc.unmethylatedCount) > 0);
                                 } else {
                                     byte ref = refBases[refIdx];
-                                    mismatch = alignmentCounts.isMismatch(pos, ref, context.getChr(), snpThreshold);
+                                    mismatch = alignmentCounts.isConsensusMismatch(pos, ref, context.getChr(), snpThreshold);
                                 }
                             }
                         }
@@ -756,12 +766,12 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
 
     private Color getShadedColor(int qual, Color backgroundColor, Color color) {
         float alpha = 0;
-        int minQ = prefs.getAsInt(PreferenceManager.SAM_BASE_QUALITY_MIN);
+        int minQ = prefs.getAsInt(SAM_BASE_QUALITY_MIN);
         ColorUtilities.getRGBColorComponents(color);
         if (qual < minQ) {
             alpha = 0.1f;
         } else {
-            int maxQ = prefs.getAsInt(PreferenceManager.SAM_BASE_QUALITY_MAX);
+            int maxQ = prefs.getAsInt(SAM_BASE_QUALITY_MAX);
             alpha = Math.max(0.1f, Math.min(1.0f, 0.1f + 0.9f * (qual - minQ) / (maxQ - minQ)));
         }
         // Round alpha to nearest 0.1, for effeciency;
@@ -806,7 +816,7 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
         JMenuItem copyDetails = new JMenuItem("Copy Details to Clipboard");
         copyDetails.setEnabled(false);
         if (te.getFrame() != null) {
-            final String details = getValueStringAt(te.getFrame().getChrName(), te.getChromosomePosition(), te.getMouseEvent().getY(), te.getFrame());
+            final String details = getValueStringAt(te.getFrame().getChrName(), te.getChromosomePosition(), te.getMouseEvent().getX(), te.getMouseEvent().getY(), te.getFrame());
             copyDetails.addActionListener(new ActionListener() {
                 @Override
                 public void actionPerformed(ActionEvent e) {
@@ -872,7 +882,7 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
                 try {
                     float tmp = Float.parseFloat(value);
                     snpThreshold = tmp;
-                    IGV.getInstance().repaintDataPanels();
+                    IGV.getInstance().revalidateTrackPanels();
                 } catch (Exception exc) {
                     //log
                 }
@@ -893,10 +903,7 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
             alignmentItem.addActionListener(new ActionListener() {
                 @Override
                 public void actionPerformed(ActionEvent e) {
-                    alignmentTrack.onAlignmentTrackEvent(new AlignmentTrackEvent(CoverageTrack.this, AlignmentTrackEvent.Type.VISIBLE, alignmentItem.isSelected()));
-                    if (alignmentItem.isSelected()) {
-                        alignmentTrack.onAlignmentTrackEvent(new AlignmentTrackEvent(CoverageTrack.this, AlignmentTrackEvent.Type.RELOAD));
-                    }
+                    alignmentTrack.setVisible(alignmentItem.isSelected());
                 }
             });
             menu.add(alignmentItem);
@@ -909,15 +916,14 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
                 junctionItem.addActionListener(new ActionListener() {
                     @Override
                     public void actionPerformed(ActionEvent e) {
-                        alignmentTrack.onAlignmentTrackEvent(new AlignmentTrackEvent(CoverageTrack.this, AlignmentTrackEvent.Type.SPLICE_JUNCTION, junctionItem.isSelected()));
-                        IGV.getInstance().getMainPanel().revalidate();
+                        spliceJunctionTrack.setVisible(junctionItem.isSelected());
                     }
                 });
 
                 menu.add(junctionItem);
             }
 
-            final JMenuItem coverageItem = new JMenuItem("Hide Track");
+            final JMenuItem coverageItem = new JMenuItem("Hide Coverage Track");
             coverageItem.setEnabled(!isRemoved());
             coverageItem.addActionListener(new ActionListener() {
                 @Override
@@ -926,7 +932,7 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
 
                         public void run() {
                             setVisible(false);
-                            IGV.getInstance().getMainPanel().revalidate();
+                            if (IGV.hasInstance()) IGV.getInstance().getMainPanel().revalidate();
 
                         }
                     });
@@ -944,7 +950,7 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
 
             public void actionPerformed(ActionEvent e) {
 
-                final PreferenceManager prefs = PreferenceManager.getInstance();
+                final IGVPreferences prefs = PreferencesManager.getPreferences();
                 File initDirectory = prefs.getLastTrackDirectory();
                 File file = FileDialogUtils.chooseFile("Select coverage file", initDirectory, FileDialog.LOAD);
                 if (file != null) {
@@ -954,11 +960,11 @@ public class CoverageTrack extends AbstractTrack implements ScalableTrack {
                         TDFReader reader = TDFReader.getReader(file.getAbsolutePath());
                         TDFDataSource ds = new TDFDataSource(reader, 0, getName() + " coverage", genome);
                         setDataSource(ds);
-                        IGV.getInstance().repaintDataPanels();
+                        IGV.getInstance().revalidateTrackPanels();
                     } else if (path.endsWith(".counts")) {
                         CoverageDataSource ds = new GobyCountArchiveDataSource(file);
                         setDataSource(ds);
-                        IGV.getInstance().repaintDataPanels();
+                        IGV.getInstance().revalidateTrackPanels();
                     } else {
                         MessageUtils.showMessage("Coverage data must be in .tdf format");
                     }
