@@ -31,13 +31,15 @@ import htsjdk.samtools.SAMFileHeader;
 import htsjdk.samtools.SAMReadGroupRecord;
 import htsjdk.samtools.SAMRecord;
 import org.apache.log4j.Logger;
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.genome.GenomeManager;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.IGVPreferences;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.ui.color.ColorUtilities;
 
-import java.util.List;
 import java.util.ArrayList;
+import java.util.List;
 
 /**
  * @author jrobinso
@@ -45,7 +47,7 @@ import java.util.ArrayList;
 public class PicardAlignment extends SAMAlignment implements Alignment {
 
     private static Logger log = Logger.getLogger(PicardAlignment.class);
-    private static PreferenceManager prefMgr = PreferenceManager.getInstance();
+    private static IGVPreferences prefMgr = PreferencesManager.getPreferences();
 
     private static final int READ_PAIRED_FLAG = 0x1;
     private static final int PROPER_PAIR_FLAG = 0x2;
@@ -60,7 +62,7 @@ public class PicardAlignment extends SAMAlignment implements Alignment {
     private static final int DUPLICATE_READ_FLAG = 0x400;
     private static final int SUPPLEMENTARY_ALIGNMENT_FLAG = 0x800;
 
-
+    private SAMReadGroupRecord readGroupRecord;
     private int flags;
 
     /**
@@ -94,18 +96,16 @@ public class PicardAlignment extends SAMAlignment implements Alignment {
                     record.getMateUnmappedFlag()));
         }
 
-        String keySequence = null;
         SAMFileHeader header = record.getHeader();
+        String keySequence = null;
         String flowOrder = null;
         if (header != null) {
-            readGroup = (String) record.getAttribute("RG");
+            String readGroup = (String) record.getAttribute("RG");
             if (readGroup != null) {
-                SAMReadGroupRecord rgRec = header.getReadGroup(readGroup);
-                if (rgRec != null) {
-                    this.sample = rgRec.getSample();
-                    this.library = rgRec.getLibrary();
-                    flowOrder = rgRec.getFlowOrder();
-                    keySequence = rgRec.getKeySequence();
+                this.readGroupRecord = header.getReadGroup(readGroup);
+                if(this.readGroupRecord != null) {
+                    keySequence = this.readGroupRecord.getKeySequence();
+                    flowOrder = this.readGroupRecord.getFlowOrder();
                 }
             }
         }
@@ -113,7 +113,7 @@ public class PicardAlignment extends SAMAlignment implements Alignment {
         Object colorTag = record.getAttribute("YC");
         if (colorTag != null) {
             try {
-                color = ColorUtilities.stringToColor(colorTag.toString(), null);
+                ycColor = ColorUtilities.stringToColor(colorTag.toString(), null);
             } catch (Exception e) {
                 log.error("Error interpreting color tag: " + colorTag, e);
             }
@@ -121,8 +121,7 @@ public class PicardAlignment extends SAMAlignment implements Alignment {
 
         setPairOrientation();
         setPairStrands();
-        createAlignmentBlocks(record.getCigarString(), record.getReadBases(), record.getBaseQualities(),
-                getFlowSignals(flowOrder, keySequence), flowOrder, this.getFlowSignalsStart());
+        createAlignmentBlocks(record.getCigarString(), record.getReadBases(), record.getBaseQualities());
 
 
     }      // End constructor
@@ -179,6 +178,7 @@ public class PicardAlignment extends SAMAlignment implements Alignment {
     public boolean isVendorFailedRead() {
         return (flags & READ_FAILS_VENDOR_QUALITY_CHECK_FLAG) != 0;
     }
+
     @Override
     public boolean isPrimary() {
         return (flags & NOT_PRIMARY_ALIGNMENT_FLAG) == 0;
@@ -233,16 +233,15 @@ public class PicardAlignment extends SAMAlignment implements Alignment {
         // List of tags to skip.  Some tags, like MD and SA, are both quite verbose and not easily
         // interpreted by a human reader.  It is best to just hide these tags.  The list of tags
         // to hide is set through the SAM_HIDDEN_TAGS preference.
-        ArrayList<String> tagsToHide = new ArrayList<String>();
+        ArrayList<String> tagsToHide = new ArrayList<String>(),
+            tagsHidden = new ArrayList<String>();
 
-        String samHiddenTagsPref = prefMgr.get(PreferenceManager.SAM_HIDDEN_TAGS);
-        for (String s: (samHiddenTagsPref == null ? "" : samHiddenTagsPref).split("[, ]")) {
+        String samHiddenTagsPref = prefMgr.get(Constants.SAM_HIDDEN_TAGS);
+        for (String s : (samHiddenTagsPref == null ? "" : samHiddenTagsPref).split("[, ]")) {
             if (!s.equals("")) {
                 tagsToHide.add(s);
             }
         }
-        // Always hide the read group (RG) tag, as it is displayed as a special case.
-        tagsToHide.add("RG");
 
         StringBuffer buf = new StringBuffer();
         SAMRecord record = getRecord();
@@ -250,7 +249,10 @@ public class PicardAlignment extends SAMAlignment implements Alignment {
         if (attributes != null && !attributes.isEmpty()) {
 
             for (SAMRecord.SAMTagAndValue tag : attributes) {
-                if (tagsToHide.contains(tag.tag)) { continue; }
+                if (tagsToHide.contains(tag.tag)) {
+                    tagsHidden.add(tag.tag);
+                    continue;
+                }
                 buf.append("<br>" + tag.tag + " = ");
 
                 if (tag.value.getClass().isArray()) { // ignore array types
@@ -289,77 +291,23 @@ public class PicardAlignment extends SAMAlignment implements Alignment {
                 }
 
             }
-            buf.append("<br>-------------------");
+
+            if (tagsHidden.size() > 0) {
+                buf.append("<br>Hidden tags: " + String.join(", ", tagsHidden));
+            }
         }
         return buf.toString();
     }
 
-    /**
-     * @param flowOrder   the flow order corresponding to this read
-     * @param keySequence sequence the key sequence corresponding to this read
-     * @return the flow signals in 100x format (SFF), only if they exist (FZ tag),
-     * if the key sequence and flow order are found in the read group header tag
-     * (RG.KS and RG.FO).  Note: the array proceeds in the sequencing direction.
-     */
-    public short[] getFlowSignals(String flowOrder, String keySequence) {
-        short[] r = null;
-        int i;
-        int startFlow, keySignalOverlap;
-        char firstBase;
-
-        if (null == flowOrder || null == keySequence) {
-            return null;
-        }
-
-        startFlow = this.getFlowSignalsStart();
-        if (startFlow < 0) {
-            return null;
-        }
-
-        // get the # of bases that the first base in the read overlaps with the last base(s) in the key
-        SAMRecord record = getRecord();
-        if (this.isNegativeStrand()) {
-            firstBase = (char) NT2COMP[record.getReadBases()[record.getReadLength() - 1]];
-        } else {
-            firstBase = (char) record.getReadBases()[0];
-        }
-        keySignalOverlap = 0;
-        for (i = keySequence.length() - 1; 0 <= i && keySequence.charAt(i) == firstBase; i--) {
-            keySignalOverlap += 100;
-        }
-
-        Object attribute = record.getAttribute("FZ");
-        if (null == attribute) {
-            return null;
-        } else if (attribute instanceof short[]) {
-            short[] signals = (short[]) attribute;
-            r = new short[signals.length - startFlow];
-            for (i = startFlow; i < signals.length; i++) {
-                r[i - startFlow] = signals[i];
-            }
-        } else if (attribute instanceof int[]) {
-            int[] signals = (int[]) attribute;
-            r = new short[signals.length - startFlow];
-            System.arraycopy(signals, startFlow, r, 0, r.length);
-        } else if (attribute instanceof byte[]) {
-            byte[] signals = (byte[]) attribute;
-            r = new short[signals.length - startFlow];
-            for (i = startFlow; i < signals.length; i++) {
-                r[i - startFlow] = signals[i];
-            }
-        } else {
-            return null;
-        }
-        // Subtract the key's contribution to the first base
-        if (0 < keySignalOverlap && 0 < r.length) {
-            if (r[0] <= keySignalOverlap) {
-                r[0] = 0;
-            } else {
-                r[0] -= keySignalOverlap;
-            }
-        }
-
-        return r;
+    public String getSample() {
+        return readGroupRecord == null ? null : readGroupRecord.getSample();
     }
 
+    public String getReadGroup() {
+        return readGroupRecord == null ? null : readGroupRecord.getId();
+    }
+
+    public String getLibrary() {
+        return readGroupRecord == null ? null : readGroupRecord.getLibrary();
+    }
 }
