@@ -31,16 +31,19 @@ package org.broad.igv.sam;
 
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.Strand;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.genome.GenomeManager;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.track.WindowFunction;
 
 import java.awt.*;
-import java.text.DecimalFormat;
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.List;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
 /**
  * @author jrobinso
@@ -86,22 +89,20 @@ public abstract class SAMAlignment implements Alignment {
             'N', 'N', 'N', 'N', 'N', 'N', 'N', 'N', 'N', 'N', 'N', 'N', 'N', 'N', 'N', 'N'
     };
     private static final String FLOW_SIGNAL_TAG = "ZF";
+    protected int alignmentStart;
+    protected int alignmentEnd;
 
 
     String chr;
     protected int start;  // <= Might differ from alignment start if soft clipping is considered
     protected int end;    // ditto
-    protected Color color = null;
-
-    protected String readGroup;
-    protected String library;
-    protected String sample;
+    protected Color ycColor = null;
 
     ReadMate mate;
-    AlignmentBlockImpl[] alignmentBlocks;
-    AlignmentBlockImpl[] insertions;
+    public AlignmentBlockImpl[] alignmentBlocks;
+    public AlignmentBlockImpl[] insertions;
+    List<Gap> gaps;
     char[] gapTypes;
-    private static final DecimalFormat DECIMAL_FORMAT = new DecimalFormat();
 
     protected String mateSequence = null;
     protected String pairOrientation = "";
@@ -129,8 +130,8 @@ public abstract class SAMAlignment implements Alignment {
         return mate;
     }
 
-    public Color getColor() {
-        return color;
+    public Color getYcColor() {
+        return ycColor;
     }
 
     abstract public String getReadName();
@@ -236,29 +237,26 @@ public abstract class SAMAlignment implements Alignment {
      * @param cigarString
      * @param readBases
      * @param readBaseQualities
-     * @param flowSignals       from the FZ tag, null if not present
-     * @param flowOrder         from the RG.FO header tag, null if not present
-     * @param flowOrderStart
      */
-    protected void createAlignmentBlocks(String cigarString, byte[] readBases, byte[] readBaseQualities,
-                                         short[] flowSignals, String flowOrder, int flowOrderStart) {
+    protected void createAlignmentBlocks(String cigarString, byte[] readBases, byte[] readBaseQualities) {
 
         if (cigarString.equals("*")) {
             alignmentBlocks = new AlignmentBlockImpl[1];
-            alignmentBlocks[0] = new AlignmentBlockImpl(getChr(), getStart(), readBases, readBaseQualities);
+            alignmentBlocks[0] = new AlignmentBlockImpl(getStart(), readBases, readBaseQualities);
             return;
         }
 
         // Create list of cigar operators
         java.util.List<CigarOperator> operators = buildOperators(cigarString);
 
-        boolean showSoftClipped = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SAM_SHOW_SOFT_CLIPPED);
+        boolean showSoftClipped = PreferencesManager.getPreferences().getAsBoolean(Constants.SAM_SHOW_SOFT_CLIPPED);
 
         int nInsertions = 0;
         int nBlocks = 0;
         boolean firstOperator = true;
         int softClippedBaseCount = 0;
         int nGaps = 0;
+        int nRealGaps = 0;
         char prevOp = 0;
         for (CigarOperator operator : operators) {
 
@@ -274,6 +272,7 @@ public abstract class SAMAlignment implements Alignment {
                 }
             } else if (op == DELETION || op == SKIPPED_REGION) {
                 nGaps++;
+                nRealGaps++;
             } else if (op == INSERTION) {
                 nInsertions++;
                 nGaps++; // "virtual" gap, account for artificial block split @ insertion
@@ -296,6 +295,9 @@ public abstract class SAMAlignment implements Alignment {
         if (nGaps > 0) {
             gapTypes = new char[nGaps];
         }
+        if (nRealGaps > 0) {
+            gaps = new ArrayList<Gap>();
+        }
 
         // Adjust start to include soft clipped bases a
         if (showSoftClipped) {
@@ -308,15 +310,10 @@ public abstract class SAMAlignment implements Alignment {
         int blockIdx = 0;
         int insertionIdx = 0;
         int gapIdx = 0;
-        FlowSignalContextBuilder fBlockBuilder = null;
-        if (null != flowSignals) {
-            if (0 < readBases.length) {
-                fBlockBuilder = new FlowSignalContextBuilder(flowSignals, flowOrder, flowOrderStart, readBases, fromIdx, this.isNegativeStrand());
-            }
-        }
-
+        int padding = 0;
         prevOp = 0;
-        for (CigarOperator op : operators) {
+        for (int i = 0; i < operators.size(); i++) {
+            CigarOperator op = operators.get(i);
             try {
 
                 if (op.operator == HARD_CLIP) {
@@ -324,8 +321,8 @@ public abstract class SAMAlignment implements Alignment {
                 }
                 if (operatorIsMatch(showSoftClipped, op.operator)) {
 
-                    AlignmentBlockImpl block = buildAlignmentBlock(fBlockBuilder, readBases, readBaseQualities,
-                            getChr(), blockStart, fromIdx, op.nBases, true);
+                    AlignmentBlockImpl block = buildAlignmentBlock(readBases, readBaseQualities,
+                            blockStart, fromIdx, op.nBases, true);
 
                     if (op.operator == SOFT_CLIP) {
                         block.setSoftClipped(true);
@@ -339,22 +336,37 @@ public abstract class SAMAlignment implements Alignment {
                         gapTypes[gapIdx++] = ZERO_GAP;
                     }
 
-                } else if (op.operator == DELETION || op.operator == SKIPPED_REGION) {
+                } else if (op.operator == DELETION) {
+                    gaps.add(new Gap(blockStart, op.nBases, op.operator));
+                    blockStart += op.nBases;
+                    gapTypes[gapIdx++] = op.operator;
+                } else if (op.operator == SKIPPED_REGION) {
+
+                    // Need the "flanking" regions, i.e. size of blocks either side of splice
+                    int flankingLeft = 0;
+                    int flankingRight = 0;
+                    if (i > 0) {
+                        flankingLeft = operators.get(i - 1).nBases;
+                    }
+                    if (i < operators.size() - 1) {
+                        flankingRight = operators.get(i + 1).nBases;
+                    }
+                    gaps.add(new SpliceGap(blockStart, op.nBases, op.operator, flankingLeft, flankingRight));
                     blockStart += op.nBases;
                     gapTypes[gapIdx++] = op.operator;
                 } else if (op.operator == INSERTION) {
                     // This gap is between blocks split by insertion.   It is a zero
                     // length gap but must be accounted for.
                     gapTypes[gapIdx++] = ZERO_GAP;
-                    AlignmentBlockImpl block = buildAlignmentBlock(fBlockBuilder, readBases, readBaseQualities,
-                            getChr(), blockStart, fromIdx, op.nBases, false);
-
+                    AlignmentBlockImpl block = buildAlignmentBlock(readBases, readBaseQualities,
+                            blockStart, fromIdx, op.nBases, false);
+                    block.setPadding(padding);
                     insertions[insertionIdx++] = block;
                     fromIdx += op.nBases;
+                    padding = 0;
                 } else if (op.operator == PADDING) {
-                    //Padding represents a deletion against the padded reference
-                    //But we don't have the padded reference
-                    gapTypes[gapIdx++] = ZERO_GAP;
+                    // Padding for insertion start, which should be the next operator
+                    padding += op.nBases;
                 }
             } catch (Exception e) {
                 log.error("Error processing CIGAR string", e);
@@ -395,10 +407,7 @@ public abstract class SAMAlignment implements Alignment {
                 int nBases = Integer.parseInt(buffer.toString());
                 buffer.setLength(0);
 
-                if (op == PADDING) {
-                    // Just skip padding for now
-                    continue;
-                } else if (prevOp != null && prevOp.operator == op) {
+                 if (prevOp != null && prevOp.operator == op) {
                     prevOp.nBases += nBases;
                 } else {
                     prevOp = new CigarOperator(nBases, op);
@@ -411,8 +420,9 @@ public abstract class SAMAlignment implements Alignment {
 
     }
 
-    private static AlignmentBlockImpl buildAlignmentBlock(FlowSignalContextBuilder fBlockBuilder, byte[] readBases,
-                                                          byte[] readBaseQualities, String chr, int blockStart,
+
+
+    private static AlignmentBlockImpl buildAlignmentBlock(byte[] readBases, byte[] readBaseQualities, int blockStart,
                                                           int fromIdx, int nBases, boolean checkNBasesAvailable) {
 
         byte[] blockBases = new byte[nBases];
@@ -441,71 +451,50 @@ public abstract class SAMAlignment implements Alignment {
             System.arraycopy(readBaseQualities, fromIdx, blockQualities, 0, nBases);
         }
 
-        AlignmentBlockImpl block;
-        if (fBlockBuilder != null) {
-            block = new AlignmentBlockImpl(chr, blockStart, blockBases, blockQualities,
-                    fBlockBuilder.getFlowSignalContext(readBases, fromIdx, nBases));
-        } else {
-            block = new AlignmentBlockImpl(chr, blockStart, blockBases, blockQualities);
-        }
+        AlignmentBlockImpl block = new AlignmentBlockImpl(blockStart, blockBases, blockQualities);
 
         return block;
     }
 
 
-    private static void bufAppendFlowSignals(AlignmentBlock block, StringBuffer buf, int offset) {
-        if (block.hasFlowSignals()) {
-            // flow signals
-            int i, j, n = 0;
-            FlowSignalSubContext f = block.getFlowSignalSubContext(offset);
-            if (null != f && null != f.getSignals() && null != f.getBases()) {
-                buf.append("FZ = ");
-                StringBuffer spos = new StringBuffer();
-                spos.append("Flow position = ").append(f.getFlowOrderIndex());
+    public String getClipboardString(double location, int mouseX) {
+        return getValueStringImpl(location, mouseX, false);
+    }
 
-                for (i = 0; i < f.getNrSignalTypes(); i++) {
-                    short[] signals = f.getSignalsOfType(i);
-                    char[] bases = f.getBasesOfType(i);
-                    if (null != signals && 0 < signals.length) {
-                        if (1 == i) {
-                            if (0 < n) {
-                                buf.append(",");
-                            }
-                            buf.append("[");
-                        }
-                        for (j = 0; j < signals.length; j++) {
-                            if (1 != i && 0 < n) {
-                                buf.append(",");
-                            }
-                            buf.append(bases[j]);
-                            buf.append(signals[j]);
+    public String getValueString(double position, int mouseX, WindowFunction windowFunction) {
+        return getValueStringImpl(position, mouseX, true);
+    }
 
-                            n++;
-                        }
-                        if (1 == i) {
-                            buf.append("]");
+    private String getValueStringImpl(double position, int mouseX, boolean truncate) {
+
+        int basePosition = (int) position;
+        StringBuffer buf = new StringBuffer();
+
+
+        // First check insertions.  Position is zero based, block coords 1 based
+        if (this.insertions != null) {
+            for (AlignmentBlock block : this.insertions) {
+
+                if (block.containsPixel(mouseX)) {
+
+                    byte[] bases = block.getBases();
+                    if (bases == null) {
+                        buf.append("Insertion: " + block.getLength() + " bases");
+                    } else {
+                        if (bases.length < 50) {
+                            buf.append("Insertion (" + bases.length + " bases): " + new String(bases));
+                        } else {
+                            int len = bases.length;
+                            buf.append("Insertion (" + bases.length + " bases): " + new String(Arrays.copyOfRange(bases, 0, 25)) + "..." +
+                                    new String(Arrays.copyOfRange(bases, len - 25, len)));
                         }
                     }
+                    return buf.toString();
                 }
-                buf.append("<br>").append(spos);
-                buf.append("<br>");
-                // maybe also add flow order?                
             }
         }
-    }
 
-    public String getClipboardString(double location) {
-        return getValueStringImpl(location, false);
-    }
-
-
-    public String getValueString(double position, WindowFunction windowFunction) {
-        return getValueStringImpl(position, true);
-    }
-
-    private String getValueStringImpl(double position, boolean truncate) {
-
-        StringBuffer buf = new StringBuffer();
+        // Not over an insertion
 
         buf.append("Read name = " + getReadName() + "<br>");
 
@@ -513,92 +502,79 @@ public abstract class SAMAlignment implements Alignment {
         if (sample != null) {
             buf.append("Sample = " + sample + "<br>");
         }
+        String library = getLibrary();
+        if (library != null) {
+            buf.append("Library = " + library + "<br>");
+        }
         String readGroup = getReadGroup();
-        if (sample != null) {
+        if (readGroup != null) {
             buf.append("Read group = " + readGroup + "<br>");
         }
+        buf.append("Read length = " + Globals.DECIMAL_FORMAT.format(getReadLength()) + "bp<br>");
+
 
         String cigarString = getCigarString();
-        if (cigarString.length() > 80) {
-            cigarString = cigarString.substring(0, 80) + "...";
+        // Abbreviate long CIGAR strings.  Retain the start and end of the CIGAR, which show
+        // clipping; trim the middle.
+        int maxCigarStringLength = 60;
+        if (cigarString.length() > maxCigarStringLength) {
+            // Match only full <length><operator> pairs at the beginning and end of the string.
+            Matcher lMatcher = Pattern.compile("^(.{1," + Integer.toString(maxCigarStringLength / 2 - 1) + "}[A-Z])").matcher(cigarString);
+            Matcher rMatcher = Pattern.compile("[A-Z](.{1," + Integer.toString(maxCigarStringLength / 2) + "})$").matcher(cigarString);
+            cigarString = (lMatcher.find() ? lMatcher.group(1) : "") + "..." + (rMatcher.find() ? rMatcher.group(1) : "");
         }
 
+
         buf.append("----------------------" + "<br>");
-        int basePosition = (int) position;
-        buf.append("Location = " + getChr() + ":" + DECIMAL_FORMAT.format(1 + (long) position) + "<br>");
-        buf.append("Alignment start = " + DECIMAL_FORMAT.format(getAlignmentStart() + 1) + " (" + (isNegativeStrand() ? "-" : "+") + ")<br>");
+        buf.append("Mapping = " + (isPrimary() ? (isSupplementary() ? "Supplementary" : "Primary") : "Secondary") +
+                (isDuplicate() ? " Duplicate" : "") + (isVendorFailedRead() ? " Failed QC" : "") +
+                " @ MAPQ " + Globals.DECIMAL_FORMAT.format(getMappingQuality()) + "<br>");
+        buf.append("Reference span = " + getChr() + ":" + Globals.DECIMAL_FORMAT.format(getAlignmentStart() + 1) + "-" +
+                Globals.DECIMAL_FORMAT.format(getAlignmentEnd()) + " (" + (isNegativeStrand() ? "-" : "+") + ")" +
+                " = " + Globals.DECIMAL_FORMAT.format(getAlignmentEnd() - getAlignmentStart()) + "bp<br>");
         buf.append("Cigar = " + cigarString + "<br>");
-        buf.append("Mapped = " + (isMapped() ? "yes" : "no") + "<br>");
-        buf.append("Mapping quality = " + getMappingQuality() + "<br>");
-        buf.append("Secondary = " + (isPrimary() ? "no" : "yes") + "<br>");
-        buf.append("Supplementary = " + (isSupplementary() ? "yes" : "no") + "<br>");
-        buf.append("Duplicate = " + (isDuplicate() ? "yes" : "no") + "<br>");
-        buf.append("Failed QC = " + (isVendorFailedRead() ? "yes" : "no") + "<br>");
-        buf.append("----------------------<br>");
+        buf.append("Clipping = ");
 
-        // First check insertions.  Position is zero based, block coords 1 based
-        if (this.insertions != null) {
-            for (AlignmentBlock block : this.insertions) {
-                double insertionLeft = block.getStart() - .25;
-                double insertionRight = block.getStart() + .25;
-                if (position > insertionLeft && position < insertionRight) {
-                    if (block.hasFlowSignals()) {
-                        int offset;
-                        buf = new StringBuffer();
-                        buf.append("Insertion: " + new String(block.getBases()) + "<br>");
-                        buf.append("Base phred quality = ");
-                        for (offset = 0; offset < block.getLength(); offset++) {
-                            byte quality = block.getQuality(offset);
-                            if (0 < offset) {
-                                buf.append(",");
-                            }
-                            buf.append(quality);
-                        }
-                        buf.append("<br>");
-                        for (offset = 0; offset < block.getLength(); offset++) {
-                            byte base = block.getBase(offset);
-                            if (base > 0) {
-                                buf.append((char) base + ": ");
-                                bufAppendFlowSignals(block, buf, offset);
-                            }
-                        }
-                        buf.append("----------------------"); // NB: no <br> required
-                        return buf.toString();
-                    } else {
-                        byte[] bases = block.getBases();
+        // Identify the number of hard and soft clipped bases.
+        Matcher lclipMatcher = Pattern.compile("^(([0-9]+)H)?(([0-9]+)S)?").matcher(cigarString);
+        Matcher rclipMatcher = Pattern.compile("(([0-9]+)S)?(([0-9]+)H)?$").matcher(cigarString);
+        int lclipHard = 0, lclipSoft = 0, rclipHard = 0, rclipSoft = 0;
+        if (lclipMatcher.find()) {
+            lclipHard = lclipMatcher.group(2) == null ? 0 : Integer.parseInt(lclipMatcher.group(2), 10);
+            lclipSoft = lclipMatcher.group(4) == null ? 0 : Integer.parseInt(lclipMatcher.group(4), 10);
+        }
+        if (rclipMatcher.find()) {
+            rclipHard = rclipMatcher.group(4) == null ? 0 : Integer.parseInt(rclipMatcher.group(4), 10);
+            rclipSoft = rclipMatcher.group(2) == null ? 0 : Integer.parseInt(rclipMatcher.group(2), 10);
+        }
 
-                        return bases == null ?
-                                "Insertion: " + block.getLength() + " bases" :
-                                "Insertion: " + new String(block.getBases());
-                    }
+        if (lclipHard + lclipSoft + rclipHard + rclipSoft == 0) {
+            buf.append("None");
+        } else {
+            if (lclipHard + lclipSoft > 0) {
+                buf.append("Left");
+                if (lclipHard > 0) {
+                    buf.append(" " + Globals.DECIMAL_FORMAT.format(lclipHard) + " hard");
+                }
+                if (lclipSoft > 0) {
+                    buf.append(" " + Globals.DECIMAL_FORMAT.format(lclipSoft) + " soft");
+                }
+            }
+            if (rclipHard + rclipSoft > 0) {
+                buf.append((lclipHard + lclipSoft > 0 ? "; " : "") + "Right");
+                if (rclipHard > 0) {
+                    buf.append(" " + Globals.DECIMAL_FORMAT.format(rclipHard) + " hard");
+                }
+                if (rclipSoft > 0) {
+                    buf.append(" " + Globals.DECIMAL_FORMAT.format(rclipSoft) + " soft");
                 }
             }
         }
+        buf.append("<br>");
+
 
         Genome genome = GenomeManager.getInstance().getCurrentGenome();
 
-        for (AlignmentBlock block : this.alignmentBlocks) {
-            if (block.contains(basePosition)) {
-                int offset = basePosition - block.getStart();
-                byte base = block.getBase(offset);
-
-                if (base == 0 && this.getReadSequence().equals("=") && !block.isSoftClipped() && genome != null) {
-                    base = genome.getReference(chr, basePosition);
-
-                }
-
-                byte quality = block.getQuality(offset);
-                buf.append("Base = " + (char) base + "<br>");
-                buf.append("Base phred quality = " + quality + "<br>");
-
-                // flow signals
-                if (block.hasFlowSignals()) {
-                    bufAppendFlowSignals(block, buf, offset);
-                }
-
-            }
-        }
-
         if (this.isPaired()) {
             buf.append("----------------------<br>");
             buf.append("Mate is mapped = " + (getMate().isMapped() ? "yes" : "no") + "<br>");
@@ -620,6 +596,14 @@ public abstract class SAMAlignment implements Alignment {
             }
         }
 
+        Object suppAlignment = this.getAttribute("SA");
+        if (suppAlignment != null) {
+            buf.append("----------------------<br>");
+            buf.append(getSupplAlignmentString(suppAlignment.toString()));
+            buf.append("<br>");
+        }
+
+
         String attributeString = getAttributeString(truncate);
         if (attributeString != null && attributeString.length() > 0) {
             buf.append("----------------------");
@@ -631,6 +615,45 @@ public abstract class SAMAlignment implements Alignment {
             buf.append("----------------------<br>");
             buf.append("Mate sequence: " + mateSequence);
         }
+
+
+        // Specific base
+
+        for (AlignmentBlock block : this.alignmentBlocks) {
+            if (block.contains(basePosition)) {
+
+                buf.append("<hr>");
+                int offset = basePosition - block.getStart();
+                byte base = block.getBase(offset);
+
+                if (base == 0 && this.getReadSequence().equals("=") && !block.isSoftClipped() && genome != null) {
+                    base = genome.getReference(chr, basePosition);
+
+                }
+
+                byte quality = block.getQuality(offset);
+                buf.append("Location = " + getChr() + ":" + Globals.DECIMAL_FORMAT.format(1 + (long) position) + "<br>");
+                buf.append("Base = " + (char) base + " @ QV " + Globals.DECIMAL_FORMAT.format(quality) + "<br>");
+
+                break;
+            }
+        }
+
+        return buf.toString();
+    }
+
+
+    // chr21,26002386,-,11785S1115M,60,0;chr21,26001844,+,1115S111M1D41M1D394M11239S,60,4;
+
+    private String getSupplAlignmentString(String sa) {
+
+        StringBuffer buf = new StringBuffer();
+        buf.append("SupplementaryAlignments");
+        String[] records = Globals.semicolonPattern.split(sa);
+        for (String rec : records) {
+            SupplementaryAlignment a = new SupplementaryAlignment(rec);
+            buf.append("<br>" + a.printString());
+        }
         return buf.toString();
     }
 
@@ -689,24 +712,11 @@ public abstract class SAMAlignment implements Alignment {
         this.end = end;
     }
 
-    public String getSample() {
-        return sample;
-    }
-
-    public String getReadGroup() {
-        return readGroup;
-    }
-
 
     public abstract Object getAttribute(String key);
 
-    public String getLibrary() {
-        return library;
-    }
-
-    @Override
-    public char[] getGapTypes() {
-        return gapTypes;
+    public java.util.List<Gap> getGaps() {
+        return gaps;
     }
 
 
@@ -715,6 +725,15 @@ public abstract class SAMAlignment implements Alignment {
 
     }
 
+    @Override
+    public AlignmentBlock getInsertionAt(int position) {
+        for (AlignmentBlock block : insertions) {
+            if (block.getStart() == position) return block;
+            if (block.getStart() > position) return null;  // Blocks increase lineraly
+        }
+        return null;
+    }
+
 
     public Strand getReadStrand() {
         return isNegativeStrand() ? Strand.NEGATIVE : Strand.POSITIVE;
@@ -818,25 +837,6 @@ public abstract class SAMAlignment implements Alignment {
         }
     }
 
-    //(String chr, int start, boolean negativeStrand,boolean isReadUnmappedFlag) {
-    //SA = X,82962991,+,18S51M31S,0,0;
-    static List<ReadMate> parseSupplementaryTag(String sa) {
-
-        List<ReadMate> mates = new ArrayList();
-        String[] records = Globals.semicolonPattern.split(sa);
-        for (String rec : records) {
-            String[] tokens = Globals.commaPattern.split(rec);
-            String seq = tokens[0];
-            int pos = Integer.parseInt(tokens[1]);
-            boolean negStrand = tokens[2].equals("-");
-            String cigar = tokens[3];
-            int mapQ = Integer.parseInt(tokens[4]);
-            int numMismatches = Integer.parseInt(tokens[5]);
-            mates.add(new ReadMate(seq, pos, negStrand, true));
-        }
-        return mates;
-    }
-
     public void setChr(String chr) {
         this.chr = chr;
     }
@@ -859,5 +859,98 @@ public abstract class SAMAlignment implements Alignment {
         }
     }
 
+    public static class SupplementaryAlignment {
+
+        public String chr;
+        public int start;
+        public char strand;
+        public int mapQ;
+        public int numMismatches;
+        public int lenOnRef;
+
+
+        public SupplementaryAlignment(String rec) {
+            String[] tokens = Globals.commaPattern.split(rec);
+            chr = tokens[0];
+            start = Integer.parseInt(tokens[1]);
+            strand = tokens[2].charAt(0);
+            mapQ = Integer.parseInt(tokens[4]);
+            numMismatches = Integer.parseInt(tokens[5]);
+            lenOnRef = computeLengthOnReference(tokens[3]);
+        }
+
+        public String printString() {
+            // chr6:43,143,415-43,149,942 (-) @ MAPQ 60 NM 763
+            return chr + ":" + Globals.DECIMAL_FORMAT.format(start) + "-" + Globals.DECIMAL_FORMAT.format(start + lenOnRef)
+                    + " (" + strand + ") = " + Globals.DECIMAL_FORMAT.format(lenOnRef) + "bp  @MAPQ " + mapQ + " NM" + numMismatches;
+        }
+
+
+        int computeLengthOnReference(String cigarString) {
+
+            int len = 0;
+            StringBuffer buf = new StringBuffer();
+
+            for (char c : cigarString.toCharArray()) {
+
+                if (c > 47 && c < 58) {
+                    buf.append(c);
+                } else {
+                    switch (c) {
+                        case 'N':
+                        case 'D':
+                        case 'M':
+                        case '=':
+                        case 'X':
+                            len += Integer.parseInt(buf.toString());
+                    }
+                    buf.setLength(0);
+                }
+
+            }
+            return len;
+        }
+    }
+
+    public String getSynopsisString() {
+
+        char st = isNegativeStrand() ? '-' : '+';
+        Object nm = getAttribute("NM");
+        String numMismatches = nm == null ? "?" : nm.toString();
+        int lenOnRef = getAlignmentEnd() - getAlignmentStart();
+
+        int[] clipping = getClipping(getCigarString());
+        String clippingString = "";
+        if (clipping[0] + clipping[1] + clipping[2] + clipping[3] > 0) {
+            if (clipping[0] > 0) clippingString += clipping[0] + "H";
+            if (clipping[1] > 0) clippingString += clipping[1] + "S";
+            clippingString += " ... ";
+            if (clipping[3] > 0) clippingString += clipping[3] + "S";
+            if (clipping[2] > 0) clippingString += clipping[2] + "H";
+        }
+
+        return chr + ":" + Globals.DECIMAL_FORMAT.format(getAlignmentStart()) + "-" +
+                Globals.DECIMAL_FORMAT.format(getAlignmentEnd())
+                + " (" + st + ") = " + Globals.DECIMAL_FORMAT.format(lenOnRef) + "BP  @MAPQ=" + getMappingQuality() +
+                " NM=" + numMismatches + " CLIPPING=" + clippingString;
+
+    }
+
+
+    public static int[] getClipping(String cigarString) {
+        // Identify the number of hard and soft clipped bases.
+        Matcher lclipMatcher = Pattern.compile("^(([0-9]+)H)?(([0-9]+)S)?").matcher(cigarString);
+        Matcher rclipMatcher = Pattern.compile("(([0-9]+)S)?(([0-9]+)H)?$").matcher(cigarString);
+        int lclipHard = 0, lclipSoft = 0, rclipHard = 0, rclipSoft = 0;
+        if (lclipMatcher.find()) {
+            lclipHard = lclipMatcher.group(2) == null ? 0 : Integer.parseInt(lclipMatcher.group(2), 10);
+            lclipSoft = lclipMatcher.group(4) == null ? 0 : Integer.parseInt(lclipMatcher.group(4), 10);
+        }
+        if (rclipMatcher.find()) {
+            rclipHard = rclipMatcher.group(4) == null ? 0 : Integer.parseInt(rclipMatcher.group(4), 10);
+            rclipSoft = rclipMatcher.group(2) == null ? 0 : Integer.parseInt(rclipMatcher.group(2), 10);
+        }
+        return new int[]{lclipHard, lclipSoft, rclipHard, rclipSoft};
+    }
 
 }
