@@ -52,7 +52,7 @@ public class MergedAlignmentReader implements AlignmentReader {
     Map<String, Integer> chrNameIndex;
     SAMFileHeader header;
 
-    public MergedAlignmentReader(List<AlignmentReader> readers) {
+    public MergedAlignmentReader(List<AlignmentReader> readers) throws IOException {
         this.readers = readers;
         loadSequenceNames();
     }
@@ -98,7 +98,7 @@ public class MergedAlignmentReader implements AlignmentReader {
      *
      * @return
      */
-    public void loadSequenceNames() {
+    public void loadSequenceNames() throws IOException {
         // Use a set for quick comparison
         LinkedHashSet<String> names = new LinkedHashSet<String>(50);
         for (AlignmentReader reader : readers) {
@@ -220,7 +220,6 @@ public class MergedAlignmentReader implements AlignmentReader {
 
             void close() {
                 if (iterator != null) {
-                    System.out.println("Closing " + this);
                     iterator.close();
                     iterator = null;
                 }
@@ -235,6 +234,8 @@ public class MergedAlignmentReader implements AlignmentReader {
 
                 Integer idx1 = chrNameIndex.get(a1.getChr());
                 Integer idx2 = chrNameIndex.get(a2.getChr());
+                if(idx1==null) idx1 = Integer.MAX_VALUE;
+                if(idx2== null) idx2 = Integer.MAX_VALUE;  // Put these records at the end.
                 if (idx1 > idx2) {
                     return 1;
                 } else if (idx1 < idx2) {
