@@ -30,6 +30,9 @@ import org.broad.igv.Globals;
 import org.broad.igv.feature.Locus;
 import org.broad.igv.feature.RegionOfInterest;
 import org.broad.igv.feature.genome.Genome;
+import org.broad.igv.feature.genome.GenomeListItem;
+import org.broad.igv.sam.AlignmentTrack;
+import org.broad.igv.ui.commandbar.GenomeListManager;
 import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.lists.GeneList;
 import org.broad.igv.lists.GeneListManager;
@@ -60,7 +63,6 @@ import javax.xml.bind.JAXBElement;
 import javax.xml.bind.JAXBException;
 import javax.xml.bind.Unmarshaller;
 import java.awt.*;
-import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.lang.ref.WeakReference;
@@ -207,6 +209,7 @@ public class IGVSessionReader implements SessionReader {
         FILTER_MATCH("match"),
         FILTER_SHOW_ALL_TRACKS("showTracks"),
         GENOME("genome"),
+        UCSC_ID("ucscID"),
         GROUP_TRACKS_BY("groupTracksBy"),
         NEXT_AUTOSCALE_GROUP("nextAutoscaleGroup"),
         HEIGHT("height"),
@@ -316,12 +319,13 @@ public class IGVSessionReader implements SessionReader {
         HashMap additionalInformation = new HashMap();
         additionalInformation.put(INPUT_FILE_KEY, sessionPath);
 
-        NodeList nodes = document.getElementsByTagName(SessionElement.GLOBAL.getText());
+        NodeList nodes = document.getElementsByTagName(SessionElement.SESSION.getText());
         if (nodes == null || nodes.getLength() == 0) {
-            nodes = document.getElementsByTagName(SessionElement.SESSION.getText());
+            nodes = document.getElementsByTagName(SessionElement.GLOBAL.getText());
         }
 
         this.rootPath = sessionPath;
+
         processRootNode(session, nodes.item(0), additionalInformation, sessionPath);
 
         // Add tracks not explicitly allocated to panels.  It is legal to define sessions with the Resources
@@ -370,7 +374,9 @@ public class IGVSessionReader implements SessionReader {
 
         // Load the genome, which can be an ID, or a path or URL to a .genome or indexed fasta file.
         String genomeId = getAttribute(element, SessionAttribute.GENOME.getText());
+
         String hasGeneTrackStr = getAttribute(element, SessionAttribute.HAS_GENE_TRACK.getText());
+
         boolean hasGeneTrack = true;
         if (hasGeneTrackStr != null) {
             hasGeneTrack = Boolean.parseBoolean(hasGeneTrackStr);
@@ -382,6 +388,7 @@ public class IGVSessionReader implements SessionReader {
         }
 
         if (genomeId != null && genomeId.length() > 0) {
+
             if (genomeId.equals(GenomeManager.getInstance().getGenomeId())) {
                 // We don't have to reload the genome, but the gene track for the current genome should be restored.
                 if (hasGeneTrack || hasSeqTrack) {
@@ -390,26 +397,33 @@ public class IGVSessionReader implements SessionReader {
                     IGV.getInstance().setGenomeTracks(geneTrack);
                 }
             } else {
+
                 // Selecting a genome will actually "reset" the session so we have to
                 // save the path and restore it.
                 String sessionPath = session.getPath();
-                //Loads genome from list, or from server or cache
-                igv.selectGenomeFromList(genomeId);
-                if (!genomeId.equals(GenomeManager.getInstance().getGenomeId())) {
-                    String genomePath = genomeId;
-                    if (!ParsingUtils.pathExists(genomePath)) {
-                        genomePath = getAbsolutePath(genomeId, rootPath, session.getPath());
-                    }
-                    if (ParsingUtils.pathExists(genomePath)) {
-                        try {
-                            IGV.getInstance().loadGenome(genomePath, null, hasGeneTrack);
-                        } catch (IOException e) {
-                            throw new RuntimeException("Error loading genome: " + genomeId);
-                        }
+
+                try {
+                    GenomeListItem item = GenomeListManager.getInstance().getGenomeListItem(genomeId);
+                    if (item != null) {
+                        GenomeManager.getInstance().loadGenome(item.getPath(), null);
                     } else {
-                        MessageUtils.showMessage("Warning: Could not locate genome: " + genomeId);
+                        String genomePath = genomeId;
+                        if (!ParsingUtils.pathExists(genomePath)) {
+                            genomePath = getAbsolutePath(genomeId, rootPath);
+                        }
+                        if (ParsingUtils.pathExists(genomePath)) {
+                            GenomeManager.getInstance().loadGenome(genomePath, null);
+
+                        } else {
+                            MessageUtils.showMessage("Warning: Could not locate genome: " + genomeId);
+                        }
                     }
+                } catch (IOException e) {
+                    MessageUtils.showErrorMessage("Error loading genome: " + genomeId, e);
+                    log.error("Error loading genome: " + genomeId, e);
                 }
+
+
                 session.setPath(sessionPath);
             }
         }
@@ -444,11 +458,12 @@ public class IGVSessionReader implements SessionReader {
             }
         }
 
+        session.setUcscId(getAttribute(element, SessionAttribute.UCSC_ID.getText()));
         session.setLocus(getAttribute(element, SessionAttribute.LOCUS.getText()));
         session.setGroupTracksBy(getAttribute(element, SessionAttribute.GROUP_TRACKS_BY.getText()));
 
         String nextAutoscaleGroup = getAttribute(element, SessionAttribute.NEXT_AUTOSCALE_GROUP.getText());
-        if(nextAutoscaleGroup != null) {
+        if (nextAutoscaleGroup != null) {
             try {
                 session.setNextAutoscaleGroup(Integer.parseInt(nextAutoscaleGroup));
             } catch (NumberFormatException e) {
@@ -560,9 +575,11 @@ public class IGVSessionReader implements SessionReader {
     }
 
     private void processResources(Session session, Element element, HashMap additionalInformation, String rootPath, String alternateRootPath) {
+
         dataFiles = new ArrayList();
         missingDataFiles = new ArrayList();
         NodeList elements = element.getChildNodes();
+
         process(session, elements, additionalInformation, rootPath, alternateRootPath);
 
         if (missingDataFiles.size() > 0) {
@@ -634,7 +651,7 @@ public class IGVSessionReader implements SessionReader {
                             }
                         } catch (Exception e) {
                             log.error("Error loading resource " + locator.getPath(), e);
-                            String ms = "<b>" + locator.getPath() + "</b><br>&nbs;p&nbsp;" + e.toString() + "<br>";
+                            String ms = "<b>" + locator.getPath() + "</b><br>&nbsp;&nbsp;" + e.toString() + "<br>";
                             errors.add(ms);
                         }
                     }
@@ -732,7 +749,7 @@ public class IGVSessionReader implements SessionReader {
         }
 
         String absolutePath = "ga4gh".equals(type) ? path :
-                getAbsolutePath(path, rootPath, alternateRootPath);
+                getAbsolutePath(path, rootPath);
 
         fullToRelPathMap.put(absolutePath, path);
 
@@ -741,12 +758,12 @@ public class IGVSessionReader implements SessionReader {
         if (index != null) resourceLocator.setIndexPath(index);
 
         if (coverage != null) {
-            String absoluteCoveragePath = coverage.equals(".") ? coverage : getAbsolutePath(coverage, rootPath, alternateRootPath);
+            String absoluteCoveragePath = coverage.equals(".") ? coverage : getAbsolutePath(coverage, rootPath);
             resourceLocator.setCoverage(absoluteCoveragePath);
         }
 
         if (mapping != null) {
-            String absoluteMappingPath = mapping.equals(".") ? mapping : getAbsolutePath(mapping, rootPath, alternateRootPath);
+            String absoluteMappingPath = mapping.equals(".") ? mapping : getAbsolutePath(mapping, rootPath);
             resourceLocator.setMappingPath(absoluteMappingPath);
         }
 
@@ -797,15 +814,10 @@ public class IGVSessionReader implements SessionReader {
 
     }
 
-    private String getAbsolutePath(String path, String rootPath, String alternateRootPath) {
+    private String getAbsolutePath(String path, String rootPath) {
 
         String absolutePath = FileUtils.getAbsolutePath(path, rootPath);
 
-        // Session file might have been moved, try to correct if the path is a local file (not an http or ftp url)
-        if (alternateRootPath != null && !FileUtils.isRemote(absolutePath) && !(new File(absolutePath).exists())) {
-            absolutePath = FileUtils.getAbsolutePath(path, alternateRootPath);
-        }
-
         return absolutePath;
     }
 
@@ -1077,12 +1089,11 @@ public class IGVSessionReader implements SessionReader {
 
         if (matchedTracks == null) {
             //Try creating an "absolute" path for the id
-            matchedTracks = allTracks.get(getAbsolutePath(id, rootPath, alternateRootPath));
+            matchedTracks = allTracks.get(getAbsolutePath(id, rootPath));
         }
 
         if (matchedTracks == null) {
 
-            log.info("Warning.  No tracks were found with id: " + id + " in session file");
             String className = getAttribute(element, "clazz");
 
             //We try anyway, some tracks can be reconstructed without a resource element
@@ -1110,6 +1121,8 @@ public class IGVSessionReader implements SessionReader {
                     }
                     if (track != null) {
                         allTracks.put(track.getId(), matchedTracks);
+                    } else {
+                        log.info("Warning.  No tracks were found with id: " + id + " in session file");
                     }
                 }
             } catch (JAXBException e) {
@@ -1127,7 +1140,7 @@ public class IGVSessionReader implements SessionReader {
 
                     // Special case for sequence & gene tracks, they need to be removed before being placed.
                     if (igv != null && version >= 4 && (track == geneTrack || track == seqTrack)) {
-                        igv.removeTracks(Arrays.asList(track));
+                        igv.removeTracks(Arrays.asList(track), false);
                     }
                     unmarshalTrackElement(u, element, (AbstractTrack) track);
                 }
@@ -1338,6 +1351,7 @@ public class IGVSessionReader implements SessionReader {
             AbstractTrack.knownUnknownTrackClasses.add(unmarshalClass);
             return unmarshalTrack(u, node, firstClass, unmarshalClass.getSuperclass());
         }
+
         return (AbstractTrack) el.getValue();
     }
 
