@@ -26,10 +26,11 @@
 package org.broad.igv.session;
 
 import org.apache.log4j.Logger;
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.RegionOfInterest;
 import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.lists.GeneList;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.session.IGVSessionReader.SessionAttribute;
 import org.broad.igv.session.IGVSessionReader.SessionElement;
 import org.broad.igv.track.*;
@@ -320,7 +321,7 @@ public class SessionWriter {
 
                     //REQUIRED ATTRIBUTES - Cannot be null
 
-                    boolean useRelative = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SESSION_RELATIVE_PATH);
+                    boolean useRelative = PreferencesManager.getPreferences().getAsBoolean(Constants.SESSION_RELATIVE_PATH);
 
                     String relativePath = useRelative ?
                             FileUtils.getRelativePath(outputFile.getAbsolutePath(), resourceLocator.getPath()) :
