@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 /*
@@ -15,7 +29,7 @@
  */
 package org.broad.igv.tdf;
 
-import net.sf.samtools.seekablestream.SeekableStream;
+import htsjdk.samtools.seekablestream.SeekableStream;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
 import org.broad.igv.exceptions.DataLoadException;
@@ -50,8 +64,8 @@ public class TDFReader {
     private String trackLine;
     private String[] trackNames;
     private String genomeId;
-    LRUCache<String, TDFGroup> groupCache = new LRUCache(this, 20);
-    LRUCache<String, TDFDataset> datasetCache = new LRUCache(this, 20);
+    LRUCache<String, TDFGroup> groupCache = new LRUCache(20);
+    LRUCache<String, TDFDataset> datasetCache = new LRUCache(20);
     TDFTile wgTile;
 
     Map<WindowFunction, Double> valueCache = new HashMap();
@@ -77,8 +91,8 @@ public class TDFReader {
         //this.path = path;
         this.locator = locator;
         try {
-            log.info("Getting stream");
-            seekableStream = IGVSeekableStreamFactory.getStreamFor(locator.getPath());
+            log.debug("Getting stream");
+            seekableStream = IGVSeekableStreamFactory.getInstance().getStreamFor(locator.getPath());
             log.debug("Reading header");
             readHeader();
             log.debug("Done reading header");
@@ -118,9 +132,9 @@ public class TDFReader {
         System.arraycopy(buffer, 0, magicBytes, 0, 4);
         String magicString = new String(magicBytes);
 
-        if (!(magicString.startsWith("TDF") || !magicString.startsWith("IBF"))) {
+        if (!(magicString.startsWith("TDF") || magicString.startsWith("IBF"))) {
             String msg = "Error reading header: bad magic number.";
-            //    throw new DataLoadException(msg, locator.getPath());
+            throw new DataLoadException(msg, locator.getPath());
         }
 
         version = byteBuffer.getInt();
