@@ -27,10 +27,13 @@ package org.broad.igv.track;
 
 //~--- non-JDK imports --------------------------------------------------------
 
+import htsjdk.tribble.Feature;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
-import org.broad.igv.PreferenceManager;
+import org.broad.igv.event.IGVEventBus;
+import org.broad.igv.event.IGVEventObserver;
 import org.broad.igv.gwas.GWASTrack;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.renderer.*;
 import org.broad.igv.sam.AlignmentTrack;
 import org.broad.igv.sam.CoverageTrack;
@@ -48,23 +51,25 @@ import org.broad.igv.ui.panel.ReferenceFrame;
 import org.broad.igv.ui.util.UIUtilities;
 import org.broad.igv.util.ResourceLocator;
 import org.broad.igv.util.Utilities;
-import htsjdk.tribble.Feature;
 import org.w3c.dom.Node;
 
 import javax.xml.bind.JAXBException;
 import javax.xml.bind.annotation.*;
+import javax.xml.bind.annotation.adapters.XmlAdapter;
 import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
 import java.awt.*;
 import java.awt.event.MouseEvent;
 import java.util.*;
 import java.util.List;
 
+import static org.broad.igv.prefs.Constants.*;
+
 /**
  * @author jrobinso
  */
 @XmlType(factoryClass = IGVSessionReader.class, factoryMethod = "getNextTrack")
 @XmlAccessorType(XmlAccessType.NONE)
-@XmlSeeAlso({CoverageTrack.class, AlignmentTrack.class, DataSourceTrack.class, GWASTrack.class, FeatureTrack.class, MergedTracks.class})
+@XmlSeeAlso({CNFreqTrack.class, CoverageTrack.class, AlignmentTrack.class, DataSourceTrack.class, GWASTrack.class, FeatureTrack.class, MergedTracks.class})
 public abstract class AbstractTrack implements Track {
 
     private static Logger log = Logger.getLogger(AbstractTrack.class);
@@ -98,8 +103,10 @@ public abstract class AbstractTrack implements Track {
 
     @XmlAttribute
     private String id;
+
     @XmlAttribute
     private String name;
+
     private String url;
     private boolean itemRGB = true;
 
@@ -109,7 +116,7 @@ public abstract class AbstractTrack implements Track {
 
 
     @XmlAttribute
-    protected int fontSize = PreferenceManager.getInstance().getAsInt(PreferenceManager.DEFAULT_FONT_SIZE);
+    protected int fontSize = PreferencesManager.getPreferences().getAsInt(DEFAULT_FONT_SIZE);
     private boolean showDataRange = true;
     private String sampleId;
 
@@ -125,6 +132,7 @@ public abstract class AbstractTrack implements Track {
 
     @XmlAttribute
     private boolean visible = true;
+
     @XmlAttribute
     private boolean sortable = true;
 
@@ -133,7 +141,9 @@ public abstract class AbstractTrack implements Track {
     boolean drawYLine = false;
     float yLine = 0;
 
-    // Map to store attributes specific to this track.  Attributes shared by multiple
+    // Map to store attributes specific to this track.
+    //@XmlElement(name = "Attributes")
+    //@XmlJavaTypeAdapter(MapAdapter.class)
     private Map<String, String> attributes = new HashMap();
 
     // Scale for heatmaps
@@ -146,6 +156,9 @@ public abstract class AbstractTrack implements Track {
     @XmlAttribute
     protected boolean autoScale;
 
+    @XmlAttribute
+    String autoscaleGroup;
+
     @XmlJavaTypeAdapter(SessionXmlAdapters.Color.class)
     @XmlAttribute(name = "color")
     protected Color posColor = Color.blue.darker();
@@ -198,8 +211,8 @@ public abstract class AbstractTrack implements Track {
     }
 
     private void init() {
-        showDataRange = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.CHART_SHOW_DATA_RANGE);
-        if (PreferenceManager.getInstance().getAsBoolean(PreferenceManager.EXPAND_FEAUTRE_TRACKS)) {
+        showDataRange = PreferencesManager.getPreferences().getAsBoolean(CHART_SHOW_DATA_RANGE);
+        if (PreferencesManager.getPreferences().getAsBoolean(EXPAND_FEAUTRE_TRACKS)) {
             displayMode = DisplayMode.EXPANDED;
         }
     }
@@ -250,11 +263,6 @@ public abstract class AbstractTrack implements Track {
         this.sampleId = sampleId;
     }
 
-    @Override
-    public void load(ReferenceFrame referenceFrame) {
-        // No-op, to be overriden by subclasses
-    }
-
     @Override
     public boolean isFilterable() {
         return true;   // True by default
@@ -365,13 +373,23 @@ public abstract class AbstractTrack implements Track {
      */
     public void setAttributeValue(String name, String value) {
         String key = name.toUpperCase();
-        attributes.put(key, value);
+        if (key.equals(AttributeManager.GROUP_AUTOSCALE)) {
+            autoscaleGroup = value;
+        } else {
+            attributes.put(key, value);
+        }
         AttributeManager.getInstance().addAttribute(getSample(), name, value);
+
     }
 
     public void removeAttribute(String name) {
         String key = name.toUpperCase();
-        attributes.remove(key);
+        if (key.equals(AttributeManager.GROUP_AUTOSCALE)) {
+            autoscaleGroup = null;
+        }
+        else {
+            attributes.remove(key);
+        }
         AttributeManager.getInstance().removeAttribute(getSample(), name);
     }
 
@@ -388,17 +406,25 @@ public abstract class AbstractTrack implements Track {
      * @return
      */
     public String getAttributeValue(String attributeName) {
+
         String key = attributeName.toUpperCase();
-        String value = attributes.get(key);
-        final AttributeManager attributeManager = AttributeManager.getInstance();
-        if (value == null && getSample() != null) {
-            value = attributeManager.getAttribute(getSample(), key);
+        String value;
+        if (key.equals(AttributeManager.GROUP_AUTOSCALE)) {
+            value = autoscaleGroup;
         }
-        if (value == null) {
-            value = attributeManager.getAttribute(getName(), key);
-        }
-        if (value == null && getResourceLocator() != null && getResourceLocator().getPath() != null) {
-            value = attributeManager.getAttribute(getResourceLocator().getPath(), key);
+        else {
+            value = attributes.get(key);
+
+            final AttributeManager attributeManager = AttributeManager.getInstance();
+            if (value == null && getSample() != null) {
+                value = attributeManager.getAttribute(getSample(), key);
+            }
+            if (value == null) {
+                value = attributeManager.getAttribute(getName(), key);
+            }
+            if (value == null && getResourceLocator() != null && getResourceLocator().getPath() != null) {
+                value = attributeManager.getAttribute(getResourceLocator().getPath(), key);
+            }
         }
         return value;
     }
@@ -426,9 +452,9 @@ public abstract class AbstractTrack implements Track {
      */
     private int getDefaultHeight() {
         if (XYPlotRenderer.class.isAssignableFrom(getDefaultRendererClass())) {
-            return PreferenceManager.getInstance().getAsInt(PreferenceManager.CHART_TRACK_HEIGHT_KEY);
+            return PreferencesManager.getPreferences().getAsInt(CHART_TRACK_HEIGHT_KEY);
         } else {
-            return PreferenceManager.getInstance().getAsInt(PreferenceManager.TRACK_HEIGHT_KEY);
+            return PreferencesManager.getPreferences().getAsInt(TRACK_HEIGHT_KEY);
         }
     }
 
@@ -490,7 +516,7 @@ public abstract class AbstractTrack implements Track {
                 if (overlaid) {
                     return false;
                 } else {
-                    return PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SHOW_ORPHANED_MUTATIONS);
+                    return PreferencesManager.getPreferences().getAsBoolean(SHOW_ORPHANED_MUTATIONS);
                 }
             }
         }
@@ -592,7 +618,7 @@ public abstract class AbstractTrack implements Track {
     protected boolean openTooltipWindow(TrackClickEvent e) {
         ReferenceFrame frame = e.getFrame();
         final MouseEvent me = e.getMouseEvent();
-        String popupText = getValueStringAt(frame.getChrName(), e.getChromosomePosition(), e.getMouseEvent().getY(), frame);
+        String popupText = getValueStringAt(frame.getChrName(), e.getChromosomePosition(), e.getMouseEvent().getX(), e.getMouseEvent().getY(), frame);
 
         if (popupText != null) {
 
@@ -709,7 +735,7 @@ public abstract class AbstractTrack implements Track {
         }
         if (properties.getRendererClass() != null) {
             setRendererClass(properties.getRendererClass());
-            if(properties.getRendererClass() == PointsRenderer.class) {
+            if (properties.getRendererClass() == PointsRenderer.class) {
                 setWindowFunction(WindowFunction.none);
             }
         }
@@ -835,12 +861,12 @@ public abstract class AbstractTrack implements Track {
             setName(displayName);
         }
 
-        if(attributes.containsKey("visible")) {
+        if (attributes.containsKey("visible")) {
             this.setVisible(Boolean.parseBoolean(attributes.get("visible")));
         }
 
         // Set DataRange -- legacy (pre V3 sessions)
-        if(version <= 3){
+        if (version <= 3) {
             String scale = attributes.get(IGVSessionReader.SessionAttribute.SCALE.getText());
             if (scale != null) {
                 String[] axis = scale.split(",");
@@ -971,7 +997,7 @@ public abstract class AbstractTrack implements Track {
         StringBuffer buffer = new StringBuffer();
         buffer.append("<html>" + getName());
 
-        if(resourceLocator != null && resourceLocator.getPath() != null) {
+        if (resourceLocator != null && resourceLocator.getPath() != null) {
             buffer.append("<br>" + this.resourceLocator.getPath());
         }
 
@@ -984,11 +1010,10 @@ public abstract class AbstractTrack implements Track {
      *
      * @param chr
      * @param position
-     * @param y
-     * @param frame
-     * @return
+     * @param mouseX
+     * @param frame    @return
      */
-    public String getValueStringAt(String chr, double position, int y, ReferenceFrame frame) {
+    public String getValueStringAt(String chr, double position, int mouseX, int mouseY, ReferenceFrame frame) {
         return null;
     }
 
@@ -1047,8 +1072,9 @@ public abstract class AbstractTrack implements Track {
 
     @Override
     public void dispose() {
-        // Default is to do nothing.  Override in subclasses
-
+        if (this instanceof IGVEventObserver) {
+            IGVEventBus.getInstance().unsubscribe((IGVEventObserver) this);
+        }
     }
 
 
@@ -1064,8 +1090,72 @@ public abstract class AbstractTrack implements Track {
     }
 
     // Start of Roche-Tessella modification
-    public boolean getAutoScale()    {
+    public boolean getAutoScale() {
         return this.autoScale;
     }
     // End of Roche-Tessella modification
+
+
+    // JAXB adapters
+
+    static class Properties {
+
+        @XmlElement(name = "property")
+        private List<KeyValue> entries = new ArrayList<>();
+
+        List<KeyValue> entries() {
+            return Collections.unmodifiableList(entries);
+        }
+
+        void addEntry(KeyValue entry) {
+            entries.add(entry);
+        }
+    }
+
+
+    static class KeyValue {
+
+        @XmlElement(name = "key")
+        private String key;
+
+        @XmlElement(name = "value")
+        private String value;
+
+        public KeyValue() {
+        }
+
+        public KeyValue(String key, String value) {
+            this.key = key;
+            this.value = value;
+        }
+
+        public String getKey() {
+            return key;
+        }
+
+        public String getValue() {
+            return value;
+        }
+    }
+
+    static class MapAdapter extends XmlAdapter<Properties, Map<String, String>> {
+
+        @Override
+        public HashMap<String, String> unmarshal(Properties v) throws Exception {
+            HashMap<String, String> map = new HashMap<>();
+            for (KeyValue kv : v.entries()) {
+                map.put(kv.getKey(), kv.getValue());
+            }
+            return map;
+        }
+
+        @Override
+        public Properties marshal(Map<String, String> v) throws Exception {
+            Properties keyValues = new Properties();
+            for (Map.Entry<String, String> entry : v.entrySet()) {
+                keyValues.addEntry(new KeyValue(entry.getKey(), entry.getValue()));
+            }
+            return keyValues;
+        }
+    }
 }
