@@ -30,10 +30,12 @@
  */
 package org.broad.igv.track;
 
+import htsjdk.tribble.readers.AsciiLineReader;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.exceptions.DataLoadException;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.renderer.AbstractColorScale;
 import org.broad.igv.renderer.ContinuousColorScale;
 import org.broad.igv.renderer.MonocolorScale;
@@ -47,7 +49,6 @@ import org.broad.igv.util.FileUtils;
 import org.broad.igv.util.ParsingUtils;
 import org.broad.igv.util.ResourceLocator;
 import org.broad.igv.util.Utilities;
-import htsjdk.tribble.readers.AsciiLineReader;
 
 import java.awt.*;
 import java.beans.PropertyChangeEvent;
@@ -516,7 +517,7 @@ public class AttributeManager {
             trackSampleMappings.put(track, sample);
             return sample;
         } else {
-            String key = PreferenceManager.getInstance().get(PreferenceManager.OVERLAY_ATTRIBUTE_KEY);
+            String key = PreferencesManager.getPreferences().get(Constants.OVERLAY_ATTRIBUTE_KEY);
             return key == null ? null : getAttribute(track, key);
         }
     }
