@@ -66,6 +66,8 @@ public class GisticTrack extends AbstractTrack {
 
     private double maxGScore = 0;
 
+    private boolean hasScores = false;
+
     /**
      * Map of chromosome -> sorted list of scores
      */
@@ -75,7 +77,6 @@ public class GisticTrack extends AbstractTrack {
 
     GisticTrackRenderer renderer;
 
-
     public GisticTrack(ResourceLocator locator) {
         super(locator);
         ampScoreMap = new HashMap<String, List<GisticScore>>();
@@ -87,19 +88,26 @@ public class GisticTrack extends AbstractTrack {
 
     }
 
+    @Override
+    public boolean isReadyToPaint(ReferenceFrame frame) {
+        return hasScores;
+    }
+
+    @Override
+    public void load(ReferenceFrame referenceFrame) {
+        //
+    }
+
     @Override
     public int getMinimumHeight() {
         return 25;
     }
 
 
-    /**
-     * Method description
-     *
-     * @param scores
-     */
     public void setScores(List<GisticScore> scores) {
 
+        this.hasScores = true;
+
         for (GisticScore score : scores) {
             String chr = score.getChromosome();
             if (score.getType() == GisticScore.Type.AMP) {
@@ -336,10 +344,10 @@ public class GisticTrack extends AbstractTrack {
      *
      * @param chr
      * @param position
-     * @param ignore
-     * @return
+     * @param mouseX
+     *@param ignore  @return
      */
-    public String getValueStringAt(String chr, double position, int ignore, ReferenceFrame frame) {
+    public String getValueStringAt(String chr, double position, int mouseX, int ignore, ReferenceFrame frame) {
 
         // give a 2 pixel window, otherwise very narrow features will be missed.
         double bpPerPixel = frame.getScale();
