@@ -25,9 +25,10 @@
 
 package org.broad.igv.track;
 
+import htsjdk.tribble.AsciiFeatureCodec;
 import htsjdk.tribble.Feature;
+import htsjdk.variant.vcf.VCFHeader;
 import org.apache.log4j.Logger;
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.bbfile.BBFileReader;
 import org.broad.igv.bigwig.BigWigDataSource;
 import org.broad.igv.das.DASFeatureSource;
@@ -47,18 +48,16 @@ import org.broad.igv.dev.db.SQLCodecSource;
 import org.broad.igv.dev.db.SampleInfoSQLReader;
 import org.broad.igv.dev.db.SegmentedSQLReader;
 import org.broad.igv.exceptions.DataLoadException;
+import org.broad.igv.feature.*;
 import org.broad.igv.feature.basepair.BasePairTrack;
-import org.broad.igv.feature.BasePairFileUtils;
-import org.broad.igv.feature.ShapeFileUtils;
-import org.broad.igv.feature.CachingFeatureSource;
-import org.broad.igv.feature.GisticFileParser;
-import org.broad.igv.feature.MutationTrackLoader;
 import org.broad.igv.feature.bionano.SMAPParser;
 import org.broad.igv.feature.bionano.SMAPRenderer;
 import org.broad.igv.feature.dranger.DRangerParser;
 import org.broad.igv.feature.dsi.DSIRenderer;
 import org.broad.igv.feature.dsi.DSITrack;
-import org.broad.igv.feature.genome.*;
+import org.broad.igv.feature.genome.GenbankParser;
+import org.broad.igv.feature.genome.Genome;
+import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.feature.tribble.CodecFactory;
 import org.broad.igv.feature.tribble.FeatureFileHeader;
 import org.broad.igv.feature.tribble.TribbleIndexNotFoundException;
@@ -71,10 +70,11 @@ import org.broad.igv.gwas.GWASParser;
 import org.broad.igv.gwas.GWASTrack;
 import org.broad.igv.lists.GeneList;
 import org.broad.igv.lists.GeneListManager;
-import org.broad.igv.lists.VariantListManager;
 import org.broad.igv.maf.MultipleAlignmentTrack;
 import org.broad.igv.methyl.MethylTrack;
 import org.broad.igv.peaks.PeakTrack;
+import org.broad.igv.prefs.IGVPreferences;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.renderer.*;
 import org.broad.igv.sam.*;
 import org.broad.igv.sam.reader.IndexNotFoundException;
@@ -84,17 +84,15 @@ import org.broad.igv.tdf.TDFDataSource;
 import org.broad.igv.tdf.TDFReader;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.util.ConfirmDialog;
-import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.ui.util.ConvertFileDialog;
 import org.broad.igv.ui.util.ConvertOptions;
+import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.util.FileUtils;
 import org.broad.igv.util.HttpUtils;
 import org.broad.igv.util.ParsingUtils;
 import org.broad.igv.util.ResourceLocator;
 import org.broad.igv.variant.VariantTrack;
 import org.broad.igv.variant.util.PedigreeUtils;
-import htsjdk.tribble.AsciiFeatureCodec;
-import htsjdk.variant.vcf.VCFHeader;
 
 import java.awt.*;
 import java.io.IOException;
@@ -102,6 +100,8 @@ import java.net.MalformedURLException;
 import java.util.*;
 import java.util.List;
 
+import static org.broad.igv.prefs.Constants.*;
+
 /**
  * User: jrobinso
  * Date: Feb 14, 2010
@@ -149,11 +149,7 @@ public class TrackLoader {
                 loadVCFListFile(locator, newTracks, genome);
             } else if (typeString.endsWith(".trio")) {
                 loadTrioData(locator);
-            } else if (typeString.endsWith("varlist")) {
-                VariantListManager.loadVariants(locator);
-            } else if (typeString.endsWith("samplepathmap")) {
-                VariantListManager.loadSamplePathMap(locator);
-            } else if (typeString.endsWith(".rnai.gct")) {
+            }  else if (typeString.endsWith(".rnai.gct")) {
                 loadRnaiGctFile(locator, newTracks, genome);
             } else if (typeString.endsWith(".gct") || typeString.endsWith("res") || typeString.endsWith("tab")) {
                 loadGctFile(locator, newTracks, genome);
@@ -200,7 +196,12 @@ public class TrackLoader {
             } else if (WiggleParser.isWiggle(locator)) {
                 loadWigFile(locator, newTracks, genome);
             } else if (typeString.endsWith(".maf")) {
-                loadMultipleAlignmentTrack(locator, newTracks, genome);
+                if (MutationTrackLoader.isMutationAnnotationFile(locator)) {
+                    loadMutFile(locator, newTracks, genome); // Must be tried before generic "loadIndexed" below
+                }
+                else {
+                    loadMultipleAlignmentTrack(locator, newTracks, genome);
+                }
             } else if (typeString.endsWith(".maf.dict")) {
                 loadMultipleAlignmentTrack(locator, newTracks, genome);
             } else if (typeString.contains(".peak.bin")) {
@@ -275,7 +276,7 @@ public class TrackLoader {
     }
 
     public static boolean isAlignmentTrack(String typeString) {
-        return typeString.endsWith(".sam") || typeString.endsWith(".bam") ||
+        return typeString.endsWith(".sam") || typeString.endsWith(".bam") || typeString.endsWith(".cram") ||
                 typeString.endsWith(".sam.list") || typeString.endsWith(".bam.list") ||
                 typeString.endsWith(".aligned") || typeString.endsWith(".sai") ||
                 typeString.endsWith(".bai") || typeString.equals("alist") ||
@@ -632,7 +633,7 @@ public class TrackLoader {
 
     private static boolean checkSize(ResourceLocator locator) {
 
-        if (!PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SHOW_SIZE_WARNING)) {
+        if (!PreferencesManager.getPreferences().getAsBoolean(SHOW_SIZE_WARNING)) {
             return true;
         }
 
@@ -653,7 +654,7 @@ public class TrackLoader {
                     "command line program. See the user guide for more details.<br><br>Click <b>Continue</b> " +
                     "to continue loading, or <b>Cancel</b> to skip this file.";
 
-            return ConfirmDialog.optionallyShowConfirmDialog(message, PreferenceManager.SHOW_SIZE_WARNING, true);
+            return ConfirmDialog.optionallyShowConfirmDialog(message, SHOW_SIZE_WARNING, true);
 
 
         }
@@ -937,7 +938,7 @@ public class TrackLoader {
                 }
             }
 
-            if (locator.getPath().toLowerCase().endsWith(".bam")) {
+            if (locator.getTypeString().endsWith("bam") || locator.getTypeString().endsWith("cram")) {
                 if (!dataManager.hasIndex()) {
                     MessageUtils.showMessage("<html>Could not load index file for: " +
                             locator.getPath() + "<br>  An index file is required for SAM & BAM files.");
@@ -945,13 +946,13 @@ public class TrackLoader {
                 }
             }
 
-            AlignmentTrack alignmentTrack = new AlignmentTrack(locator, dataManager, genome);    // parser.loadTrack(locator, dsName);
+            AlignmentTrack alignmentTrack = new AlignmentTrack(locator, dataManager, genome);    // parser.loadTrack(locator, dsName)
             alignmentTrack.setName(dsName);
-            alignmentTrack.setVisible(PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SAM_SHOW_ALIGNMENT_TRACK));
+            alignmentTrack.setVisible(PreferencesManager.getPreferences().getAsBoolean(SAM_SHOW_ALIGNMENT_TRACK));
 
             // Create coverage track
             CoverageTrack covTrack = new CoverageTrack(locator, dsName + " Coverage", alignmentTrack, genome);
-            covTrack.setVisible(PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SAM_SHOW_COV_TRACK));
+            covTrack.setVisible(PreferencesManager.getPreferences().getAsBoolean(SAM_SHOW_COV_TRACK));
             newTracks.add(covTrack);
             covTrack.setDataManager(dataManager);
             dataManager.setCoverageTrack(covTrack);
@@ -966,7 +967,7 @@ public class TrackLoader {
 
                 String covPath = locator.getCoverage();
                 if (covPath == null) {
-                    boolean bypassFileAutoDiscovery = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.BYPASS_FILE_AUTO_DISCOVERY);
+                    boolean bypassFileAutoDiscovery = PreferencesManager.getPreferences().getAsBoolean(BYPASS_FILE_AUTO_DISCOVERY);
                     String path = locator.getPath();
                     if (!bypassFileAutoDiscovery && !path.contains("/query.cgi?")) {
                         covPath = path + ".tdf";
@@ -988,7 +989,7 @@ public class TrackLoader {
                 }
             }
 
-            boolean showSpliceJunctionTrack = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SAM_SHOW_JUNCTION_TRACK);
+            boolean showSpliceJunctionTrack = PreferencesManager.getPreferences().getAsBoolean(SAM_SHOW_JUNCTION_TRACK);
 
             SpliceJunctionTrack spliceJunctionTrack = new SpliceJunctionTrack(locator,
                     dsName + " Junctions", dataManager, alignmentTrack, SpliceJunctionTrack.StrandOption.BOTH);
@@ -1171,14 +1172,7 @@ public class TrackLoader {
             newTracks.add(freqTrack);
         }
 
-        ContinuousColorScale colorScale = null;
-        if (props != null) {
-            Color maxColor = props.getColor();
-            Color minColor = props.getAltColor();
-            if (maxColor != null && minColor != null) {
-                colorScale = PreferenceManager.getDefaultColorScale(minColor, Color.white, maxColor);
-            }
-        }
+
 
         for (String trackName : ds.getSampleNames()) {
             String trackId = path + "_" + trackName;
@@ -1190,9 +1184,6 @@ public class TrackLoader {
             if (props != null) {
                 track.setProperties(props);
             }
-            if (colorScale != null) {
-                track.setColorScale(colorScale);
-            }
 
             newTracks.add(track);
         }
