@@ -25,6 +25,7 @@
 
 package org.broad.igv.track;
 
+import htsjdk.tribble.AbstractFeatureReader;
 import org.broad.igv.Globals;
 import org.broad.igv.data.AbstractDataSource;
 import org.broad.igv.data.DataTile;
@@ -136,8 +137,6 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
 
     public abstract boolean isIndexed();
 
-    public abstract Index getIndex();
-
     public Class getFeatureClass() {
         return featureClass;
     }
@@ -184,11 +183,6 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
             return true;
         }
 
-        @Override
-        public Index getIndex() {
-            return this.reader.getIndex();
-        }
-
         @Override
         public Iterator<Feature> getFeatures(String chr, int start, int end) throws IOException {
 
@@ -334,14 +328,24 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
             }
         }
 
+        @Override
+        public void dispose() {
+            super.dispose();
+            for(List<Feature> featureList : featureMap.values()) {
+                for(Feature f : featureList) {
+                    if(f instanceof NamedFeature) FeatureDB.removeFeature((NamedFeature) f, genome);
+                }
+            }
+        }
+
         @Override
         public boolean isIndexed() {
             return false;
         }
 
         @Override
-        public Index getIndex() {
-            return null;
+        public boolean isLoaded(ReferenceFrame frame) {
+            return true;
         }
 
         @Override
