@@ -25,13 +25,17 @@
 
 package org.broad.igv.ui;
 
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.IExon;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.renderer.SashimiJunctionRenderer;
 import org.broad.igv.sam.*;
 import org.broad.igv.track.*;
 import org.broad.igv.ui.color.ColorPalette;
 import org.broad.igv.ui.color.ColorUtilities;
+import org.broad.igv.event.IGVEventBus;
+import org.broad.igv.event.IGVEventObserver;
+import org.broad.igv.event.ViewChange;
 import org.broad.igv.ui.panel.*;
 import org.broad.igv.ui.util.UIUtilities;
 
@@ -55,11 +59,14 @@ import java.util.List;
  * User: jacob
  * Date: 2013-Jan-11
  */
-public class SashimiPlot extends JFrame {
+public class SashimiPlot extends JFrame implements IGVEventObserver {
 
     private List<SpliceJunctionTrack> spliceJunctionTracks;
+
     private ReferenceFrame frame;
 
+    private IGVEventBus eventBus;
+
     /**
      * The minimum allowed origin of the frame. We set scrolling
      * limits based on initialization
@@ -82,10 +89,12 @@ public class SashimiPlot extends JFrame {
 
 
     public SashimiPlot(ReferenceFrame iframe, Collection<? extends AlignmentTrack> alignmentTracks, FeatureTrack geneTrack) {
-        getGlassPane().setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
-        int minJunctionCoverage = PreferenceManager.getInstance().getAsInt(PreferenceManager.SAM_JUNCTION_MIN_COVERAGE);
 
-        this.frame = new ReferenceFrame(iframe);
+        getGlassPane().setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
+        int minJunctionCoverage = PreferencesManager.getPreferences().getAsInt(Constants.SAM_JUNCTION_MIN_COVERAGE);
+
+        this.eventBus = new IGVEventBus();
+        this.frame = new ReferenceFrame(iframe, eventBus);
 
         minOrigin = this.frame.getOrigin();
         maxEnd = this.frame.getEnd();
@@ -98,17 +107,19 @@ public class SashimiPlot extends JFrame {
         //Add control elements to the top
         getContentPane().add(generateControlPanel(this.frame));
 
-        spliceJunctionTracks = new ArrayList<SpliceJunctionTrack>(alignmentTracks.size());
+        spliceJunctionTracks = new ArrayList<>(alignmentTracks.size());
         int colorInd = 0;
 
+        eventBus.subscribe(ViewChange.class, this);
+
         for (AlignmentTrack alignmentTrack : alignmentTracks) {
 
 
-            AlignmentDataManager oldDataManager = alignmentTrack.getDataManager();
-            MemoryAlignmentDataManager dataManager = new MemoryAlignmentDataManager(oldDataManager, oldDataManager.getSpliceJunctionLoadOptions());
+            //AlignmentDataManager oldDataManager = alignmentTrack.getDataManager();
+            AlignmentDataManager dataManager = alignmentTrack.getDataManager();
 
             SpliceJunctionTrack spliceJunctionTrack =
-                    new SpliceJunctionTrack(alignmentTrack.getResourceLocator(), alignmentTrack.getName(), dataManager, null, SpliceJunctionTrack.StrandOption.COMBINE);
+                    new SpliceJunctionTrack(alignmentTrack.getResourceLocator(), alignmentTrack.getName(), dataManager, alignmentTrack, SpliceJunctionTrack.StrandOption.COMBINE);
             // Override expand/collpase setting -- expanded sashimi plots make no sense
             spliceJunctionTrack.setDisplayMode(Track.DisplayMode.COLLAPSED);
 
@@ -119,11 +130,14 @@ public class SashimiPlot extends JFrame {
             spliceJunctionTrack.setColor(color);
 
             TrackComponent<SpliceJunctionTrack> trackComponent = new TrackComponent<SpliceJunctionTrack>(frame, spliceJunctionTrack);
+            trackComponent.originalFrame = iframe;
 
-            initSpliceJunctionComponent(trackComponent, dataManager, oldDataManager.getCoverageTrack(), minJunctionCoverage);
+            initSpliceJunctionComponent(trackComponent, dataManager,dataManager.getCoverageTrack(), minJunctionCoverage);
 
             getContentPane().add(trackComponent);
             spliceJunctionTracks.add(spliceJunctionTrack);
+
+            spliceJunctionTrack.load(iframe);  // <= Must "load" tracks with frame of alignment track (actually just fetches from cache)
         }
 
         Axis axis = createAxis(frame);
@@ -153,10 +167,6 @@ public class SashimiPlot extends JFrame {
 
         Dimension controlSize = new Dimension(200, 30);
 
-        //JSlider scaleSlider = new JSlider(JSlider.HORIZONTAL);
-        //setFixedSize(scaleSlider, controlSize);
-        //controlPanel.add(scaleSlider);
-
         controlPanel.add(zoomSliderPanel);
         setFixedSize(zoomSliderPanel, controlSize);
 
@@ -197,8 +207,7 @@ public class SashimiPlot extends JFrame {
         geneTrack.setDisplayMode(Track.DisplayMode.SQUISHED);
 
         geneTrack.clearPackedFeatures();
-        RenderContext context = new RenderContextImpl(geneComponent, null, frame, null);
-        geneTrack.setForceLoadSync(true);
+        RenderContext context = new RenderContext(geneComponent, null, frame, null);
         geneTrack.load(context.getReferenceFrame());
 
 
@@ -213,14 +222,14 @@ public class SashimiPlot extends JFrame {
         geneComponent.addMouseMotionListener(ad2);
     }
 
-    private void initSpliceJunctionComponent(TrackComponent<SpliceJunctionTrack> trackComponent, IAlignmentDataManager dataManager, CoverageTrack coverageTrack, int minJunctionCoverage) {
+    private void initSpliceJunctionComponent(TrackComponent<SpliceJunctionTrack> trackComponent, AlignmentDataManager dataManager, CoverageTrack coverageTrack, int minJunctionCoverage) {
         JunctionTrackMouseAdapter ad1 = new JunctionTrackMouseAdapter(trackComponent);
         trackComponent.addMouseListener(ad1);
         trackComponent.addMouseMotionListener(ad1);
 
         getRenderer(trackComponent.track).setDataManager(dataManager);
         getRenderer(trackComponent.track).setCoverageTrack(coverageTrack);
-        getRenderer(trackComponent.track).getCoverageTrack().rescale(trackComponent.frame);
+        getRenderer(trackComponent.track).getCoverageTrack().rescale(trackComponent.originalFrame);
 
         dataManager.setMinJunctionCoverage(minJunctionCoverage);
 
@@ -231,6 +240,11 @@ public class SashimiPlot extends JFrame {
         return (SashimiJunctionRenderer) spliceJunctionTrack.getRenderer();
     }
 
+    @Override
+    public void receiveEvent(Object event) {
+        repaint();
+    }
+
     /**
      * Should consider using this elsewhere. Single component
      * which contains a single track
@@ -240,6 +254,7 @@ public class SashimiPlot extends JFrame {
         private T track;
         private ReferenceFrame frame;
         private String toolTipText = null;
+        public ReferenceFrame originalFrame;
 
         public TrackComponent(ReferenceFrame frame, T track) {
             this.frame = frame;
@@ -247,7 +262,7 @@ public class SashimiPlot extends JFrame {
         }
 
         public void updateToolTipText(TrackClickEvent tce) {
-            toolTipText = track.getValueStringAt(tce.getFrame().getChrName(), tce.getChromosomePosition(), tce.getMouseEvent().getY(), tce.getFrame());
+            toolTipText = track.getValueStringAt(tce.getFrame().getChrName(), tce.getChromosomePosition(), tce.getMouseEvent().getX(), tce.getMouseEvent().getY(), tce.getFrame());
             toolTipText = "<html>" + toolTipText;
             setToolTipText(toolTipText);
         }
@@ -256,7 +271,7 @@ public class SashimiPlot extends JFrame {
         public void paintComponent(Graphics g) {
             super.paintComponent(g);
             Rectangle visibleRect = getVisibleRect();
-            RenderContext context = new RenderContextImpl(this, (Graphics2D) g, frame, visibleRect);
+            RenderContext context = new RenderContext(this, (Graphics2D) g, frame, visibleRect);
             track.render(context, visibleRect);
         }
 
@@ -272,7 +287,7 @@ public class SashimiPlot extends JFrame {
      * @param newMinJunctionCoverage
      */
     private void setMinJunctionCoverage(TrackComponent<SpliceJunctionTrack> trackComponent, int newMinJunctionCoverage) {
-        IAlignmentDataManager dataManager = getRenderer(trackComponent.track).getDataManager();
+        AlignmentDataManager dataManager = getRenderer(trackComponent.track).getDataManager();
         dataManager.setMinJunctionCoverage(newMinJunctionCoverage);
         trackComponent.track.clear();
         trackComponent.repaint();
@@ -307,11 +322,11 @@ public class SashimiPlot extends JFrame {
             IGVPopupMenu menu = new IGVPopupMenu();
 
             final JCheckBoxMenuItem showCoverageData = new JCheckBoxMenuItem("Show Exon Coverage Data");
-            showCoverageData.setSelected(PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SASHIMI_SHOW_COVERAGE));
+            showCoverageData.setSelected(PreferencesManager.getPreferences().getAsBoolean(Constants.SASHIMI_SHOW_COVERAGE));
             showCoverageData.addActionListener(new ActionListener() {
                 @Override
                 public void actionPerformed(ActionEvent e) {
-                    PreferenceManager.getInstance().put(PreferenceManager.SASHIMI_SHOW_COVERAGE, showCoverageData.isSelected());
+                    PreferencesManager.getPreferences().put(Constants.SASHIMI_SHOW_COVERAGE, showCoverageData.isSelected());
                     SashimiPlot.this.repaint();
                 }
             });
@@ -341,7 +356,7 @@ public class SashimiPlot extends JFrame {
             minJunctionCoverage.addActionListener(new ActionListener() {
                 @Override
                 public void actionPerformed(ActionEvent e) {
-                    IAlignmentDataManager dataManager = getRenderer(trackComponent.track).getDataManager();
+                    AlignmentDataManager dataManager = getRenderer(trackComponent.track).getDataManager();
                     SpliceJunctionHelper.LoadOptions loadOptions = dataManager.getSpliceJunctionLoadOptions();
 
                     String input = JOptionPane.showInputDialog("Set Minimum Junction Coverage", loadOptions.minJunctionCoverage);
@@ -682,7 +697,7 @@ public class SashimiPlot extends JFrame {
         protected void paintComponent(Graphics g) {
             super.paintComponent(g);
             Rectangle visibleRect = getVisibleRect();
-            RenderContext context = new RenderContextImpl(this, (Graphics2D) g, frame, visibleRect);
+            RenderContext context = new RenderContext(this, (Graphics2D) g, frame, visibleRect);
             drawGenomicAxis(context, visibleRect);
         }
 
