@@ -26,14 +26,10 @@
 package org.broad.igv.ui;
 
 import org.apache.log4j.Logger;
-import org.broad.igv.DirectoryManager;
-import org.broad.igv.Globals;
 import org.broad.igv.batch.CommandListener;
 import org.broad.igv.dev.db.DBManager;
 import org.broad.igv.feature.RegionOfInterest;
-import org.broad.igv.sam.reader.BAMHttpReader;
 import org.broad.igv.track.Track;
-import org.broad.igv.util.FileUtils;
 
 import java.io.File;
 import java.io.PrintWriter;
