@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2012 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 
@@ -14,20 +28,20 @@ package org.broad.igv.ui.action;
 
 //~--- non-JDK imports --------------------------------------------------------
 
+import htsjdk.tribble.Feature;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.annotations.ForTesting;
 import org.broad.igv.dev.api.NamedFeatureSearcher;
 import org.broad.igv.feature.*;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.lists.GeneList;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.ui.IGV;
-import org.broad.igv.ui.event.ViewChange;
 import org.broad.igv.ui.panel.ReferenceFrame;
 import org.broad.igv.ui.util.MessageUtils;
-import htsjdk.tribble.Feature;
 
 import javax.swing.*;
 import java.awt.*;
@@ -51,7 +65,7 @@ import java.util.List;
 public class SearchCommand {
 
     private static Logger log = Logger.getLogger(SearchCommand.class);
-    public static int SEARCH_LIMIT = 20;
+    public static int SEARCH_LIMIT = 10000;
     private boolean askUser = false;
 
     String searchString;
@@ -204,8 +218,7 @@ public class SearchCommand {
                     referenceFrame.jumpTo(result.chr, result.start, result.end);
                     break;
                 case CHROMOSOME:
-                    referenceFrame.getEventBus().post(new ViewChange.ChromosomeChangeCause(this, result.chr));
-                    referenceFrame.getEventBus().post(new ViewChange.ZoomCause(0));
+                    referenceFrame.changeChromosome(result.chr, true);
                     break;
                 case ERROR:
                 default: {
@@ -519,12 +532,12 @@ public class SearchCommand {
         }
 
         //startEnd will have coordinates if found.
-        chr = genome.getChromosomeAlias(chr);
+        chr = genome.getCanonicalChrName(chr);
         Chromosome chromosome = genome.getChromosome(chr);
         //If we couldn't find chromosome, check
         //whole string
         if (chromosome == null) {
-            chr = genome.getChromosomeAlias(tokens[0]);
+            chr = genome.getCanonicalChrName(tokens[0]);
             chromosome = genome.getChromosome(chr);
             if (chromosome != null) {
                 //Found chromosome
@@ -549,7 +562,7 @@ public class SearchCommand {
     }
 
     private void showFlankedRegion(String chr, int start, int end) {
-        int flankingRegion = PreferenceManager.getInstance().getAsInt(PreferenceManager.FLANKING_REGION);
+        int flankingRegion = PreferencesManager.getPreferences().getAsInt(Constants.FLANKING_REGION);
         int delta;
         if((end - start) == 1) {
             delta = 20; // Don't show flanking region for single base jumps, use 40bp window
@@ -562,7 +575,7 @@ public class SearchCommand {
         start = Math.max(0, start - delta);
         end = end + delta;
 
-        if (PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SEARCH_ZOOM)) {
+        if (PreferencesManager.getPreferences().getAsBoolean(Constants.SEARCH_ZOOM)) {
             referenceFrame.jumpTo(chr, start, end);
         } else {
             int center = (start + end) / 2;
@@ -595,7 +608,7 @@ public class SearchCommand {
                 int widen = 20;
                 start = center - widen;
                 start = Math.max(0, start);
-                end = center + widen + 1;
+                end = center + widen;
             }
 
             return new int[]{Math.min(start, end)-1, Math.max(start, end)};
