@@ -32,7 +32,8 @@ package org.broad.igv.ui.legend;
 
 //~--- non-JDK imports --------------------------------------------------------
 
-import org.broad.igv.PreferenceManager;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.renderer.ColorScale;
 import org.broad.igv.ui.FontManager;
 import org.broad.igv.ui.IGV;
@@ -55,7 +56,7 @@ public class MutationLegendPanel extends LegendPanel {
     }
 
     private void init() {
-        PaletteColorTable prefTable = PreferenceManager.getInstance().getMutationColorScheme();
+        PaletteColorTable prefTable = PreferencesManager.getPreferences().getMutationColorScheme();
         colorTable = new PaletteColorTable();
         for (String key : prefTable.getKeys()) {
             colorTable.put(key, prefTable.get(key));
@@ -63,7 +64,7 @@ public class MutationLegendPanel extends LegendPanel {
     }
 
     protected void persistResetPreferences() {
-        PreferenceManager.getInstance().resetMutationColorScheme();
+        PreferencesManager.getPreferences().resetMutationColorScheme();
         reloadPreferences();
     }
 
@@ -90,7 +91,7 @@ public class MutationLegendPanel extends LegendPanel {
      */
     public void edit() {
 
-        PaletteColorTable ct = PreferenceManager.getInstance().getMutationColorScheme();
+        PaletteColorTable ct = PreferencesManager.getPreferences().getMutationColorScheme();
         ColorMapEditor editor = new ColorMapEditor(IGV.getMainFrame(), ct.getColorMap());
         editor.setVisible(true);
 
@@ -100,7 +101,7 @@ public class MutationLegendPanel extends LegendPanel {
                 ct.put(entry.getKey(), entry.getValue());
             }
             String colorTableString = ct.getMapAsString();
-            PreferenceManager.getInstance().put(PreferenceManager.MUTATION_COLOR_TABLE, colorTableString);
+            PreferencesManager.getPreferences().put(Constants.MUTATION_COLOR_TABLE, colorTableString);
             reloadPreferences();
         }
 
@@ -108,52 +109,42 @@ public class MutationLegendPanel extends LegendPanel {
 
 
     @Override
-    public void paintLegend(Graphics g) {
+    public void paintLegend(Graphics2D g2D) {
 
 
         if (colorTable == null) {
             return;
         }
 
-        Graphics2D g2D = null;
+        g2D.setFont(FontManager.getFont(10));
 
-        try {
-            g2D = (Graphics2D) g.create();
-            if (PreferenceManager.getInstance().getAsBoolean(PreferenceManager.ENABLE_ANTIALISING)) {
-                g2D.setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
+        FontMetrics fm = g2D.getFontMetrics();
+        int dh = fm.getHeight() / 2 + 3;
+
+        int x = 0;
+        int lineHeight = 12;
+        int y = lineHeight;
+        int colCount = 0;
+
+        for (Map.Entry<String, Color> entry : colorTable.entrySet()) {
+
+            String mutType = entry.getKey();
+            String label = mutType.replace("_", " ");
+            int labelWidth = (int) fm.getStringBounds(label, g2D).getWidth();
+
+            g2D.setColor(entry.getValue());
+            g2D.fillRect(x, y, 10, 10);
+            g2D.setColor(Color.BLACK);
+            g2D.drawRect(x, y, 10, 10);
+            g2D.drawString(label, x + 20, y + dh);
+            x += labelWidth + 40;
+            colCount++;
+
+            if (colCount % 5 == 0) {
+                y += lineHeight + 5;
+                x = 0;
             }
-            g2D.setFont(FontManager.getFont(10));
-
-            FontMetrics fm = g2D.getFontMetrics();
-            int dh = fm.getHeight() / 2 + 3;
-
-            int x = 0;
-            int lineHeight = 12;
-            int y = lineHeight;
-            int colCount = 0;
-
-            for (Map.Entry<String, Color> entry : colorTable.entrySet()) {
-
-                String mutType = entry.getKey();
-                String label = mutType.replace("_", " ");
-                int labelWidth = (int) fm.getStringBounds(label, g2D).getWidth();
-
-                g2D.setColor(entry.getValue());
-                g2D.fillRect(x, y, 10, 10);
-                g2D.setColor(Color.BLACK);
-                g2D.drawRect(x, y, 10, 10);
-                g2D.drawString(label, x + 20, y + dh);
-                x += labelWidth + 40;
-                colCount++;
-
-                if (colCount % 5 == 0) {
-                    y += lineHeight + 5;
-                    x = 0;
-                }
-            }
-
-        } finally {
-            g2D.dispose();
         }
+
     }
 }
