@@ -37,13 +37,15 @@ package org.broad.igv.ui.panel;
 //~--- non-JDK imports --------------------------------------------------------
 
 import org.broad.igv.Globals;
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.Chromosome;
 import org.broad.igv.feature.Cytoband;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.renderer.CytobandRenderer;
 import org.broad.igv.ui.FontManager;
 import org.broad.igv.ui.WaitCursorManager;
-import org.broad.igv.ui.event.ViewChange;
+import org.broad.igv.event.IGVEventBus;
+import org.broad.igv.event.ViewChange;
 
 import javax.swing.*;
 import javax.swing.event.MouseInputAdapter;
@@ -95,7 +97,7 @@ public class CytobandPanel extends JPanel {
 
         super.paintComponent(g);
 
-        if (PreferenceManager.getInstance().getAsBoolean(PreferenceManager.ENABLE_ANTIALISING)) {
+        if (PreferencesManager.getPreferences().getAsBoolean(Constants.ENABLE_ANTIALISING)) {
             ((Graphics2D) g).setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
         }
 
@@ -171,9 +173,9 @@ public class CytobandPanel extends JPanel {
                         getReferenceFrame().centerOnLocation(newLocation);
                     }
 
-                    ViewChange.Result result = new ViewChange.Result();
+                    ViewChange result =  ViewChange.Result();
                     result.setRecordHistory(true);
-                    getReferenceFrame().getEventBus().post(result);
+                    IGVEventBus.getInstance().post(result);
 
                 } finally {
                     WaitCursorManager.removeWaitCursor(token);
