@@ -36,13 +36,19 @@ package org.broad.igv.ui.panel;
 import com.google.common.base.Objects;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.RegionOfInterest;
-import org.broad.igv.track.*;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.PreferencesManager;
+import org.broad.igv.track.RenderContext;
+import org.broad.igv.track.Track;
+import org.broad.igv.track.TrackClickEvent;
+import org.broad.igv.track.TrackGroup;
 import org.broad.igv.ui.AbstractDataPanelTool;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.UIConstants;
 import org.broad.igv.ui.WaitCursorManager;
+import org.broad.igv.event.DataLoadedEvent;
+import org.broad.igv.event.IGVEventObserver;
 import org.broad.igv.ui.util.DataPanelTool;
 
 import javax.swing.*;
@@ -55,6 +61,10 @@ import java.awt.event.MouseWheelEvent;
 import java.text.DecimalFormat;
 import java.util.*;
 import java.util.List;
+import java.util.concurrent.CompletableFuture;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.Executors;
+import java.util.stream.Collectors;
 
 /**
  * The batch panel for displaying tracks and data.  A DataPanel is always associated with a ReferenceFrame.  Normally
@@ -63,19 +73,24 @@ import java.util.List;
  *
  * @author jrobinso
  */
-public class DataPanel extends JComponent implements Paintable {
+public class DataPanel extends JComponent implements Paintable, IGVEventObserver {
 
     private static Logger log = Logger.getLogger(DataPanel.class);
+
+    // Thread pool for loading data
+    private static final ExecutorService threadExecutor = Executors.newFixedThreadPool(5);
+
     private boolean isWaitingForToolTipText = false;
 
     private DataPanelTool defaultTool;
     private DataPanelTool currentTool;
     // private Point tooltipTextPosition;
     private ReferenceFrame frame;
-    DataPanelContainer parent;
+    private DataPanelContainer parent;
     private DataPanelPainter painter;
     private String tooltipText = "";
 
+    private boolean loadInProgress = false;
 
     public DataPanel(ReferenceFrame frame, DataPanelContainer parent) {
         init();
@@ -87,11 +102,24 @@ public class DataPanel extends JComponent implements Paintable {
         setAutoscrolls(true);
         setToolTipText("");
         painter = new DataPanelPainter();
-        setBackground(PreferenceManager.getInstance().getAsColor(PreferenceManager.BACKGROUND_COLOR));
+        setBackground(PreferencesManager.getPreferences().getAsColor(Constants.BACKGROUND_COLOR));
 
         ToolTipManager.sharedInstance().registerComponent(this);
+
+
+        //    IGVEventBus.getInstance().subscribe(DataLoadedEvent.class, this);
     }
 
+    @Override
+    public void receiveEvent(Object event) {
+
+        if (event instanceof DataLoadedEvent) {
+            if (((DataLoadedEvent) event).referenceFrame == frame) {
+                log.info("Data loaded repaint " + frame);
+                repaint();
+            }
+        }
+    }
 
     /**
      * @return
@@ -120,38 +148,30 @@ public class DataPanel extends JComponent implements Paintable {
         RenderContext context = null;
         try {
 
+            long t0 = System.currentTimeMillis();
+
+            if (!allTracksLoaded()) {
+                if (!loadInProgress) {
+                    loadInProgress = true;
+                    load();
+                }
+                if (!Globals.isBatch()) return;
+            }
+
             Rectangle clipBounds = g.getClipBounds();
             final Rectangle visibleRect = getVisibleRect();
             final Rectangle damageRect = clipBounds == null ? visibleRect : clipBounds.intersection(visibleRect);
             Graphics2D graphics2D = (Graphics2D) g; //(Graphics2D) g.create();
 
-            context = new RenderContextImpl(this, graphics2D, frame, visibleRect);
-
-            if (Globals.IS_MAC) {
-                this.applyMacPerformanceHints((Graphics2D) g);
-            }
+            context = new RenderContext(this, graphics2D, frame, visibleRect);
 
             final Collection<TrackGroup> groups = parent.getTrackGroups();
 
-            // If there are no tracks to paint, just exit
-            boolean hasTracks = false;
-            for (TrackGroup group : groups) {
-                if (group.getVisibleTracks().size() > 0) {
-                    hasTracks = true;
-                    break;
-                }
-            }
-            if (!hasTracks) {
-                removeMousableRegions();
-                return;
-            }
-
-
             int trackWidth = getWidth();
 
             computeMousableRegions(groups, trackWidth);
-            painter.paint(groups, context, trackWidth, getBackground(), damageRect);
 
+            painter.paint(groups, context, trackWidth, getBackground(), damageRect);
 
             // If there is a partial ROI in progress draw it first
             if (currentTool instanceof RegionOfInterestTool) {
@@ -166,6 +186,9 @@ public class DataPanel extends JComponent implements Paintable {
             drawAllRegions(g);
 
 
+            long dt = System.currentTimeMillis() - t0;
+            PanTool.repaintTime(dt);
+
         } finally {
 
             if (context != null) {
@@ -174,6 +197,67 @@ public class DataPanel extends JComponent implements Paintable {
         }
     }
 
+
+    public boolean allTracksLoaded() {
+        return parent.getTrackGroups().stream().
+                filter(TrackGroup::isVisible).
+                flatMap(trackGroup -> trackGroup.getVisibleTracks().stream()).
+                allMatch(track -> track.isReadyToPaint(frame));
+    }
+
+
+    public List<Track> visibleTracks() {
+        return parent.getTrackGroups().stream().
+                filter(TrackGroup::isVisible).
+                flatMap(trackGroup -> trackGroup.getVisibleTracks().stream()).
+                collect(Collectors.toList());
+    }
+
+    private void load() {
+
+        ReferenceFrame frame = getFrame();
+        Collection<Track> trackList = visibleTracks();
+        List<CompletableFuture> futures = new ArrayList(trackList.size());
+        boolean batchLoaded = false;
+        for (Track track : trackList) {
+            if (track.isReadyToPaint(frame) == false) {
+                final Runnable runnable = () -> {
+                    track.load(frame);
+                };
+
+                if (Globals.isBatch()) {
+                    runnable.run();
+                    batchLoaded = true;
+                } else {
+                    futures.add(CompletableFuture.runAsync(runnable, threadExecutor));
+                }
+            }
+        }
+
+        if (futures.size() > 0 || batchLoaded) {
+
+            final CompletableFuture[] futureArray = futures.toArray(new CompletableFuture[futures.size()]);
+
+            WaitCursorManager.CursorToken token = WaitCursorManager.showWaitCursor();
+
+            CompletableFuture.allOf(futureArray)
+                    .thenRun(() -> {
+                        //log.info("Call repaint " + dataPanel.hashCode() + " " + dataPanel.allTracksLoaded());
+                        loadInProgress = false;
+                        WaitCursorManager.removeWaitCursor(token);
+                        repaint();
+
+                    })
+                    .exceptionally(e -> {
+                        log.error("Error: ", e);
+                        loadInProgress = false;
+                        WaitCursorManager.removeWaitCursor(token);
+                        return null;
+                    });
+
+        }
+    }
+
     /**
      * TODO -- move this to a "layout" command, to layout tracks and assign positions
      */
@@ -223,7 +307,7 @@ public class DataPanel extends JComponent implements Paintable {
         RenderContext context = null;
         try {
 
-            context = new RenderContextImpl(null, g, frame, rect);
+            context = new RenderContext(null, g, frame, rect);
             final Collection<TrackGroup> groups = new ArrayList(parent.getTrackGroups());
             int width = rect.width;
             painter.paint(groups, context, width, getBackground(), rect);
@@ -257,7 +341,7 @@ public class DataPanel extends JComponent implements Paintable {
             return;
         }
 
-        boolean drawBars = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SHOW_REGION_BARS);
+        boolean drawBars = PreferencesManager.getPreferences().getAsBoolean(Constants.SHOW_REGION_BARS);
         Graphics2D graphics2D = (Graphics2D) g.create();
         try {
 
@@ -422,8 +506,8 @@ public class DataPanel extends JComponent implements Paintable {
                     if (overlays != null) {
                         for (Track overlay : overlays) {
                             if ((overlay != track) && (overlay.getValueStringAt(
-                                    frame.getChrName(), position, y, frame) != null)) {
-                                String valueString = overlay.getValueStringAt(frame.getChrName(), position, y, frame);
+                                    frame.getChrName(), position, x, y, frame) != null)) {
+                                String valueString = overlay.getValueStringAt(frame.getChrName(), position, x, y, frame);
                                 if (valueString != null) {
                                     popupTextBuffer.append(valueString);
                                     popupTextBuffer.append("<br>");
@@ -434,7 +518,7 @@ public class DataPanel extends JComponent implements Paintable {
                         }
                     }
                     if (!foundOverlaidFeature) {
-                        String valueString = track.getValueStringAt(frame.getChrName(), position, y, frame);
+                        String valueString = track.getValueStringAt(frame.getChrName(), position, x, y, frame);
                         if (valueString != null) {
                             if (foundOverlaidFeature) {
                                 popupTextBuffer.append("---------------------<br>");
@@ -495,23 +579,23 @@ public class DataPanel extends JComponent implements Paintable {
                 }
 
                 WaitCursorManager.CursorToken token = null;
-                if(showWaitCursor) token = WaitCursorManager.showWaitCursor();
+                if (showWaitCursor) token = WaitCursorManager.showWaitCursor();
                 try {
-                    if(zoomIncr > Integer.MIN_VALUE){
+                    if (zoomIncr > Integer.MIN_VALUE) {
                         frame.doZoomIncrement(zoomIncr);
-                    }else if(shiftOriginPixels > Integer.MIN_VALUE){
+                    } else if (shiftOriginPixels > Integer.MIN_VALUE) {
                         frame.shiftOriginPixels(shiftOriginPixels);
-                    }else{
+                    } else {
                         return;
                     }
 
                     //Assume that anything special enough to warrant a wait cursor
                     //should be in history
-                    if(showWaitCursor){
+                    if (showWaitCursor) {
                         frame.recordHistory();
                     }
                 } finally {
-                    if(token != null) WaitCursorManager.removeWaitCursor(token);
+                    if (token != null) WaitCursorManager.removeWaitCursor(token);
                 }
 
             }
@@ -527,28 +611,6 @@ public class DataPanel extends JComponent implements Paintable {
         addMouseWheelListener(mouseAdapter);
     }
 
-
-    /**
-     * Some performance hings from the Mac developer mailing list.  Might improve
-     * graphics performance?
-     * <p/>
-     * // TODO  do timing tests with and without these hints
-     *
-     * @param g2D
-     */
-    private void applyMacPerformanceHints(Graphics2D g2D) {
-
-        // From mac mailint list.  Might help performance ?
-        g2D.setRenderingHint(RenderingHints.KEY_ALPHA_INTERPOLATION, RenderingHints.VALUE_ALPHA_INTERPOLATION_SPEED);
-        g2D.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_OFF);
-        g2D.setRenderingHint(RenderingHints.KEY_COLOR_RENDERING, RenderingHints.VALUE_COLOR_RENDER_SPEED);
-        g2D.setRenderingHint(RenderingHints.KEY_DITHERING, RenderingHints.VALUE_DITHER_DISABLE);
-        g2D.setRenderingHint(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_NEAREST_NEIGHBOR);
-        g2D.setRenderingHint(RenderingHints.KEY_RENDERING, RenderingHints.VALUE_RENDER_SPEED);
-
-
-    }
-
     protected void removeMousableRegions() {
         parent.getMouseRegions().clear();
     }
@@ -568,6 +630,8 @@ public class DataPanel extends JComponent implements Paintable {
          */
         private ClickTaskScheduler clickScheduler = new ClickTaskScheduler();
 
+        long lastClickTime = 0;
+
 
         @Override
         public void mouseMoved(MouseEvent e) {
@@ -575,12 +639,12 @@ public class DataPanel extends JComponent implements Paintable {
             if (!frame.getChrName().equals(Globals.CHR_ALL)) {
                 int location = (int) frame.getChromosomePosition(e.getX()) + 1;
                 position = frame.getChrName() + ":" + locationFormatter.format(location);
-                IGV.getInstance().setStatusBarPosition(position);
+                IGV.getInstance().setStatusBarMessag2(position);
             }
             updateTooltipText(e.getX(), e.getY());
 
-            if(IGV.getInstance().isRulerEnabled()) {
-                IGV.getInstance().repaintDataPanels();
+            if (IGV.getInstance().isRulerEnabled()) {
+                IGV.getInstance().revalidateTrackPanels();
             }
 
         }
@@ -654,6 +718,8 @@ public class DataPanel extends JComponent implements Paintable {
         @Override
         public void mouseClicked(final MouseEvent e) {
 
+            long clickTime = System.currentTimeMillis();
+
             // ctrl-mouse down is the mac popup trigger, but you will also get a clck even.  Ignore the click.
             if (Globals.IS_MAC && e.isControlDown()) {
                 return;
@@ -661,11 +727,13 @@ public class DataPanel extends JComponent implements Paintable {
 
             if (currentTool instanceof RegionOfInterestTool) {
                 currentTool.mouseClicked(e);
+                e.consume();
                 return;
             }
 
             if (e.isPopupTrigger()) {
                 doPopupMenu(e);
+                e.consume();
                 return;
             }
 
@@ -676,26 +744,32 @@ public class DataPanel extends JComponent implements Paintable {
                 if (e.isShiftDown()) {
                     final double locationClicked = frame.getChromosomePosition(e.getX());
                     frame.doIncrementZoom(3, locationClicked);
+                    e.consume();
                 } else if (e.isAltDown()) {
                     final double locationClicked = frame.getChromosomePosition(e.getX());
                     frame.doIncrementZoom(-1, locationClicked);
+                    e.consume();
                 } else if ((e.isMetaDown() || e.isControlDown()) && track != null) {
                     TrackClickEvent te = new TrackClickEvent(e, frame);
-
-                    track.handleDataClick(te);
+                    if (track.handleDataClick(te)) {
+                        e.consume();
+                        return;
+                    }
 
                 } else {
 
                     // No modifier, left-click.  Defer processing with a timer until we are sure this is not the
                     // first of a "double-click".
 
-                    if (e.getClickCount() > 1) {
+                    if (clickTime - lastClickTime < UIConstants.getDoubleClickInterval()) {
                         clickScheduler.cancelClickTask();
                         final double locationClicked = frame.getChromosomePosition(e.getX());
                         frame.doIncrementZoom(1, locationClicked);
 
                     } else {
 
+                        lastClickTime = clickTime;
+
                         // Unhandled single click.  Delegate to track or tool unless second click arrives within
                         // double-click interval.
                         TimerTask clickTask = new TimerTask() {
