@@ -29,22 +29,22 @@
  */
 package org.broad.igv.ui.panel;
 
-import com.google.common.eventbus.AsyncEventBus;
-import com.google.common.eventbus.EventBus;
-import com.google.common.eventbus.Subscribe;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
-import org.broad.igv.PreferenceManager;
+import org.broad.igv.event.ShiftEvent;
 import org.broad.igv.feature.Chromosome;
 import org.broad.igv.feature.Locus;
 import org.broad.igv.feature.Range;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.genome.GenomeManager;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.PreferencesManager;
+import org.broad.igv.sam.InsertionManager;
+import org.broad.igv.sam.InsertionMarker;
 import org.broad.igv.ui.IGV;
-import org.broad.igv.ui.event.DragStoppedEvent;
-import org.broad.igv.ui.event.ViewChange;
+import org.broad.igv.event.IGVEventBus;
+import org.broad.igv.event.ViewChange;
 import org.broad.igv.ui.util.MessageUtils;
-import org.broad.igv.util.LongRunningTask;
 
 
 /**
@@ -54,13 +54,20 @@ public class ReferenceFrame {
 
     private static Logger log = Logger.getLogger(ReferenceFrame.class);
 
-    boolean visible = true;
+    IGVEventBus eventBus;
+
+    /**
+     * The origin in bp
+     */
+    public volatile double origin = 0;
 
     /**
      * The nominal viewport width in pixels.
      */
     public static int binsPerTile = 700;
 
+    boolean visible = true;
+
     private String name;
 
     /**
@@ -106,67 +113,44 @@ public class ReferenceFrame {
      */
     protected double nTiles = 1;
 
-    /**
-     * The maximum virtual pixel value.
-     */
-    //private double maxPixel;
-
-    /**
-     * The origin in bp
-     */
-    protected volatile double origin = 0;
 
     /**
      * The location (x axis) locationScale in base pairs / virtual pixel
      */
-    protected volatile double locationScale;
+    protected volatile double scale;
 
     protected Locus initialLocus = null;
 
-    /**
-     * A temporary holder. We set the end location and then
-     * later zoom/origin/etc. calculations are made
-     */
-    //protected int setEnd = 0;
+
     public ReferenceFrame(String name) {
         this.name = name;
         Genome genome = getGenome();
         this.chrName = genome == null ? "" : genome.getHomeChromosome();
-        registerEventBuses();
+        this.eventBus = IGVEventBus.getInstance();
     }
 
-
     public ReferenceFrame(ReferenceFrame otherFrame) {
+        this(otherFrame, otherFrame.eventBus);
+    }
+
+    /**
+     * Copy constructor with event bus ovverride -- used by Sashimii plot
+     *
+     * @param otherFrame
+     */
+    public ReferenceFrame(ReferenceFrame otherFrame, IGVEventBus eventBus) {
         this.chrName = otherFrame.chrName;
         this.initialLocus = otherFrame.initialLocus;
-        this.locationScale = otherFrame.locationScale;
+        this.scale = otherFrame.scale;
         this.minZoom = otherFrame.minZoom;
         this.name = otherFrame.name;
         this.nTiles = otherFrame.nTiles;
         this.origin = otherFrame.origin;
         this.pixelX = otherFrame.pixelX;
-        //this.setEnd = otherFrame.setEnd;
         this.widthInPixels = otherFrame.widthInPixels;
         this.zoom = otherFrame.zoom;
         this.maxZoom = otherFrame.maxZoom;
-        registerEventBuses();
-    }
-
-    private void registerEventBuses(){
-        //TODO Would rather put this in IGV.createFrame, but since frame get
-        //changed we do it here
-        if(IGV.hasInstance()){
-            getEventBus().register(IGV.getInstance());
-        }
-    }
-    private EventBus eventBus;
-
-    public EventBus getEventBus() {
-        if (eventBus == null) {
-            eventBus = new AsyncEventBus(LongRunningTask.getThreadExecutor());
-            eventBus.register(this);
-        }
-        return eventBus;
+        this.eventBus = eventBus;
     }
 
     public boolean isVisible() {
@@ -177,6 +161,34 @@ public class ReferenceFrame {
         this.visible = visible;
     }
 
+
+    public void dragStopped() {
+        setOrigin(Math.round(origin));   // Snap to gride
+        eventBus.post(ViewChange.Result());
+    }
+
+    public void changeGenome(Genome genome) {
+        setChromosomeName(genome.getHomeChromosome(), true);
+    }
+
+    public void changeChromosome(String chrName, boolean recordHistory) {
+        boolean changed = setChromosomeName(chrName, false);
+        // if (changed) {
+        ViewChange resultEvent = ViewChange.ChromosomeChangeResult(chrName);
+        resultEvent.setRecordHistory(recordHistory);
+        eventBus.post(resultEvent);
+        changeZoom(0);
+        // }
+    }
+
+    public void changeZoom(int newZoom) {
+        doSetZoom(newZoom);
+        ViewChange result = ViewChange.Result();
+        result.setRecordHistory(false);
+        eventBus.post(result);
+    }
+
+
     /**
      * Set the position and width of the frame, in pixels
      * The origin/end positions are kept fixed iff valid
@@ -230,7 +242,7 @@ public class ReferenceFrame {
     public void setOrigin(double position) {
         int windowLengthBP = (int) (widthInPixels * getScale());
         double newOrigin;
-        if (PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SAM_SHOW_SOFT_CLIPPED)) {
+        if (PreferencesManager.getPreferences().getAsBoolean(Constants.SAM_SHOW_SOFT_CLIPPED)) {
             newOrigin = Math.max(-1000, Math.min(position, getMaxCoordinate() + 1000 - windowLengthBP));
         } else {
             newOrigin = Math.max(0, Math.min(position, getMaxCoordinate() - windowLengthBP));
@@ -266,20 +278,6 @@ public class ReferenceFrame {
         doSetZoomCenter(newZoom, currentCenter);
     }
 
-    @Subscribe
-    public void receiveZoomChange(ViewChange.ZoomCause e) {
-        doSetZoom(e.newZoom);
-        ViewChange.Result result = new ViewChange.Result();
-        result.setRecordHistory(false);
-        getEventBus().post(result);
-    }
-
-    @Subscribe
-    public void receiveDragStopped(DragStoppedEvent e) {
-        this.snapToGrid();
-        getEventBus().post(new ViewChange.Result());
-    }
-
 
     public void doIncrementZoom(final int zoomIncrement, final double newCenter) {
         doSetZoomCenter(getZoom() + zoomIncrement, newCenter);
@@ -299,13 +297,7 @@ public class ReferenceFrame {
             chrName = getGenome().getHomeChromosome();
         }
 
-        if (chrName.equals(Globals.CHR_ALL)) {
-            // Translate the location to chromosome number
-            synchronized (this) {
-                jumpToChromosomeForGenomeLocation(newCenter);
-            }
-            //IGV.getInstance().chromosomeChangeEvent(chrName);
-        } else {
+        if (!chrName.equals(Globals.CHR_ALL)) {
             setZoom(newZoom);
             // Adjust origin so newCenter is centered
             centerOnLocation(newCenter);
@@ -322,10 +314,10 @@ public class ReferenceFrame {
      * @return
      */
     public double getScale() {
-        if (locationScale <= 0) {
+        if (scale <= 0) {
             computeLocationScale();
         }
-        return locationScale;
+        return scale;
     }
 
     /**
@@ -354,7 +346,7 @@ public class ReferenceFrame {
         if (shouldChangeChromosome(name) || force) {
             chrName = name;
             origin = 0;
-            this.locationScale = -1;
+            this.scale = -1;
             this.calculateMaxZoom();
 
             this.zoom = -1;
@@ -367,78 +359,24 @@ public class ReferenceFrame {
         return false;
     }
 
-    /**
-     * Recalculate the locationScale, based on {@link #initialLocus}, {@link #origin}, and
-     * {@link #widthInPixels}
-     * DOES NOT alter zoom value
-     */
-    protected synchronized void computeLocationScale() {
-        Genome genome = getGenome();
-
-        //Should consider getting rid of this. We don't have
-        //a chromosome length without a genome, not always a problem
-        if (genome != null) {
-
-            // The end location, in base pairs.
-            // If negative, we use the whole chromosome
-            int setEnd = -1;
-            if (this.initialLocus != null) setEnd = this.initialLocus.getEnd();
-
-            if (setEnd > 0 && widthInPixels > 0) {
-                this.locationScale = ((setEnd - origin) / widthInPixels);
-                this.initialLocus = null;
-            } else {
-                double virtualPixelSize = getTilesTimesBinsPerTile();
-                double nPixel = Math.max(virtualPixelSize, widthInPixels);
-                this.locationScale = (((double) getChromosomeLength()) / nPixel);
-            }
-        }
-    }
-
-    /**
-     * Recalculate the zoom value based on current start/end
-     * locationScale is not altered
-     */
-    protected void computeZoom() {
-        int newZoom = calculateZoom(getOrigin(), getEnd());
-        setZoomWithinLimits(newZoom);
-    }
 
     /**
      * Record the current state of the frame in history.
      * It is recommended that this NOT be called from within ReferenceFrame,
      * and callers use it after making all changes
-     * <p/>
+     * <p>
      * //TODO Should we save history by receiving events in History?
      */
     public void recordHistory() {
         IGV.getInstance().getSession().getHistory().push(getFormattedLocusString(), zoom);
     }
 
-    private void jumpToChromosomeForGenomeLocation(double locationMB) {
-        double startMB = 0;
-
-        for (String chr : getGenome().getLongChromosomeNames()) {
-            double endMB = startMB + getGenome().getChromosome(chr).getLength() / 1000.0;
-
-            if ((locationMB > startMB) && (locationMB <= endMB)) {
-                this.setChromosomeName(chr);
-                break;
-            }
-
-            startMB = endMB;
-        }
-    }
 
     public void shiftOriginPixels(int delta) {
+
         double shiftBP = delta * getScale();
         setOrigin(origin + shiftBP);
-        getEventBus().post(new ViewChange.Result());
-    }
-
-    public void snapToGrid() {
-        setOrigin(Math.round(origin));
-        getEventBus().post(new ViewChange.Result());
+        eventBus.post(ViewChange.Result());
     }
 
     public void centerOnLocation(String chr, double chrLocation) {
@@ -451,7 +389,7 @@ public class ReferenceFrame {
     public void centerOnLocation(double chrLocation) {
         double windowWidth = (widthInPixels * getScale()) / 2;
         setOrigin(Math.round(chrLocation - windowWidth));
-        getEventBus().post(new ViewChange.LocusChangeResult(chrName, origin, chrLocation + windowWidth));
+        eventBus.post(ViewChange.LocusChangeResult(chrName, origin, chrLocation + windowWidth));
     }
 
     public boolean windowAtEnd() {
@@ -503,35 +441,10 @@ public class ReferenceFrame {
             log.debug("New start = " + (int) origin);
             log.debug("New end = " + (int) getEnd());
             log.debug("New center = " + (int) getCenter());
-            log.debug("Scale = " + locationScale);
+            log.debug("Scale = " + scale);
         }
 
-        getEventBus().post(new ViewChange.LocusChangeResult(chrName, start, end));
-    }
-
-    /**
-     * Called before scaling and zooming, during jumpTo.
-     * Intended to be overridden
-     * @param locus
-     */
-    protected void beforeScaleZoom(Locus locus) {
-        calculateMaxZoom();
-    }
-
-    /**
-     * Calculate the zoom level given start/end in bp.
-     * Doesn't change anything
-     *
-     * @param start
-     * @param end
-     * @return
-     */
-    protected int calculateZoom(double start, double end) {
-        return (int) Math.round((Math.log((getChromosomeLength() / (end - start)) * (((double) widthInPixels) / binsPerTile)) / Globals.log2));
-    }
-
-    protected static Genome getGenome() {
-        return GenomeManager.getInstance().getCurrentGenome();
+        eventBus.post(ViewChange.LocusChangeResult(chrName, start, end));
     }
 
     public double getOrigin() {
@@ -546,10 +459,6 @@ public class ReferenceFrame {
         return origin + getScale() * widthInPixels;
     }
 
-    protected double getnTiles() {
-        return nTiles;
-    }
-
     public int getZoom() {
         return zoom;
     }
@@ -567,31 +476,18 @@ public class ReferenceFrame {
         return zoom - minZoom;
     }
 
-    public double getMaxPixel() {
-        return getTilesTimesBinsPerTile();
-    }
-
     /**
      * Determine if this view will change at all based on the {@code newChrName}
      * The view changes if newChrName != {@code #this.chr} or if we are not
      * at full chromosome view
+     *
      * @param newChrName
      * @return
      */
-    private boolean shouldChangeChromosome(String newChrName){
+    private boolean shouldChangeChromosome(String newChrName) {
         return chrName == null || !chrName.equals(newChrName);
     }
 
-    @Subscribe
-    public void receiveChromosomeChange(ViewChange.ChromosomeChangeCause chromoChangeCause) {
-        boolean changed = setChromosomeName(chromoChangeCause.chrName, false);
-        if (changed) {
-            ViewChange.ChromosomeChangeResult resultEvent = new ViewChange.ChromosomeChangeResult(chromoChangeCause.source,
-                    chrName);
-            resultEvent.setRecordHistory(chromoChangeCause.recordHistory());
-            getEventBus().post(resultEvent);
-        }
-    }
 
     protected void calculateMaxZoom() {
         this.maxZoom = Globals.CHR_ALL.equals(this.chrName) ? 0 :
@@ -617,9 +513,38 @@ public class ReferenceFrame {
      * @return
      */
     public double getChromosomePosition(int screenPosition) {
-        return origin + getScale() * screenPosition;
+
+        InsertionMarker i = InsertionManager.getInstance().getSelectedInsertion(getChrName());
+
+        if (i != null && i.position > origin) {
+            // if (IGV.getInstance().getSession().expandInsertions && insertionMarkers != null && insertionMarkers.size() > 0) {
+            double start = getOrigin();
+            double scale = getScale();
+            double iEnd = 0,
+                    iStart = 0;
+
+
+            iStart = iEnd + (i.position - start) / scale; // Screen position of insertionMarker start
+            if (screenPosition < iStart) {
+                return start + scale * (screenPosition - iEnd);
+            }
+
+            iEnd = iStart + i.size / scale;  // Screen position of insertionMarker end
+            if (screenPosition < iEnd) {
+                return i.position;   // In the gap
+            }
+
+            start = i.position + 1;
+            //    }
+            return start + scale * (screenPosition - iEnd);
+
+        } else {
+            return origin + getScale() * screenPosition;
+        }
+
     }
 
+
     /**
      * Return the screen position corresponding to the chromosomal position.
      *
@@ -627,7 +552,14 @@ public class ReferenceFrame {
      * @return
      */
     public int getScreenPosition(double chromosomePosition) {
-        return (int) ((chromosomePosition - origin) / getScale());
+
+        InsertionMarker i = InsertionManager.getInstance().getSelectedInsertion(chrName);
+
+        if (i == null || i.position < origin || i.position > chromosomePosition) {
+            return (int) ((chromosomePosition - origin) / getScale());
+        } else {
+            return (int) ((chromosomePosition + i.size - origin) / getScale());
+        }
     }
 
 
@@ -645,52 +577,29 @@ public class ReferenceFrame {
      * In genomic coordinates this is the same as the chromosome length.
      * In exome coordinates, the two are different
      * (since ExomeReferenceFrame takes input in genomic coordinates)
-     * @see #getChromosomeLength()
+     *
      * @return
+     * @see #getChromosomeLength()
      */
-    public int getMaxCoordinate(){
+    public int getMaxCoordinate() {
         return this.getChromosomeLength();
     }
 
-    private static int getMaxCoordinate(String chrName){
+    private static int getMaxCoordinate(String chrName) {
         return getChromosomeLength(chrName);
     }
 
     /**
      * Chromosome length, in genomic coordinates.
      * Intended to be used for scaling
-     * @see #getMaxCoordinate()
+     *
      * @return
+     * @see #getMaxCoordinate()
      */
-    public int getChromosomeLength(){
+    public int getChromosomeLength() {
         return getChromosomeLength(this.chrName);
     }
 
-    private static int getChromosomeLength(String chrName) {
-        Genome genome = getGenome();
-
-        if (genome == null) {
-            return 1;
-        }
-
-        if (chrName.equals("All")) {
-            // TODO -- remove the hardcoded unit divider ("1000")
-            return (int) (genome.getNominalLength() / 1000);
-        } else {
-            Chromosome chromosome = genome.getChromosome(chrName);
-            if (chromosome == null) {
-                log.error("Null chromosome: " + chrName);
-                if (genome.getChromosomes().size() == 0) {
-                    return 1;
-                } else {
-                    return genome.getChromosomes().iterator().next().getLength();
-                }
-            }
-            return chromosome.getLength();
-        }
-    }
-
-
     public double getTilesTimesBinsPerTile() {
         return nTiles * (double) binsPerTile;
     }
@@ -750,8 +659,110 @@ public class ReferenceFrame {
         this.name = name;
     }
 
-    public int getStateHash() {
-       return (chrName + origin + locationScale + widthInPixels).hashCode();
+    /**
+     * Recalculate the locationScale, based on {@link #initialLocus}, {@link #origin}, and
+     * {@link #widthInPixels}
+     * DOES NOT alter zoom value
+     */
+    private synchronized void computeLocationScale() {
+        Genome genome = getGenome();
+
+        //Should consider getting rid of this. We don't have
+        //a chromosome length without a genome, not always a problem
+        if (genome != null) {
+
+            // The end location, in base pairs.
+            // If negative, we use the whole chromosome
+            int setEnd = -1;
+            if (this.initialLocus != null) setEnd = this.initialLocus.getEnd();
+
+            if (setEnd > 0 && widthInPixels > 0) {
+                this.scale = ((setEnd - origin) / widthInPixels);
+                this.initialLocus = null;
+            } else {
+                double virtualPixelSize = getTilesTimesBinsPerTile();
+                double nPixel = Math.max(virtualPixelSize, widthInPixels);
+                this.scale = (((double) getChromosomeLength()) / nPixel);
+            }
+        }
     }
 
+    /**
+     * Recalculate the zoom value based on current start/end
+     * locationScale is not altered
+     */
+    private void computeZoom() {
+        int newZoom = calculateZoom(getOrigin(), getEnd());
+        setZoomWithinLimits(newZoom);
+    }
+
+
+    /**
+     * Called before scaling and zooming, during jumpTo.
+     * Intended to be overridden
+     *
+     * @param locus
+     */
+    private void beforeScaleZoom(Locus locus) {
+        calculateMaxZoom();
+    }
+
+    /**
+     * Calculate the zoom level given start/end in bp.
+     * Doesn't change anything
+     *
+     * @param start
+     * @param end
+     * @return
+     */
+    private int calculateZoom(double start, double end) {
+        return (int) Math.round((Math.log((getChromosomeLength() / (end - start)) * (((double) widthInPixels) / binsPerTile)) / Globals.log2));
+    }
+
+
+    private static int getChromosomeLength(String chrName) {
+        Genome genome = getGenome();
+
+        if (genome == null) {
+            return 1;
+        }
+
+        if (chrName.equals("All")) {
+            // Genome coordinates are in kb => divde by 1000
+            return (int) (genome.getNominalLength() / 1000);
+        } else {
+            Chromosome chromosome = genome.getChromosome(chrName);
+            if (chromosome == null) {
+                log.error("Null chromosome: " + chrName);
+                if (genome.getChromosomes().size() == 0) {
+                    return 1;
+                } else {
+                    return genome.getChromosomes().iterator().next().getLength();
+                }
+            }
+            return chromosome.getLength();
+        }
+    }
+
+
+    public int stateHash() {
+        int result;
+        long temp;
+        temp = Double.doubleToLongBits(origin);
+        result = (int) (temp ^ (temp >>> 32));
+        result = 31 * result + chrName.hashCode();
+        result = 31 * result + zoom;
+        result = 31 * result + pixelX;
+        result = 31 * result + widthInPixels;
+        temp = Double.doubleToLongBits(scale);
+        result = 31 * result + (int) (temp ^ (temp >>> 32));
+        return result;
+    }
+
+    private static Genome getGenome() {
+        return GenomeManager.getInstance().getCurrentGenome();
+    }
+
+
 }
+
