@@ -31,12 +31,28 @@ package org.broad.igv.ui.panel;
 
 //~--- non-JDK imports --------------------------------------------------------
 
+import com.google.gson.Gson;
+import com.google.gson.JsonObject;
 import org.apache.log4j.Logger;
 import org.broad.igv.Globals;
+import org.broad.igv.batch.CommandExecutor;
+import org.broad.igv.feature.genome.GenomeManager;
+import org.broad.igv.ga4gh.OAuthUtils;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.PreferencesManager;
+import org.broad.igv.sam.Alignment;
+import org.broad.igv.sam.AlignmentCounts;
+import org.broad.igv.sam.AlignmentTrack;
+import org.broad.igv.sam.mutreview.BaseCounts;
+import org.broad.igv.sam.mutreview.VariantReviewAction;
+import org.broad.igv.sam.mutreview.VariantReviewFX;
+import org.broad.igv.sam.mutreview.VariantReviewMetadata;
 import org.broad.igv.track.Track;
 import org.broad.igv.track.TrackClickEvent;
 import org.broad.igv.track.TrackMenuUtils;
 import org.broad.igv.ui.IGV;
+import org.broad.igv.ui.util.MessageUtils;
+import org.broad.igv.ui.util.SnapshotUtilities;
 
 import javax.swing.*;
 import java.awt.*;
@@ -44,9 +60,12 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.KeyEvent;
 import java.awt.event.MouseEvent;
+import java.awt.image.BufferedImage;
+import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
+import java.util.Optional;
 
 
 /**
@@ -180,6 +199,7 @@ abstract public class TrackPanelComponent extends JPanel {
     }
 
     protected void openPopupMenu(TrackClickEvent te, List<Component> extraItems) {
+
         MouseEvent e = te.getMouseEvent();
 
         final Collection<Track> selectedTracks = getSelectedTracks();
@@ -195,6 +215,7 @@ abstract public class TrackPanelComponent extends JPanel {
             menu = track.getPopupMenu(te);
         }
 
+
         // If still no menu, create a generic one with common items
         if (menu == null) {
             String title = getPopupMenuTitle(e.getX(), e.getY());
@@ -209,34 +230,28 @@ abstract public class TrackPanelComponent extends JPanel {
             }
         }
 
-        TrackMenuUtils.addPluginItems(menu, selectedTracks, te);
+        if (menu.includeStandardItems()) {
 
-        // Add saveImage
-        menu.addSeparator();
-        JMenuItem item = new JMenuItem("Save image...");
-        item.addActionListener(new ActionListener() {
-            public void actionPerformed(ActionEvent e) {
-                saveImage();
-            }
-        });
-        menu.add(item);
+            TrackMenuUtils.addPluginItems(menu, selectedTracks, te);
 
-        // Add export features
-        ReferenceFrame frame = FrameManager.getDefaultFrame();
-        JMenuItem exportFeats = TrackMenuUtils.getExportFeatures(selectedTracks, frame);
-        if (exportFeats != null) menu.add(exportFeats);
+            // Add saveImage
+            menu.addSeparator();
+            JMenuItem item = new JMenuItem("Save image...");
+            item.addActionListener(e1 -> saveImage());
+            menu.add(item);
 
-        JMenuItem exportNames = new JMenuItem("Export track names...");
-        exportNames.addActionListener(new ActionListener() {
-            @Override
-            public void actionPerformed(ActionEvent e) {
-                TrackMenuUtils.exportTrackNames(selectedTracks);
-            }
-        });
-        menu.add(exportNames);
+            // Add export features
+            ReferenceFrame frame = FrameManager.getDefaultFrame();
+            JMenuItem exportFeats = TrackMenuUtils.getExportFeatures(selectedTracks, frame);
+            if (exportFeats != null) menu.add(exportFeats);
 
-        menu.addSeparator();
-        menu.add(TrackMenuUtils.getRemoveMenuItem(selectedTracks));
+            JMenuItem exportNames = new JMenuItem("Export track names...");
+            exportNames.addActionListener(e12 -> TrackMenuUtils.exportTrackNames(selectedTracks));
+            menu.add(exportNames);
+
+            menu.addSeparator();
+            menu.add(TrackMenuUtils.getRemoveMenuItem(selectedTracks));
+        }
 
         menu.show(e.getComponent(), e.getX(), e.getY());
 
