@@ -1,12 +1,26 @@
 /*
- * Copyright (c) 2007-2013 The Broad Institute, Inc.
- * SOFTWARE COPYRIGHT NOTICE
- * This software and its documentation are the copyright of the Broad Institute, Inc. All rights are reserved.
+ * The MIT License (MIT)
  *
- * This software is supplied without any warranty or guaranteed support whatsoever. The Broad Institute is not responsible for its use, misuse, or functionality.
+ * Copyright (c) 2007-2015 Broad Institute
  *
- * This software is licensed under the terms of the GNU Lesser General Public License (LGPL),
- * Version 2.1 which is available at http://www.opensource.org/licenses/lgpl-2.1.php.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 
@@ -15,8 +29,9 @@ package org.broad.igv.ui.util;
 import com.jidesoft.swing.JideBoxLayout;
 import com.jidesoft.swing.JideButton;
 import org.apache.log4j.Logger;
-import org.broad.igv.Globals;
 import org.broad.igv.ui.FontManager;
+import org.broad.igv.event.IGVEventBus;
+//import org.broad.igv.event.StopEvent;
 
 import javax.swing.*;
 import java.awt.*;
@@ -32,13 +47,12 @@ import java.util.TimerTask;
 public class ApplicationStatusBar extends JPanel { //StatusBar {
 
     static Logger log = Logger.getLogger(ApplicationStatusBar.class);
+    public JButton stopButton;
     private JLabel messageBox;
     private JLabel messageBox2;
     private JLabel messageBox3;
     private JLabel memoryStatus;
 
-    private JButton cancelButton;
-
     java.util.Timer timer;
 
     public ApplicationStatusBar() {
@@ -63,19 +77,24 @@ public class ApplicationStatusBar extends JPanel { //StatusBar {
         messageBox.setPreferredSize(new Dimension(135, 20));
         add(messageBox, JideBoxLayout.FIX);
 
-        if (Globals.isDevelopment()) {
-            cancelButton = new JideButton(IconFactory.getInstance().getIcon(IconFactory.IconID.CLOSE));
-            cancelButton.setMinimumSize(new Dimension(20, 10));
-            cancelButton.setPreferredSize(new Dimension(20, 20));
-            cancelButton.setBorder(BorderFactory.createLineBorder(Color.black));
-            add(cancelButton, JideBoxLayout.FIX);
-        }
+        stopButton = new JButton();
+        stopButton.setBorder(BorderFactory.createLineBorder(Color.black));
+        stopButton.setIcon(new javax.swing.ImageIcon(
+                getClass().getResource("/toolbarButtonGraphics/general/Stop16.gif")));
+        stopButton.setMaximumSize(new java.awt.Dimension(16, 16));
+        stopButton.setMinimumSize(new java.awt.Dimension(16, 16));
+        stopButton.setPreferredSize(new java.awt.Dimension(16, 16));
+        stopButton.setSize(new java.awt.Dimension(16, 16));
+        stopButton.setToolTipText("Cancel load");
+        stopButton.setEnabled(false);
+        add(stopButton, JideBoxLayout.FIX);
 
         messageBox2 = createMessageField(messageBG, messageFont);
         messageBox2.setMinimumSize(new Dimension(150, 10));
         messageBox2.setPreferredSize(new Dimension(150, 20));
         add(messageBox2, JideBoxLayout.FIX);
 
+
         messageBox3 = createMessageField(messageBG, messageFont);
         messageBox3.setMinimumSize(new Dimension(165, 10));
         messageBox3.setPreferredSize(new Dimension(165, 20));
@@ -95,23 +114,33 @@ public class ApplicationStatusBar extends JPanel { //StatusBar {
     }
 
     public void setMessage(final String message) {
-        UIUtilities.invokeOnEventThread(new Runnable() {
-            public void run() {
-                messageBox.setText(message);
-                messageBox.paintImmediately(messageBox.getBounds());
-            }
+        UIUtilities.invokeOnEventThread(() -> {
+            messageBox.setText(message);
+            messageBox.paintImmediately(messageBox.getBounds());
         });
+
+        if (!SwingUtilities.isEventDispatchThread()) {
+            try {
+                Thread.currentThread().sleep(10);
+            } catch (InterruptedException e) {
+                // ignore
+            }
+        }
     }
 
     public void setMessage2(final String message) {
-        UIUtilities.invokeOnEventThread(new Runnable() {
-            public void run() {
-                messageBox2.setText(message);
-                messageBox2.paintImmediately(messageBox2.getBounds());
-            }
+        UIUtilities.invokeOnEventThread(() -> {
+            messageBox2.setText(message);
+            messageBox2.paintImmediately(messageBox2.getBounds());
         });
     }
 
+    public void setMessage3(final String message) {
+        UIUtilities.invokeOnEventThread(() -> {
+            messageBox3.setText(message);
+            messageBox3.paintImmediately(messageBox2.getBounds());
+        });
+    }
 
     private JLabel createMessageField(Color bg, Font font) {
         JLabel messageField = new JLabel();
@@ -122,40 +151,10 @@ public class ApplicationStatusBar extends JPanel { //StatusBar {
 
     }
 
-    /**
-     * Set the cancel button
-     */
-    public void activateCancelButton(ActionListener listener) {
-
-        if (Globals.isDevelopment()) {
-            this.cancelButton.addActionListener(listener);
-            this.cancelButton.addActionListener(new CancelButtonActionListener());
-            this.cancelButton.setEnabled(true);
-        }
-
+    public void enableStopButton(boolean enable) {
+        stopButton.setEnabled(enable);
     }
 
-    public void deactivateCancelButton() {
-        if (Globals.isDevelopment()) {
-            for (ActionListener l : this.cancelButton.getActionListeners()) {
-                this.cancelButton.removeActionListener(l);
-            }
-            this.cancelButton.setEnabled(false);
-        }
-    }
-
-    public JButton getCancelButton() {
-        return cancelButton;
-    }
-
-    class CancelButtonActionListener implements ActionListener {
-        @Override
-        public void actionPerformed(ActionEvent e) {
-            deactivateCancelButton();
-        }
-    }
-
-
     class MemoryUpdateTask extends TimerTask {
 
         JLabel textField;
@@ -174,8 +173,8 @@ public class ApplicationStatusBar extends JPanel { //StatusBar {
             int usedMemory = (totalMemory - freeMemory);
             String um = format.format(usedMemory);
             String tm = format.format(totalMemory);
-            textField.setText(um + "M of " + tm + "M");
+            UIUtilities.invokeOnEventThread(() -> textField.setText(um + "M of " + tm + "M"));
         }
 
     }
-}
\ No newline at end of file
+}
