@@ -72,30 +72,32 @@ public class MessageUtils {
     public static synchronized void showMessage(Level level, String message) {
 
         log.log(level, message);
-        boolean showDialog = !(Globals.isHeadless() || Globals.isSuppressMessages() || Globals.isTesting());
+        boolean showDialog = !(Globals.isHeadless() || Globals.isSuppressMessages() || Globals.isTesting() || Globals.isBatch());
         if (showDialog) {
-            // Always use HTML for message displays, but first remove any embedded <html> tags.
-            message = "<html>" + message.replaceAll("<html>", "");
-            Frame parent = IGV.hasInstance() ? IGV.getMainFrame() : null;
-            Color background = parent != null ? parent.getBackground() : Color.lightGray;
+            UIUtilities.invokeOnEventThread (() -> {
+                // Always use HTML for message displays, but first remove any embedded <html> tags.
+                String dlgMessage = "<html>" + message.replaceAll("<html>", "");
+                Frame parent = IGV.hasInstance() ? IGV.getMainFrame() : null;
+                Color background = parent != null ? parent.getBackground() : Color.lightGray;
 
-            //JEditorPane So users can select text
-            JEditorPane content = new JEditorPane();
-            content.setContentType("text/html");
-            content.setText(message);
-            content.setBackground(background);
-            content.setEditable(false);
-            Component dispMessage = content;
+                //JEditorPane So users can select text
+                JEditorPane content = new JEditorPane();
+                content.setContentType("text/html");
+                content.setText(dlgMessage);
+                content.setBackground(background);
+                content.setEditable(false);
+                Component dispMessage = content;
 
-            //Really long messages should be scrollable
-            if(message.length() > 200){
-                Dimension size = new Dimension(1000, content.getHeight());
-                content.setPreferredSize(size);
-                JScrollPane pane = new JScrollPane(content);
-                dispMessage = pane;
-            }
+                //Really long messages should be scrollable
+                if(dlgMessage.length() > 200){
+                    Dimension size = new Dimension(1000, content.getHeight() + 100);
+                    content.setPreferredSize(size);
+                    JScrollPane pane = new JScrollPane(content);
+                    dispMessage = pane;
+                }
 
-            JOptionPane.showMessageDialog(parent, dispMessage);
+                JOptionPane.showMessageDialog(parent, dispMessage);
+            });
         }
     }
 
@@ -109,7 +111,11 @@ public class MessageUtils {
     public static synchronized boolean confirm(final String message) {
         if(Globals.isHeadless()){
             log.error("Attempted to confirm while running headless with the following message:\n" + message);
-            return false;
+            return true;
+        }
+
+        if(Globals.isBatch()) {
+            return true;
         }
 
         final Frame parent = IGV.hasInstance() ? IGV.getMainFrame() : null;
@@ -126,6 +132,10 @@ public class MessageUtils {
     public static synchronized boolean confirm(final Component component, final String message) {
 
 
+        if(Globals.isHeadless() || Globals.isBatch()) {
+            return true;
+        }
+
         if (SwingUtilities.isEventDispatchThread()) {
             int opt = JOptionPane.showConfirmDialog(component, message, "Confirm", JOptionPane.YES_NO_OPTION);
             return opt == JOptionPane.YES_OPTION;
@@ -152,11 +162,11 @@ public class MessageUtils {
         }
     }
 
-    public static String showInputDialog(String message, final String defaultValue) {
+    public static String showInputDialog(String message, String defaultValue) {
 
         final Frame parent = IGV.hasInstance() ? IGV.getMainFrame() : null;
         //Pad message with spaces so it's as wide as the defaultValue
-        if(message.length() < defaultValue.length()){
+        if(defaultValue != null && message.length() < defaultValue.length()){
             message = String.format("%-" + defaultValue.length() + "s", message);
         }
         final String actMsg = message;
@@ -166,11 +176,9 @@ public class MessageUtils {
             return val;
         } else {
             final ValueHolder returnValue = new ValueHolder();
-            Runnable runnable = new Runnable() {
-                public void run() {
-                    String val = JOptionPane.showInputDialog(parent, actMsg, defaultValue);
-                    returnValue.value = val;
-                }
+            Runnable runnable = () -> {
+                String val = JOptionPane.showInputDialog(parent, actMsg, defaultValue);
+                returnValue.value = val;
             };
             try {
                 SwingUtilities.invokeAndWait(runnable);
