@@ -25,9 +25,9 @@
 
 /**
  * SnapshotUtilities.java
- *
+ * <p>
  * Created on November 29, 2007, 2:14 PM
- *
+ * <p>
  * To change this template, choose Tools | Template Manager
  * and open the template in the editor.
  */
@@ -59,7 +59,6 @@ public class SnapshotUtilities {
     private static Logger log = Logger.getLogger(SnapshotUtilities.class);
 
 
-
     private static String EPSClassName = "net.sf.epsgraphics.EpsGraphics";
     private static String EPSColorModeClassName = "net.sf.epsgraphics.ColorMode";
 
@@ -70,22 +69,16 @@ public class SnapshotUtilities {
     public static int DEFAULT_MAX_PANEL_HEIGHT = 1000;
 
     /**
-     * We need to use a static for max panel height,  or alternatively much refactoring, however this class might
-     * be accessed by multiple threads which set this to different values => use a thread local
+     * We need to use a static for max panel height,  or alternatively much refactoring
      */
-    private static ThreadLocal<Integer> maxPanelHeight = new ThreadLocal() {
-        @Override
-        protected Object initialValue() {
-            return new Integer(DEFAULT_MAX_PANEL_HEIGHT);
-        }
-    };
+    private static int maxPanelHeight = DEFAULT_MAX_PANEL_HEIGHT;
 
     public static int getMaxPanelHeight() {
-        return maxPanelHeight.get().intValue();
+        return maxPanelHeight;
     }
 
     public static void setMaxPanelHeight(int h) {
-        maxPanelHeight.set(h);
+        maxPanelHeight = h;
     }
 
     // Treat this class as a singleton, no instances allowed
@@ -93,7 +86,7 @@ public class SnapshotUtilities {
     }
 
 
-    public static String doComponentSnapshot(Component component, File file, SnapshotFileChooser.SnapshotFileType type, boolean paintOffscreen) throws IOException{
+    public static String doComponentSnapshot(Component component, File file, SnapshotFileChooser.SnapshotFileType type, boolean paintOffscreen) throws IOException {
 
         //TODO Should really make this work for more components
         if (paintOffscreen && !(component instanceof Paintable)) {
@@ -101,13 +94,13 @@ public class SnapshotUtilities {
             paintOffscreen = false;
         }
 
-        if(paintOffscreen){
+        if (paintOffscreen) {
 
             Rectangle rect = component.getBounds();
 
-            if(component instanceof MainPanel){
+            if (component instanceof MainPanel) {
                 rect.height = ((MainPanel) component).getOffscreenImageHeight();
-            }else{
+            } else {
                 rect.height = Math.min(component.getHeight(), getMaxPanelHeight());
             }
 
@@ -131,7 +124,7 @@ public class SnapshotUtilities {
         switch (type) {
             case SVG:
                 //log.debug("Exporting svg screenshot");
-                exportScreenshotSVG(component, file, paintOffscreen);
+                exportScreenshotSVG(component, file, width, height, paintOffscreen);
                 //exportScreenshotVector2D(component, file, paintOffscreen);
                 break;
             case JPEG:
@@ -143,11 +136,11 @@ public class SnapshotUtilities {
                 exts = new String[]{"." + format};
                 break;
             case EPS:
-                exportScreenshotEpsGraphics(component, file, paintOffscreen);
+                exportScreenshotEpsGraphics(component, file, width, height, paintOffscreen);
                 //exportScreenshotEpsGraphicsNoRef(component, file, paintOffscreen);
                 break;
         }
-        if(format != null && exts != null){
+        if (format != null && exts != null) {
             exportScreenShotBufferedImage(component, file, width, height, exts, format, paintOffscreen);
         }
         return "OK";
@@ -175,9 +168,9 @@ public class SnapshotUtilities {
 //
 //    }
 
-    private static void exportScreenshotEpsGraphics(Component target, File selectedFile, boolean paintOffscreen) throws IOException{
+    private static void exportScreenshotEpsGraphics(Component target, File selectedFile, int width, int height, boolean paintOffscreen) throws IOException {
 
-        if(!SnapshotUtilities.canExportScreenshotEps()){
+        if (!SnapshotUtilities.canExportScreenshotEps()) {
             String msg = "ERROR: EPS output requires EPSGraphics library. See https://www.broadinstitute.org/software/igv/third_party_tools#epsgraphics";
             log.error(msg);
             return;
@@ -185,7 +178,7 @@ public class SnapshotUtilities {
 
         Graphics2D g = null;
         FileOutputStream fos = null;
-        try{
+        try {
             Class colorModeClass = RuntimeUtils.loadClassForName(EPSColorModeClassName, null);
             Class graphicsClass = RuntimeUtils.loadClassForName(EPSClassName, null);
 
@@ -198,14 +191,14 @@ public class SnapshotUtilities {
             fos = new FileOutputStream(selectedFile);
             g = (Graphics2D) constructor.newInstance("eps", fos, 0, 0, target.getWidth(), target.getHeight(), colorModeValue);
 
-            choosePaint(target, g, paintOffscreen);
+            paintImage(target, g, width, height, paintOffscreen);
 
             graphicsClass.getMethod("close").invoke(g);
 
-        }catch (Exception e){
+        } catch (Exception e) {
             log.error(e.getMessage(), e);
         } finally {
-            if(fos != null){
+            if (fos != null) {
                 fos.flush();
                 fos.close();
             }
@@ -213,7 +206,7 @@ public class SnapshotUtilities {
 
     }
 
-    public static boolean canExportScreenshotEps(){
+    public static boolean canExportScreenshotEps() {
         Constructor constr = null;
         try {
             Class colorModeClass = RuntimeUtils.loadClassForName(EPSColorModeClassName, null);
@@ -233,7 +226,7 @@ public class SnapshotUtilities {
 //            // EpsGraphics stores directly in a file
 //            fos = new FileOutputStream(selectedFile);
 //            Graphics2D g = new EpsGraphics("eps", fos, 0, 0, target.getWidth(), target.getHeight(), ColorMode.COLOR_RGB);
-//            choosePaint(target, g, paintOffscreen);
+//            paintImage(target, g, paintOffscreen);
 //
 //        } finally {
 //            if(fos != null){
@@ -244,7 +237,7 @@ public class SnapshotUtilities {
 //
 //    }
 
-    private static void exportScreenshotSVG(Component target, File selectedFile, boolean paintOffscreen) throws IOException {
+    private static void exportScreenshotSVG(Component target, File selectedFile, int width, int height, boolean paintOffscreen) throws IOException {
 
         String format = "svg";
         selectedFile = fixFileExt(selectedFile, new String[]{format}, format);
@@ -257,14 +250,14 @@ public class SnapshotUtilities {
         // Write image data into document
         SVGGraphics2D svgGenerator = new SVGGraphics2D(document);
 
-        choosePaint(target, svgGenerator, paintOffscreen);
+        paintImage(target, svgGenerator, width, height, paintOffscreen);
 
         Writer out = null;
         try {
             // Finally, stream out SVG to the standard output using
             // UTF-8 encoding.
             boolean useCSS = true; // we want to use CSS style attributes
-            out = new BufferedWriter(new OutputStreamWriter( new FileOutputStream(selectedFile), "UTF-8"));
+            out = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(selectedFile), "UTF-8"));
             svgGenerator.stream(out, useCSS);
         } finally {
             if (out != null) try {
@@ -276,33 +269,34 @@ public class SnapshotUtilities {
 
     }
 
-    private static void choosePaint(Component target, Graphics2D g, boolean paintOffscreen){
+    private static void paintImage(Component target, Graphics2D g, int width, int height, boolean paintOffscreen) {
         log.debug("Painting to target " + target + " , offscreen " + paintOffscreen);
-        if(paintOffscreen){
-            ((Paintable) target).paintOffscreen(g, target.getBounds());
-        }else{
+        if (paintOffscreen) {
+            Rectangle rect = new Rectangle(0, 0, width, height);
+            ((Paintable) target).paintOffscreen(g, rect);
+        } else {
             target.paintAll(g);
         }
     }
 
     /**
-     *
      * Export the specified {@code target} component as a {@code BufferedImage} to the given file.
+     *
      * @param target
      * @param selectedFile
      * @param width
      * @param height
      * @param allowedExts
-     * @param format Format, also appended as an extension if the file doesn't end with anything in {@code allowedExts}
+     * @param format         Format, also appended as an extension if the file doesn't end with anything in {@code allowedExts}
      * @param paintOffscreen
      * @throws IOException
      */
     private static void exportScreenShotBufferedImage(Component target, File selectedFile, int width, int height,
-                                                      String[] allowedExts, String format, boolean paintOffscreen) throws IOException{
+                                                      String[] allowedExts, String format, boolean paintOffscreen) throws IOException {
         BufferedImage image = getDeviceCompatibleImage(width, height);
         Graphics2D g = image.createGraphics();
 
-        choosePaint(target, g, paintOffscreen);
+        paintImage(target, g, width, height, paintOffscreen);
 
         selectedFile = fixFileExt(selectedFile, allowedExts, format);
         if (selectedFile != null) {
@@ -311,26 +305,52 @@ public class SnapshotUtilities {
         }
     }
 
+    public static BufferedImage createBufferedImage(Component target, Rectangle clipRect,  int maxHeight) throws IOException {
+
+        int width = clipRect.width;
+        int height = Math.min(clipRect.height, 1000);
+
+        BufferedImage image = getDeviceCompatibleImage(width, height);
+        Graphics2D g = image.createGraphics();
+
+       // clipRect.x += 5;
+       // clipRect.width -=5;
+
+       // g.setClip(clipRect);
+        g.translate(0, -clipRect.y);
+        height += clipRect.y;
+
+        Rectangle rect = new Rectangle(0, 0, width, height);
+        ((Paintable) target).paintOffscreen(g, rect);
+
+        g.setBackground(Color.WHITE);
+        g.clearRect(0, 0, 5, height);
+
+        return image;
+
+    }
+
     /**
      * Add a file extension to the file if it doesn't already
      * have an acceptable one
+     *
      * @param selectedFile
      * @param allowedExts  Strings which qualify as extensions
      * @param defExtension Default extension. A period be inserted in between the file path iff {@code defExtension}
      *                     does not already have it
      * @return Either the input File, if it had an extension contained in {@code allowedExts},
-     *         or a new with with {@code defExtension} appended
+     * or a new with with {@code defExtension} appended
      */
-    private static File fixFileExt(File selectedFile, String[] allowedExts, String defExtension){
+    private static File fixFileExt(File selectedFile, String[] allowedExts, String defExtension) {
         boolean hasExt = false;
         if (selectedFile != null) {
-            for(String ext: allowedExts){
+            for (String ext : allowedExts) {
                 if (selectedFile.getName().toLowerCase().endsWith(ext)) {
                     hasExt = true;
                     break;
                 }
             }
-            if(!hasExt){
+            if (!hasExt) {
                 String addExt = defExtension.startsWith(".") ? defExtension : "." + defExtension;
                 String correctedFilename = selectedFile.getAbsolutePath() + addExt;
                 selectedFile = new File(correctedFilename);
