@@ -36,6 +36,7 @@ import org.broad.igv.ui.IGV;
 
 import javax.swing.*;
 import java.awt.*;
+import java.awt.event.InputEvent;
 import java.lang.reflect.InvocationTargetException;
 
 
@@ -53,7 +54,7 @@ public class UIUtilities {
      *
      * @param dialogTitle
      * @param defaultColor The currently selected color
-     * @return  The color the user selected, or null if none/cancelled
+     * @return The color the user selected, or null if none/cancelled
      */
     public static Color showColorChooserDialog(String dialogTitle, Color defaultColor) {
 
@@ -173,4 +174,14 @@ public class UIUtilities {
             }
         }
     }
-}
+
+    public static String bringToFront() {
+        // Trick to force window to front, the setAlwaysOnTop works on a Mac,  toFront() does nothing.
+        Frame mainFrame = IGV.getMainFrame();
+        mainFrame.toFront();
+        mainFrame.setAlwaysOnTop(true);
+        mainFrame.setAlwaysOnTop(false);
+        return "OK";
+    }
+
+}
\ No newline at end of file
