@@ -25,6 +25,7 @@
 
 package org.broad.igv.util;
 
+import org.apache.commons.io.output.StringBuilderWriter;
 import org.broad.igv.util.ftp.FTPUtils;
 import org.apache.commons.io.FilenameUtils;
 import org.apache.log4j.Logger;
@@ -52,6 +53,8 @@ public class FileUtils {
 
 
     public static boolean resourceExists(String path) {
+
+        if(path == null) return false;
         try {
             if (isRemote(path)) {
                 return HttpUtils.getInstance().resourceAvailable(new URL(path));
@@ -70,7 +73,7 @@ public class FileUtils {
             return false;
         }
         return path.startsWith("http://") || path.startsWith("https://") ||
-                path.startsWith("ftp://");
+                path.startsWith("ftp://") || path.startsWith("gs://");
     }
 
 
@@ -380,7 +383,8 @@ public class FileUtils {
             String basePath = referencePath.substring(0, idx);
             absolutePath = basePath + "/" + inputPath;
         } else {
-            File parent = new File(referencePath).getParentFile();
+            File referenceFile = new File(referencePath);
+            File parent = referenceFile.isDirectory() ? referenceFile : referenceFile.getParentFile();
             File file = new File(parent, inputPath);
             try {
                 absolutePath = file.getCanonicalPath();
@@ -463,4 +467,52 @@ public class FileUtils {
             }
         }
     }
+
+    /**
+     * Read and return the file contents as a string
+     * @param path
+     * @return
+     */
+    public static String getContents(String path) throws IOException {
+
+        BufferedReader reader = ParsingUtils.openBufferedReader(path);
+
+        StringBuilder contents = new StringBuilder();
+        PrintWriter pw = new PrintWriter(new StringBuilderWriter(contents));
+        String nextLine;
+        while((nextLine = reader.readLine()) != null) {
+            pw.println(nextLine);
+        }
+        return contents.toString();
+
+    }
+
+    public static byte[] readFully(String aInputFileName) {
+        File file = new File(aInputFileName);
+        byte[] result = new byte[(int) file.length()];
+        try {
+            InputStream input = null;
+            try {
+                int totalBytesRead = 0;
+                input = new BufferedInputStream(new FileInputStream(file));
+                while (totalBytesRead < result.length) {
+                    int bytesRemaining = result.length - totalBytesRead;
+                    //input.read() returns -1, 0, or more :
+                    int bytesRead = input.read(result, totalBytesRead, bytesRemaining);
+                    if (bytesRead > 0) {
+                        totalBytesRead = totalBytesRead + bytesRead;
+                    }
+                }
+
+            } finally {
+
+                input.close();
+            }
+        } catch (FileNotFoundException ex) {
+
+        } catch (IOException ex) {
+
+        }
+        return result;
+    }
 }
