@@ -26,28 +26,31 @@
 package org.broad.igv.util.blat;
 
 import org.broad.igv.Globals;
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.PSLRecord;
+import org.broad.igv.feature.Strand;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.feature.tribble.PSLCodec;
-import org.broad.igv.track.FeatureCollectionSource;
-import org.broad.igv.track.FeatureSource;
-import org.broad.igv.track.FeatureTrack;
-import org.broad.igv.track.Track;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.PreferencesManager;
+import org.broad.igv.track.*;
 import org.broad.igv.ui.IGV;
-import org.broad.igv.ui.IGVMainFrame;
 import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.util.HttpUtils;
 import org.broad.igv.util.LongRunningTask;
 import org.broad.igv.util.NamedRunnable;
 
+import javax.swing.*;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
 import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.StringReader;
 import java.net.URL;
 import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 
 /**
  * Port of perl script blatPlot.pl   http://genomewiki.cse.ucsc.edu/index.php/Blat_Scripts
@@ -131,13 +134,13 @@ public class BlatClient {
         }
 
         //$response;
-        String $url = PreferenceManager.getInstance().get(PreferenceManager.BLAT_URL);
+        String $url = PreferencesManager.getPreferences().get(Constants.BLAT_URL);
 
         //if an hgsid was obtained from the output of the first batch
         //then use this.
 
         String urlString = ($url + "?org=" + org + "&db=" + db + "&type=" + searchType + "&sort=" + sortOrder +
-                "&output=" + outputType + "&userSeq=" + userSeq); // + "&hgsid=" + hgsid);
+                "&output=" + outputType); // + "&hgsid=" + hgsid);
         if (hgsid != null) {
             urlString += "&hgsid=" + hgsid;
         }
@@ -153,7 +156,9 @@ public class BlatClient {
 
         lastQueryTime = System.currentTimeMillis();
 
-        String result = HttpUtils.getInstance().getContentsAsString(new URL(urlString));
+        Map<String, String> params = new HashMap();
+        params.put("userSeq", userSeq);
+        String result = HttpUtils.getInstance().doPost(new URL(urlString), params);
 
         return parseResult(result);
     }
@@ -215,7 +220,7 @@ public class BlatClient {
         return records;
     }
 
-    public static void doBlatQuery(final String chr, final int start, final int end) {
+    public static void doBlatQuery(final String chr, final int start, final int end, Strand strand) {
 
         if((end - start) > 8000) {
             MessageUtils.showMessage("BLAT searches are limited to 8kb.  Please try a shorter sequence.");
@@ -226,6 +231,10 @@ public class BlatClient {
         final byte[] seqBytes = genome.getSequence(chr, start, end);
         String userSeq = new String(seqBytes);
 
+        if(strand == Strand.NEGATIVE) {
+            userSeq = SequenceTrack.getReverseComplement(userSeq);
+        }
+
         doBlatQuery(userSeq);
     }
 
@@ -242,7 +251,6 @@ public class BlatClient {
                     Genome genome = IGV.hasInstance() ? GenomeManager.getInstance().getCurrentGenome() : null;
                     PSLCodec codec = new PSLCodec(genome, true);
 
-                    // TODO -- something better than this!
                     String db = genome.getId();
                     String species = genome.getSpecies();
                     if (species == null) {
@@ -277,11 +285,28 @@ public class BlatClient {
 
                     }
                 } catch (IOException e1) {
-
                     MessageUtils.showErrorMessage("Error running blat", e1);
                 }
             }
         });
     }
+
+
+    public static JMenuItem getMenuItem() {
+        JMenuItem menuItem = new JMenuItem("BLAT ...");
+        menuItem.addActionListener(new ActionListener() {
+            @Override
+            public void actionPerformed(ActionEvent e) {
+
+                String blatSequence = MessageUtils.showInputDialog("Enter sequence to blat:");
+                if(blatSequence != null) {
+                    doBlatQuery(blatSequence);
+                }
+
+            }
+        });
+
+        return menuItem;
+    }
 }
 
