@@ -44,7 +44,7 @@ public class SeekableServiceStream extends SeekableStream {
 
     static Logger log = Logger.getLogger(SeekableServiceStream.class);
 
-    private static final String WEBSERVICE_URL = "https://portals.broadinstitute.org/webservices/igv/range";
+    public static final String WEBSERVICE_URL = "https://portals.broadinstitute.org/webservices/igv/range";
 
 
 
@@ -151,4 +151,4 @@ public class SeekableServiceStream extends SeekableStream {
     public int read() throws IOException {
         throw new UnsupportedOperationException("read() is not supported on SeekableServiceStream.  Must read in blocks.");
     }
-}
\ No newline at end of file
+}
