@@ -28,23 +28,25 @@
 
 package org.broad.igv.variant;
 
+import htsjdk.tribble.Feature;
+import htsjdk.variant.variantcontext.GenotypeType;
 import org.apache.log4j.Logger;
-import org.broad.igv.PreferenceManager;
 import org.broad.igv.feature.FeatureUtils;
 import org.broad.igv.feature.IGVFeature;
+import org.broad.igv.prefs.IGVPreferences;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.renderer.GraphicUtils;
 import org.broad.igv.session.IGVSessionReader;
 import org.broad.igv.session.SubtlyImportant;
 import org.broad.igv.track.*;
 import org.broad.igv.ui.FontManager;
 import org.broad.igv.ui.IGV;
-import org.broad.igv.ui.event.TrackGroupEvent;
-import org.broad.igv.ui.event.TrackGroupEventListener;
+import org.broad.igv.event.IGVEventBus;
+import org.broad.igv.event.IGVEventObserver;
+import org.broad.igv.event.TrackGroupEvent;
 import org.broad.igv.ui.panel.*;
 import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.util.*;
-import htsjdk.tribble.Feature;
-import htsjdk.variant.variantcontext.GenotypeType;
 
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlType;
@@ -57,11 +59,13 @@ import java.text.DecimalFormat;
 import java.util.*;
 import java.util.List;
 
+import static org.broad.igv.prefs.Constants.*;
+
 /**
  * @author Jesse Whitworth, Jim Robinson, Fabien Campagne
  */
 @XmlType(factoryMethod = "getNextTrack")
-public class VariantTrack extends FeatureTrack implements TrackGroupEventListener {
+public class VariantTrack extends FeatureTrack implements IGVEventObserver {
 
     private static Logger log = Logger.getLogger(VariantTrack.class);
 
@@ -75,9 +79,8 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
     private static final Color borderGray = new Color(200, 200, 200);
 
     private final static int DEFAULT_EXPANDED_GENOTYPE_HEIGHT = 15;
-    private final static int DEFAULT_SQUISHED_GENOTYPE_HEIGHT = 4;
+    private final int DEFAULT_SQUISHED_GENOTYPE_HEIGHT = 4;
     private final static int DEFAULT_VARIANT_BAND_HEIGHT = 25;
-    private final static int DEFAULT_SQUISHED_VARIANT_BAND_HEIGHT = 10;
     private final static int MAX_FILTER_LINES = 15;
 
 
@@ -115,7 +118,6 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
     /**
      * The height of the top band representing the variant call
      */
-    @XmlAttribute
     private int variantBandHeight = DEFAULT_VARIANT_BAND_HEIGHT;
 
     /**
@@ -126,13 +128,11 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
     /**
      * Boolean indicating if samples are grouped.
      */
-    @XmlAttribute
     private boolean grouped;
 
     /**
      * The id of the group used to group samples.
      */
-    @XmlAttribute
     private String groupByAttribute;
 
     /**
@@ -196,7 +196,7 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
                         boolean enableMethylationRateSupport) {
         super(locator, source);
 
-        PreferenceManager prefMgr = PreferenceManager.getInstance();
+        IGVPreferences prefMgr = PreferencesManager.getPreferences();
 
         String path = locator == null ? null : locator.getPath();
 
@@ -209,7 +209,7 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
             coloring = ColorMode.METHYLATION_RATE;
         }
 
-        this.siteColorMode = prefMgr.getAsBoolean(PreferenceManager.VARIANT_COLOR_BY_ALLELE_FREQ) ?
+        this.siteColorMode = prefMgr.getAsBoolean(VARIANT_COLOR_BY_ALLELE_FREQ) ?
                 ColorMode.ALLELE_FREQUENCY :
                 ColorMode.ALLELE_FRACTION;
 
@@ -220,15 +220,16 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
 
         setDisplayMode(DisplayMode.EXPANDED);
 
-        // Listen for "group by" events.
-        if (IGV.hasInstance()) {
-            IGV.getInstance().addGroupEventListener(this);
-        }
+        int sampleCount = allSamples.size();
+        final int groupCount = samplesByGroups.size();
+        final int margins = (groupCount - 1) * 3;
+        squishedHeight = sampleCount == 0 ? DEFAULT_SQUISHED_GENOTYPE_HEIGHT :
+                Math.min(DEFAULT_SQUISHED_GENOTYPE_HEIGHT, Math.max(1, (height - variantBandHeight - margins) / sampleCount));
 
         // If sample->bam list file is supplied enable vcfToBamMode.
         String vcfToBamMapping = locator == null ? null : locator.getMappingPath();
 
-        boolean bypassFileAutoDiscovery = prefMgr.getAsBoolean(PreferenceManager.BYPASS_FILE_AUTO_DISCOVERY);
+        boolean bypassFileAutoDiscovery = prefMgr.getAsBoolean(BYPASS_FILE_AUTO_DISCOVERY);
         if (vcfToBamMapping == null && path != null && !bypassFileAutoDiscovery) {
             if (ParsingUtils.pathExists(path + ".mapping")) {
                 vcfToBamMapping = path + ".mapping";
@@ -243,7 +244,7 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
         // Ugly test on source is to avoid having to add "isIndexed" to a zillion feature source classes.  The intent
         // is to skip this if using a non-indexed source.
         if (!(source instanceof TribbleFeatureSource && ((TribbleFeatureSource) source).isIndexed() == false)) {
-            int defVisibilityWindow = prefMgr.getAsInt(PreferenceManager.DEFAULT_VISIBILITY_WINDOW);
+            int defVisibilityWindow = prefMgr.getAsInt(DEFAULT_VISIBILITY_WINDOW);
             if (defVisibilityWindow > 0) {
                 setVisibilityWindow(defVisibilityWindow * 1000);
             } else {
@@ -252,6 +253,8 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
             }
         }
 
+        IGVEventBus.getInstance().subscribe(TrackGroupEvent.class, this);
+
     }
 
     private void loadAlignmentMappings(String bamListPath) {
@@ -432,29 +435,15 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
         final int expandedHeight = variantBandHeight + margins + (sampleCount * getGenotypeBandHeight());
         if (height < expandedHeight) {
             setDisplayMode(DisplayMode.SQUISHED);
-            squishedHeight = Math.max(1, (height - variantBandHeight - margins) / sampleCount);
         } else {
             if (displayMode != DisplayMode.EXPANDED) {
                 setDisplayMode(DisplayMode.EXPANDED);
             }
         }
+
+        squishedHeight = Math.min(DEFAULT_SQUISHED_GENOTYPE_HEIGHT, Math.max(1, (height - variantBandHeight - margins) / sampleCount));
     }
 
-    @Override
-    public void setDisplayMode(DisplayMode mode) {
-
-        variantBandHeight = mode == DisplayMode.SQUISHED ? DEFAULT_SQUISHED_VARIANT_BAND_HEIGHT : DEFAULT_VARIANT_BAND_HEIGHT;
-
-        if(mode == DisplayMode.SQUISHED) {
-            // Compute row height needed to display all genotypes, if possible
-            final int groupCount = samplesByGroups.size();
-            final int margins = (groupCount - 1) * 3;
-            int sampleCount = allSamples.size();
-            squishedHeight = Math.min(DEFAULT_SQUISHED_GENOTYPE_HEIGHT, Math.max(1, (height - variantBandHeight - margins) / sampleCount));
-        }
-
-        super.setDisplayMode(mode);
-    }
 
     /**
      * Render the features in the supplied rectangle.
@@ -589,6 +578,7 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
                     }
                     tmpRect.y += tmpRect.height;
                 }
+                tmpRect.y += GROUP_BORDER_WIDTH;
             }
         } else {
 
@@ -899,23 +889,22 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
      *
      * @param chr
      * @param position - position in UCSC "0 based"  genomic coordinates
-     * @param y        - pixel position in panel coordinates (i.e. not track coordinates)
-     * @param frame
-     * @return
+     * @param mouseX
+     * @param frame    @return
      */
-    public String getValueStringAt(String chr, double position, int y, ReferenceFrame frame) {
+    public String getValueStringAt(String chr, double position, int mouseX, int mouseY, ReferenceFrame frame) {
 
         try {
             double maxDistance = 10 * frame.getScale();
-            if (y < top + getVariantsHeight()) {
-                int modY = areFeaturesStacked() ? y : -1;
+            if (mouseY < top + getVariantsHeight()) {
+                int modY = areFeaturesStacked() ? mouseY : -1;
                 Variant variant = getFeatureClosest(position, modY, frame.getName(), maxDistance);
                 if (variant == null) return null;
 
                 return getVariantToolTip(variant);
             } else {
                 if (sampleBounds == null || sampleBounds.isEmpty()) return null;
-                String sample = getSampleAtPosition(y);
+                String sample = getSampleAtPosition(mouseY);
                 if (sample == null) return null;
 
                 Variant variant = getFeatureClosest(position, -1, frame.getName(), maxDistance);
@@ -1147,8 +1136,11 @@ public class VariantTrack extends FeatureTrack implements TrackGroupEventListene
         this.squishedHeight = squishedHeight;
     }
 
-    public void onTrackGroupEvent(TrackGroupEvent e) {
-        setupGroupsFromAttributes();
+    @Override
+    public void receiveEvent(Object event) {
+        if(event instanceof  TrackGroupEvent) {
+            setupGroupsFromAttributes();
+        }
     }
 
     public boolean hasAlignmentFiles() {
