@@ -27,13 +27,11 @@ package org.broad.igv.sam;
 
 import htsjdk.samtools.util.CloseableIterator;
 import org.broad.igv.AbstractHeadlessTest;
-import org.broad.igv.PreferenceManager;
-import org.broad.igv.feature.Locus;
-import org.broad.igv.feature.Range;
+import org.broad.igv.prefs.Constants;
+import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.sam.reader.AlignmentReader;
 import org.broad.igv.sam.reader.AlignmentReaderFactory;
 import org.broad.igv.sam.reader.ReadGroupFilter;
-import org.broad.igv.track.RenderContextImpl;
 import org.broad.igv.ui.panel.ReferenceFrame;
 import org.broad.igv.util.ResourceLocator;
 import org.broad.igv.util.TestUtils;
@@ -65,56 +63,42 @@ public class AlignmentDataManagerTest extends AbstractHeadlessTest {
     public void tearDown() throws Exception {
         super.tearDown();
     }
+//
+//
+//    @Test
+//    public void testPreloadNoMerge() throws Exception {
+//
+//        final String chr = "chr1";
+//        final int start = 151666494;
+//        final int halfwidth = 1000;
+//        final int end = start + 2 * halfwidth;
+//
+//        //Load separate intervals, check they don't merge
+//        AlignmentDataManager manager = getManager171();
+//        ReferenceFrame frame = new ReferenceFrame(frameName);
+//        AlignmentTrack.RenderOptions renderOptions = new AlignmentTrack.RenderOptions();
+//        frame.setBounds(0, end - start);
+//
+//        RenderContext context = new RenderContext(null, null, frame, null);
+//
+//        int lastStart = genome.getChromosome(chr).getLength() - 4 * halfwidth;
+//        int[] starts = new int[]{500, 5000, 15000, start, 500000, lastStart};
+//        int[] ends = new int[]{600, 10000, 20000, end, 600000, lastStart + 2 * halfwidth};
+//        for (int ii = 0; ii < starts.length; ii++) {
+//            frame.jumpTo(new Locus(chr, starts[ii], ends[ii]));
+//            int actEnd = (int) frame.getEnd();
+//
+//            manager.load(context.getReferenceFrame(), renderOptions, false);
+//
+//            assertManagerHasInterval(manager, context.getReferenceFrame(), chr, starts[ii], actEnd);
+//        }
+//
+//
+//    }
 
-    @Test
-    public void testPreloadPanning() throws Exception {
+    private static void assertManagerHasInterval(AlignmentDataManager manager, ReferenceFrame frame, String chr, int start, int end) {
 
-        final String chr = "chr1";
-        final int start = 151666494;
-        final int halfwidth = 1000;
-        final int end = start + 2 * halfwidth;
-        int panInterval = halfwidth;
-
-        int numPans = 20 * (end - start) / (panInterval) * 5;
-        AlignmentInterval interval = AlignmentDataManagerTest.performPanning(chr, start, end, panInterval, numPans);
-
-        assertNotNull(interval);
-    }
-
-    @Test
-    public void testPreloadNoMerge() throws Exception {
-
-        final String chr = "chr1";
-        final int start = 151666494;
-        final int halfwidth = 1000;
-        final int end = start + 2 * halfwidth;
-
-        //Load separate intervals, check they don't merge
-        AlignmentDataManager manager = getManager171();
-        ReferenceFrame frame = new ReferenceFrame(frameName);
-        AlignmentTrack.RenderOptions renderOptions = new AlignmentTrack.RenderOptions();
-        frame.setBounds(0, end - start);
-
-        RenderContextImpl context = new RenderContextImpl(null, null, frame, null);
-
-        int lastStart = genome.getChromosome(chr).getLength() - 4 * halfwidth;
-        int[] starts = new int[]{500, 5000, 15000, start, 500000, lastStart};
-        int[] ends = new int[]{600, 10000, 20000, end, 600000, lastStart + 2 * halfwidth};
-        for (int ii = 0; ii < starts.length; ii++) {
-            frame.jumpTo(new Locus(chr, starts[ii], ends[ii]));
-            int actEnd = (int) frame.getEnd();
-
-            manager.load(context.getReferenceFrame(), renderOptions, false);
-
-            assertManagerHasInterval(manager, chr, starts[ii], actEnd);
-        }
-
-
-    }
-
-    private static void assertManagerHasInterval(AlignmentDataManager manager, String chr, int start, int end) {
-        Range range = new Range(chr, start, end);
-        AlignmentInterval interval = manager.getLoadedInterval(range);
+        AlignmentInterval interval = manager.getLoadedInterval(frame);
         assertNotNull(interval);
 
         boolean haveInterval = interval.contains(chr, start, end);
@@ -129,41 +113,6 @@ public class AlignmentDataManagerTest extends AbstractHeadlessTest {
         return manager;
     }
 
-    /**
-     * Emulates panning across a specific interval.
-     *
-     * @param chr
-     * @param start
-     * @param end
-     * @param panInterval
-     * @param numPans
-     * @return
-     * @throws IOException
-     */
-    public static AlignmentInterval performPanning(String chr, int start, int end, int panInterval, int numPans) throws IOException {
-
-        AlignmentDataManager manager = getManager171();
-
-        int shift = 0;
-
-        ReferenceFrame frame = new ReferenceFrame(frameName);
-        AlignmentTrack.RenderOptions renderOptions = new AlignmentTrack.RenderOptions();
-        frame.setBounds(0, end - start);
-        RenderContextImpl context = new RenderContextImpl(null, null, frame, null);
-
-        for (int pp = 0; pp < numPans; pp++) {
-            shift = pp * panInterval;
-            Locus locus = new Locus(chr, start + shift, end + shift);
-            frame.jumpTo(locus);
-
-            manager.load(context.getReferenceFrame(), renderOptions, false);
-
-            assertManagerHasInterval(manager, chr, locus.getStart(), locus.getEnd());
-        }
-
-        return manager.getLoadedInterval(frame.getCurrentRange());
-
-    }
 
 
     @Test
@@ -195,10 +144,10 @@ public class AlignmentDataManagerTest extends AbstractHeadlessTest {
             Alignment rec = iter.next();
 
             // the following filters are applied in the Caching reader, so we need to apply them here.
-            boolean filterFailedReads = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SAM_FILTER_FAILED_READS);
+            boolean filterFailedReads = PreferencesManager.getPreferences().getAsBoolean(Constants.SAM_FILTER_FAILED_READS);
             ReadGroupFilter filter = ReadGroupFilter.getFilter();
-            boolean showDuplicates = PreferenceManager.getInstance().getAsBoolean(PreferenceManager.SAM_SHOW_DUPLICATES);
-            int qualityThreshold = PreferenceManager.getInstance().getAsInt(PreferenceManager.SAM_QUALITY_THRESHOLD);
+            boolean showDuplicates = !PreferencesManager.getPreferences().getAsBoolean(Constants.SAM_FILTER_DUPLICATES);
+            int qualityThreshold = PreferencesManager.getPreferences().getAsInt(Constants.SAM_QUALITY_THRESHOLD);
             if (!rec.isMapped() || (!showDuplicates && rec.isDuplicate()) ||
                     (filterFailedReads && rec.isVendorFailedRead()) ||
                     rec.getMappingQuality() < qualityThreshold ||
@@ -270,7 +219,7 @@ public class AlignmentDataManagerTest extends AbstractHeadlessTest {
     @Ignore
     @Test
     public void testQueryLargeFile() throws Exception {
-        PreferenceManager.getInstance().put(PreferenceManager.SAM_MAX_VISIBLE_RANGE, "5");
+        PreferencesManager.getPreferences().put(Constants.SAM_MAX_VISIBLE_RANGE, "5");
         String path = TestUtils.LARGE_DATA_DIR + "ABCD_igvSample.bam";
 
         ResourceLocator loc = new ResourceLocator(path);
@@ -308,8 +257,8 @@ public class AlignmentDataManagerTest extends AbstractHeadlessTest {
 
     @Test
     public void testQueryPiledUp() throws Exception {
-        PreferenceManager.getInstance().put(PreferenceManager.SAM_MAX_VISIBLE_RANGE, "5");
-        PreferenceManager.getInstance().put(PreferenceManager.SAM_DOWNSAMPLE_READS, "false");
+        PreferencesManager.getPreferences().put(Constants.SAM_MAX_VISIBLE_RANGE, "5");
+        PreferencesManager.getPreferences().put(Constants.SAM_DOWNSAMPLE_READS, "false");
         String path = TestUtils.DATA_DIR + "aligned/pileup.sorted.aligned";
 
         ResourceLocator loc = new ResourceLocator(path);
@@ -424,7 +373,7 @@ public class AlignmentDataManagerTest extends AbstractHeadlessTest {
      * {@link AlignmentDataManager#loadInterval(String, int, int, AlignmentTrack.RenderOptions)}
      */
     public static AlignmentInterval loadInterval(AlignmentDataManager manager, String chr, int start, int end) {
-        return manager.loadInterval(chr, start, end, new AlignmentTrack.RenderOptions());
+        return manager.loadInterval(chr, start, end, (new AlignmentTrack.RenderOptions()));
     }
 
 
