@@ -42,7 +42,7 @@ public class BisulfiteBaseInfoTest {
         byte [] ref = {(byte) 'C', (byte) 'G'};
         byte [] read = {(byte) 'C', (byte) 'G'};
         TestAlignment testAlignment = new TestAlignment();
-        AlignmentBlock block = new AlignmentBlockImpl("", 0, read, null);
+        AlignmentBlock block = new AlignmentBlockImpl(0, read, null);
         BisulfiteBaseInfo bbi = new BisulfiteBaseInfo(ref, testAlignment, block, context);
 
     }
@@ -51,6 +51,9 @@ public class BisulfiteBaseInfoTest {
 
     static class TestAlignment extends SAMAlignment {
 
+        protected String readGroup;
+        protected String library;
+        protected String sample;
         boolean isNegativeStrand = false;
         private Strand firstOfPairStrand;
         private Strand secondOfPairStrand;
@@ -240,5 +243,13 @@ public class BisulfiteBaseInfoTest {
         public boolean isNegativeStrand() {
             return false;
         }
+
+        public String getReadGroup() {
+            return readGroup;
+        }
+
+        public String getLibrary() {
+            return library;
+        }
     }
 }
